********************************************************************************
* DESCRIPTION: Converts minimum wage into quarterly frequency.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

* process MW wage data
use "${DTA_DIR}/min_wage_nom.dta", clear

gen edate = mdy(month, 1, year)
gen mdate = mofd(edate)
format mdate %tm
drop edate
order mdate year month mw

tsset mdate 
tsfill, full

replace year = yofd(dofm(mdate))
replace month = month(dofm(mdate))

replace mw = mw[_n-1] if mw == .

gen quarter = 0
replace quarter = 1 if month == 1 | month == 2 | month == 3
replace quarter = 2 if month == 4 | month == 5 | month == 6
replace quarter = 3 if month == 7 | month == 8 | month == 9
replace quarter = 4 if month == 10 | month == 11 | month == 12

collapse (mean) mw, by (year quarter)

drop if year < 1996

expand 2 in 87
gen index = _n
replace quarter = 4 if index == 88
drop index

save "${DTA_DIR}/min_wage_nom_quarterly.dta", replace
