********************************************************************************
* DESCRIPTION: Produces figures showing cross-sectional and longitudinal statistics.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

* plot settings
global fontface = "Times New Roman"

* delete / check / create directories
foreach folder in ///
	"datav" ///
	"complete" {
	cap confirm file "${FIG_DIR}/`folder'/"
	if _rc mkdir "${FIG_DIR}/`folder'/" // if folder does not exist
}

foreach folder in ///
	"datav/CS" "datav/L"  ///
	"complete/CS" "complete/L" {
	if $dir_delete {
		!rm -r "${FIG_DIR}/`folder'"
	}
	cap confirm file "${FIG_DIR}/`folder'/"
	if _rc mkdir "${FIG_DIR}/`folder'/" // if folder does not exist
}

foreach folder in ///
	"datav/CS/m1" "datav/CS/m2" "datav/L/m1" "datav/L/m2" ///
	"complete/CS/m1" "complete/CS/m2" "complete/L/m1" "complete/L/m2" {
	local method_num = real(substr("`folder'", -1, 1))
	if $method == `method_num' {
		cap confirm file "${FIG_DIR}/`folder'/"
		if _rc mkdir "${FIG_DIR}/`folder'/" // if folder does not exist
	}
}


***********************************
*** Data Validation ***************
***********************************

	* Note: Part One(Inequality), Part Three(Earnings Change), Part Four (Skewness & Kurtosis)
	
	* Part One (3 graphs)
		* first method
		if $method == 1 {
			CS_graphs "researn_datav_m1" 1 "male" "male"  0 
			CS_graphs "researn_datav_m1" 0 "fem" "fem"  0 
			CS_graphs "researn_datav_m1" . "all" "all"  0 
					
			CS_graphs "logearn_datav_m1" 1 "male" "male"  0 
			CS_graphs "logearn_datav_m1" 0 "fem" "fem" 0 
			CS_graphs "logearn_datav_m1" . "all" "all" 0 
		}
		
		* second method
		if $method == 2 {
			CS_graphs "researn_datav_m2" 1 "male" "male"  0
			CS_graphs "researn_datav_m2" 0 "fem" "fem"  0 
			CS_graphs "researn_datav_m2" . "all" "all"  0
			
			CS_graphs "logearn_datav_m2" 1 "male" "male"  0 
			CS_graphs "logearn_datav_m2" 0 "fem" "fem"  0
			CS_graphs "logearn_datav_m2" . "all" "all"  0
		}
		
	* Part Three (3 graphs) [missing for now: Four (2 graphs)]
		* first method
		if $method == 1 {
			L_graphs "L_researn_1y_datav_m1" 1 "male" "male" 0
			L_graphs "L_researn_1y_datav_m1" 0 "fem" "fem" 0
			L_graphs "L_researn_1y_datav_m1" . "all" "all" 0
		}
		
		* second method
		if $method == 2 {
			L_graphs "L_researn_1y_datav_m2" 1 "male" "male" 0
			L_graphs "L_researn_1y_datav_m2" 0 "fem" "fem" 0
			L_graphs "L_researn_1y_datav_m2" . "all" "all" 0
		}
		
		
***********************************
*** Complete Analysis *************
***********************************

*** A. All Argentina
	
	* Note: Part One(Inequality), Part Three(Earnings Change), Part Four (Skewness & Kurtosis)
	
	* Part One (3 graphs)
		* first method
		if $method == 1 {
			CS_graphs "researn_m1" 1 "male" "male"  0
			CS_graphs "researn_m1" 0 "fem" "fem"  0 
			CS_graphs "researn_m1" . "all" "all"  0 
					
			CS_graphs "logearn_m1" 1 "male" "male"  0
			CS_graphs "logearn_m1" 0 "fem" "fem" 0 
			CS_graphs "logearn_m1" . "all" "all" 0 
		}
		
		* second method
		if $method == 2 {
			CS_graphs "researn_m2" 1 "male" "male"  0 
			CS_graphs "researn_m2" 0 "fem" "fem"  0
			CS_graphs "researn_m2" . "all" "all"  0 
			
			CS_graphs "logearn_m2" 1 "male" "male"  0 
			CS_graphs "logearn_m2" 0 "fem" "fem"  0 
			CS_graphs "logearn_m2" . "all" "all"  0 
		}
		
	* Part Three (3 graphs) [missing for now: Four (2 graphs)]
		* first method
		if $method == 1 {
			L_graphs "L_researn_1y_m1" 1 "male" "male" 0 
			L_graphs "L_researn_1y_m1" 0 "fem" "fem" 0 
			L_graphs "L_researn_1y_m1" . "all" "all" 0 
		}
		
		* second method
		if $method == 2 {
			L_graphs "L_researn_1y_m2" 1 "male" "male" 0 
			L_graphs "L_researn_1y_m2" 0 "fem" "fem" 0 
			L_graphs "L_researn_1y_m2" . "all" "all" 0 
		}
		
*** B. Formal-Formal, Informal-Informal, Formal-Informal, Informal-Formal
	
	* Note: Part One(Inequality), Part Three(Earnings Change), Part Four (Skewness & Kurtosis)
	
	* Part One (3 graphs)
		* first method
		if $method == 1 {
			CS_graphs_sector "researn_sec_m1" 1 "male formal" "male_s1" 1 0
			CS_graphs_sector "researn_sec_m1" 0 "fem formal" "fem_s1" 1 0
			CS_graphs_sector "researn_sec_m1" . "all formal" "all_s1" 1 0
			
			CS_graphs_sector "researn_sec_m1" 1 "male informal" "male_s2" 2 0
			CS_graphs_sector "researn_sec_m1" 0 "fem informal" "fem_s2" 2 0
			CS_graphs_sector "researn_sec_m1" . "all informal" "all_s2" 2 0
			
			CS_graphs_sector "logearn_sec_m1" 1 "male formal" "male_s1" 1 0
			CS_graphs_sector "logearn_sec_m1" 0 "fem formal" "fem_s1" 1 0
			CS_graphs_sector "logearn_sec_m1" . "all formal" "all_s1" 1 0
			
			CS_graphs_sector "logearn_sec_m1" 1 "male informal" "male_s2" 2 0
			CS_graphs_sector "logearn_sec_m1" 0 "fem informal" "fem_s2" 2 0
			CS_graphs_sector "logearn_sec_m1" . "all informal" "all_s2" 2 0
		}
		
		* second method
		if $method == 2 {
			CS_graphs_sector "researn_sec_m2" 1 "male formal" "male_s1" 1 0
			CS_graphs_sector "researn_sec_m2" 0 "fem formal" "fem_s1" 1 0
			CS_graphs_sector "researn_sec_m2" . "all formal" "all_s1" 1 0

			CS_graphs_sector "researn_sec_m2" 1 "male informal" "male_s2" 2 0
			CS_graphs_sector "researn_sec_m2" 0 "fem informal" "fem_s2" 2 0
			CS_graphs_sector "researn_sec_m2" . "all informal" "all_s2" 2 0	
			
			CS_graphs_sector "logearn_sec_m2" 1 "male formal" "male_s1" 1 0
			CS_graphs_sector "logearn_sec_m2" 0 "fem formal" "fem_s1" 1 0
			CS_graphs_sector "logearn_sec_m2" . "all formal" "all_s1" 1 0
			
			CS_graphs_sector "logearn_sec_m2" 1 "male informal" "male_s2" 2 0
			CS_graphs_sector "logearn_sec_m2" 0 "fem informal" "fem_s2" 2 0
			CS_graphs_sector "logearn_sec_m2" . "all informal" "all_s2" 2 0	
		}
		
	* Part Three (3 graphs) [missing for now: Four (2 graphs)]
		* first method
		if $method == 1 {
			L_graphs_sector "L_researn_1y_sec_m1" 1 "male formal-formal" "male_s1" 1 0
			L_graphs_sector "L_researn_1y_sec_m1" 0 "fem formal-formal" "fem_s1" 1 0
			L_graphs_sector "L_researn_1y_sec_m1" . "all formal-formal" "all_s1" 1 0
			
			L_graphs_sector "L_researn_1y_sec_m1" 1 "male informal-informal" "male_s2" 2 0 
			L_graphs_sector "L_researn_1y_sec_m1" 0 "fem informal-informal" "fem_s2" 2 0
			L_graphs_sector "L_researn_1y_sec_m1" . "all informal-informal" "all_s2" 2 0
			
			L_graphs_sector "L_researn_1y_sec_m1" 1 "male formal-informal" "male_s5" 5 0
			L_graphs_sector "L_researn_1y_sec_m1" 0 "fem formal-informal" "fem_s5" 5 0
			L_graphs_sector "L_researn_1y_sec_m1" . "all formal-informal" "all_s5" 5 0
			
			L_graphs_sector "L_researn_1y_sec_m1" 1 "male informal-formal" "male_s6" 6 0 
			L_graphs_sector "L_researn_1y_sec_m1" 0 "fem informal-formal" "fem_s6" 6 0
			L_graphs_sector "L_researn_1y_sec_m1" . "all informal-formal" "all_s6" 6 0
		}
		
		* second method
		if $method == 2 {
			L_graphs_sector "L_researn_1y_sec_m2" 1 "male formal-formal" "male_s1" 1 0
			L_graphs_sector "L_researn_1y_sec_m2" 0 "fem formal-formal" "fem_s1" 1 0
			L_graphs_sector "L_researn_1y_sec_m2" . "all formal-formal" "all_s1" 1 0
			
			L_graphs_sector "L_researn_1y_sec_m2" 1 "male informal-informal" "male_s2" 2 0 
			L_graphs_sector "L_researn_1y_sec_m2" 0 "fem informal-informal" "fem_s2" 2 0
			L_graphs_sector "L_researn_1y_sec_m2" . "all informal-informal" "all_s2" 2 0
			
			L_graphs_sector "L_researn_1y_sec_m2" 1 "male formal-informal" "male_s5" 5 0
			L_graphs_sector "L_researn_1y_sec_m2" 0 "fem formal-informal" "fem_s5" 5 0
			L_graphs_sector "L_researn_1y_sec_m2" . "all formal-informal" "all_s5" 5 0
			
			L_graphs_sector "L_researn_1y_sec_m2" 1 "male informal-formal" "male_s6" 6 0 
			L_graphs_sector "L_researn_1y_sec_m2" 0 "fem informal-formal" "fem_s6" 6 0
			L_graphs_sector "L_researn_1y_sec_m2" . "all informal-formal" "all_s6" 6 0
		}
