********************************************************************************
* DESCRIPTION: Master file for Part 1+ of GID: Argentina.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************


********************************************************************************
** Housekeeping ****************************************************************
********************************************************************************
set more off, permanently
clear all
timer clear 1
timer on 1
set seed 1
set rmsg on
set graphics off
postutil clear
cap log close


********************************************************************************
** Macros **********************************************************************
********************************************************************************
* Users
if "`c(username)'" == "Roberta" global MAIN_DIR = "C:/Users/Roberta/Dropbox/RA_work_Roberta_Olivieri"
else if "`c(username)'" == "roberta.olivieri" global MAIN_DIR = "C:/Users/roberta.olivieri/Dropbox/RA_work_Roberta_Olivieri"
else if "`c(username)'" == "cm3594" global MAIN_DIR = "/Users/cm3594/Dropbox (CBS)/GID_Argentina"
else if "`c(username)'" == "cmoser" global MAIN_DIR = "/Users/cmoser/Dropbox (CBS)/GID_Argentina"
else {
	disp as error "USER ERROR: Cannot classify current user when defining main directory MAIN_DIR!"
	error 1
}

* directories // Note: Roberta needs to create a directory "Part_A_Plus" inside ${MAIN_DIR}!
global DO_DIR = "${MAIN_DIR}/Part_A_Plus/do"
global DTA_DIR = "${MAIN_DIR}/Part_A_Plus/dta"
global LOG_DIR = "${MAIN_DIR}/Part_A_Plus/log"
global FIG_DIR = "${MAIN_DIR}/Part_A_Plus/figs"
global FINAL_DIR = "${MAIN_DIR}/Part_A_Plus/out"
global MACRO_DIR = "${MAIN_DIR}/Figures/Macro"

* Programs
do "${DO_DIR}/panel_progs.do" // defines programs that produce summary statistics and density plots
do "${DO_DIR}/panel_figs_progs.do" // defines programs that plot figures containing results


********************************************************************************
** Manual switches -- change these! ********************************************
********************************************************************************

* Method for computing individual income
global method_min = 1 // 1 = first method, 2 = second method -- see documentation for exact description of how income is constructed under each method
global method_max = 2 // 1 = first method, 2 = second method -- see documentation for exact description of how income is constructed under each method

* Lower trim
global lower_thresh = 1 // 0 = use ${min_wage_mult}*current MW as threshold, 1 = use ${thresh_mult}*threshold based on real MW in 1996 as threshold
global min_wage_mult = 0.5 // multiple of MW below which to drop earnings observations
global thresh_mult = 0.15 // multiple of 1996-real-MW-based threshold below which to drop earnings observations

* Upper winsorizing
global inc_q_wins = 99.9

* Plot density figures in every analysis?
global kdensity_figs = 0 // 0 = no, 1 = yes

* List of income percentiles to compute
global perc_list = "5 10 25 50 75 90 95" // list of percentiles to create for data validation (e.g., "5 10 25 50 75 90 95")

* Year range
global year_min = 1996
global year_max = 2015

* Year to normalize graphs to
global year_norm = ${year_min} // year to which plots are normalized to (${year_min} or 2001)

* Define years for recession bars -- these will be used to generate a variable called rece used in the plots
global plot_rece_bars = 0 // 0 = do not plot recession years, 1 = plot recession years -- NOTE: work in progress!
global receyears = "1998,1999,2000,2001,2009,2012,2014,2015"

* Selection criteria
global age_min = 18
global age_max = 64
global gender_min = 0 // 0 = female, 1 = male --> CHANGE TO 0!!!!
global gender_max = 1 // 0 = female, 1 = male
global formal_min = 1 // 0 = informal (incl. bus owners & self-emp), 1 = formal
global formal_max = 1 // 0 = informal (incl. bus owners & self-emp), 1 = formal
global job_min = 3 // 1 = business owner, 2 = self-employed, 3 = employee
global job_max = 3 // 1 = business owner, 2 = self-employed, 3 = employee
global public_min = 0 // 0 = private, 1 = public
global public_max = 0 // 0 = private, 1 = public

* Use -gtools- package?
global gtools = 1 // 0 = use only Stata-native functions, 1 = use functions in -gtools- package

* Delete existing output directories incl. all contents?
global dir_delete = 0 // 0 = keep existing folders; 1 = delete existing folders before producing new ones


********************************************************************************
** Which sections to run -- change these! **************************************
********************************************************************************
* Minimum wage construction
global MW_adjustment = 0 // transform minimum wage data to quarterly frequency

* Produce basic summary statistics in test file by Chris
global test_chris = 0

* Data validation (formal sector only)
global data_validation = 1
	global CS_datav = 1
	global L_datav = 1

* Main Analysis (complete economy, formal vs. informal, men vs. women)
global complete_analysis = 1
	global CS = 1
	global L = 1

* Figures
global panel_figs = 1 // 0 = do not run 2_Panel_figs.do; 1 = run 2_Panel_figs.do

* Descriptive statistics
global descriptive_stats = 0 // produce additional descriptive statistics for paper


********************************************************************************
** Automatic switches -- do not change! ****************************************
********************************************************************************
global d_norm = date("31dec${year_norm}", "DMY")
global q_norm = qofd(${d_norm})

********************************************************************************
** Clean the data **************************************************************
********************************************************************************
do "${DO_DIR}/EPHMerge.do"
do "${DO_DIR}/CleaningCode.do"

********************************************************************************
** Run sections ****************************************************************
********************************************************************************
forval m = $method_min/$method_max {
	global method = `m'
	global first_method = (${method} == 1)
	global second_method = (${method} == 2)
	if $MW_adjustment do "${DO_DIR}/0_Minimum_wage.do"
	if $data_validation do "${DO_DIR}/1_Panel_datav.do"
	if $complete_analysis do "${DO_DIR}/1_Panel.do"
	if $panel_figs do "${DO_DIR}/2_Panel_figs.do"
	if $descriptive_stats do "${DO_DIR}/3_descriptive_stats.do"
}
