********************************************************************************
* DESCRIPTION: Creates programs that plot figures.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************


********************************************************************************
** Programs ********************************************************************
********************************************************************************
cap program drop CS_graphs
program CS_graphs

	graph set window fontface "${fontface}"
	global marksize = "medium"
	local titlesize "vlarge"
	local ytitlesize = "medium" 
	local subtitlesize = "medium" 
		
	global vari = "`1'"
	local subsample `2'
	local subtitle "`3'"
	local name_subsample "`4'"
	if `5' == 1 {
		local ylabel_1 ylabel(`6'(`7')`8', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_2 ylabel(`9'(`10')`11', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3 ylabel(`12'(`13')`14', axis(1) grid gstyle(dot) gmin gmax)
	}
	else if `5' == 0 { 
		local ylabel_1 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_2 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
	}
	
	* check what variable
	if substr("`1'", 1, 7) == "researn" {
		local symbol "{&epsilon}{sub:it}"
	}
	else if substr("`1'", 1, 7) == "logearn" {
		local symbol "log y{sub:it}"
	}
	
	* automatically define folder name
	if substr("`1'", -4, 4) == "v_m1" { // if variable name ends in "v_m1"
		local folder datav/CS/m1
		global variN "n${vari}"
	}
	else if substr("`1'", -4, 4) == "v_m2" { // if variable name ends in "v_m2"
		local folder datav/CS/m2
		global variN "n${vari}"
	}
	else if substr("`1'", -4, 4) == "n_m1" { // if variable name ends in "n_m1"
		local folder complete/CS/m1
		global variN "n${vari}"
	} 
	else if substr("`1'", -4, 4) == "n_m2" { // if variable name ends in "n_m2"
		local folder complete/CS/m2
		global variN "n${vari}"
	}
	else {
		disp as error "USER ERROR: Cannot automatically define folder name!"
		error 1
	}
	
	* load data
	use "${FINAL_DIR}/${vari}", clear
	
	* selection
	keep if gender == `subsample'
	
	* create scaled and normalized variables
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	foreach vv in p1${vari} p2_5${vari} p5${vari} p10${vari} p12_5${vari} p25${vari} ///
		p37_5${vari} p50${vari} p62_5${vari} p75${vari} p87_5${vari} p90${vari} p95${vari} ///
		p97_5${vari} p99${vari} p99_9${vari} p99_99${vari} ///
		mean_${vari} std_${vari} ///
		p9010${vari} p9050${vari} p5010${vari} {
		replace `vv' = 100*`vv'
		sum `vv' if year == ${year_norm}, meanonly
		gen n`vv' = `vv' - r(mean)
	}
	
	* Normalized plots plots
// 	local varilist np10${vari} np25${vari} np50${vari} np75${vari} np90${vari} np95${vari} np99${vari} // old by Roberta (before Oct 17, 2020)
// 	local varilist np5${vari} np10${vari} np25${vari} np50${vari} np75${vari} np90${vari} np95${vari} // new by Chris (after Oct 17, 2020)
	if $plot_rece_bars { // plot recession bars
		gen rece = inlist(year,${receyears})
		local rece_bars = "(bar rece year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5) yscale(off))"
		local rece_legend_entry = 1
	}
	else {
		local rece_bars = "" // do not plot recession bars
		local rece_legend_entry = 0
	}
	local varilist = ""
	local legend_str = `" "'
	local n_p = 1 + `rece_legend_entry'
	foreach p in $perc_list {
		local varilist = "`varilist' np`p'${vari}"
		local legend_str = `"`legend_str' `n_p' "P`p'" "'
		local ++n_p
	}
	local one_plus = 1 + `rece_legend_entry'
	local two_plus = 2 + `rece_legend_entry'
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Normalized percentiles of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) ylabel(-40(20)80, grid gstyle(dot) gmin gmax) ) , /// yaxis optins -- `ylabel_1'
	xtitle("",) xlabel(${year_min}(2)${year_max}, grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(4) symxsize(7.0) ring(0) position(11) ///
	order(`legend_str') ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Normalized percentiles of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig1_${variN}_`name_subsample'.pdf", replace 
	
	if inlist("${vari}", "logearn_datav_m1", "logearn_datav_m2") & "`name_subsample'" == "all" {
		cap confirm file "${MAIN_DIR}/Analysis_randomsample/dta/fig1short.dta"
		if !_rc {
			preserve
			use "${MAIN_DIR}/Analysis_randomsample/dta/fig1short.dta", clear
			foreach var of varlist np5logearn np10logearn np25logearn np50logearn np75logearn np90logearn np95logearn {
				replace `var' = `var'*100
			}
			tw `rece_bars' (connected np5logearn np10logearn np25logearn np50logearn np75logearn np90logearn np95logearn year, 				 /// Plot
				lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
				lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
				msymbol(O T D O T D O T D)		/// Marker
				msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
				mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
				mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
				yaxis(1) ytitle("Normalized percentiles of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) ylabel(-40(20)80, grid gstyle(dot) gmin gmax) ) , /// yaxis optins
				xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
				legend(col(4) symxsize(7.0) ring(0) position(11) ///
				order(`legend_str') ///
				region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
				graphregion(color(white) ) ///				Graph region define
				plotregion(lcolor(black)) ///				Plot regione define
				title("Normalized percentiles of `symbol', admin data", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
				graph export "${FIG_DIR}/`folder'/fig1_${variN}_`name_subsample'_admin.pdf", replace 
			restore
		}
	}
	
	tw `rece_bars' (connected np9010${vari} nstd_${vari} year, 				 /// Plot
	lcolor(red blue green ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D )		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) ylabel(-50(10)20, grid gstyle(dot) gmin gmax) ) , /// yaxis optins -- `ylabel_2'
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P10" `two_plus' "Std. dev.") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig2a_${variN}_`name_subsample'.pdf", replace 		
	
	if inlist("${vari}", "logearn_datav_m1", "logearn_datav_m2") & "`name_subsample'" == "all" {
		cap confirm file "${MAIN_DIR}/Analysis_randomsample/dta/fig2aN.dta"
		if !_rc {
			preserve
			use "${MAIN_DIR}/Analysis_randomsample/dta/fig2aN.dta", clear
			foreach var of varlist np9010logearn nsdlogearn {
				replace `var' = `var'*100
			}
			tw `rece_bars' (connected np9010logearn nsdlogearn year, 				 /// Plot
				lcolor(red blue green ) ///			Line color
				lpattern(solid longdash dash) ///			Line pattern
				msymbol(O T D )		/// Marker
				msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
				mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
				mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
				yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) ylabel(-50(10)20, grid gstyle(dot) gmin gmax) ) , /// yaxis optins
				xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
				legend(col(2) symxsize(7.0) ring(0) position(11) ///
				order(`one_plus' "P90-P10" `two_plus' "Std. dev.") ///
				region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
				graphregion(color(white) ) ///				Graph region define
				plotregion(lcolor(black)) ///				Plot regione define
				title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
				graph export "${FIG_DIR}/`folder'/fig2a_${variN}_`name_subsample'_admin.pdf", replace 
			restore
		}
	}
	
	tw `rece_bars' (connected np9050${vari} np5010${vari} year, 				 /// Plot
	lcolor(red blue green ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D )		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_3') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P50" `two_plus' "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig2b_${variN}_`name_subsample'.pdf", replace
	
	* Non-normalized plots
// 	local varilist p5${vari} p10${vari} p25${vari} p50${vari} p75${vari} p90${vari} p95${vari} // new by Chris (after Oct 17, 2020)
	local varilist = ""
	local legend_str = `" "'
	local n_p = 1 + `rece_legend_entry'
	foreach p in $perc_list {
		local varilist = "`varilist' p`p'${vari}"
		local legend_str = `"`legend_str' `n_p' "P`p'" "'
		local ++n_p
	}
	local one_plus = 1 + `rece_legend_entry'
	local two_plus = 2 + `rece_legend_entry'
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Percentiles of `symbol'", axis(1) size(`ytitlesize')) `ylabel_1' ) , /// yaxis optins
	xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(4) symxsize(7.0) ring(0) position(11) ///
	order(`legend_str') ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Percentiles of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig1_${vari}_`name_subsample'.pdf", replace 
	
// 	if inlist("${vari}", "logearn_datav_m1", "logearn_datav_m2") & "`name_subsample'" == "all" {
// 		cap confirm file "${MAIN_DIR}/Analysis_randomsample/dta/fig1short_XXX.dta"
// 		if !_rc {
// 			preserve
// 			use "${MAIN_DIR}/Analysis_randomsample/dta/fig1short.dta", clear
// 			foreach var of varlist p5logearn p10logearn p25logearn p50logearn p75logearn p90logearn p95logearn {
// 				replace `var' = `var'*100
// 			}
// 			tw `rece_bars' (connected p5logearn p10logearn p25logearn p50logearn p75logearn p90logearn p95logearn year, 				 /// Plot
// 				lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
// 				lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
// 				msymbol(O T D O T D O T D)		/// Marker
// 				msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
// 				mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
// 				mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
// 				yaxis(1) ytitle("Percentiles of `symbol'", axis(1) size(`ytitlesize')) `ylabel_1' ) , /// yaxis optins
// 				xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
// 				legend(col(4) symxsize(7.0) ring(0) position(11) ///
// 				order(`legend_str') ///
// 				region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
// 				graphregion(color(white) ) ///				Graph region define
// 				plotregion(lcolor(black)) ///				Plot regione define
// 				title("Percentiles of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
// 				graph export "${FIG_DIR}/`folder'/fig1_${vari}_`name_subsample'_admin.pdf", replace 
// 			restore
// 		}
// 	}
	
	tw `rece_bars' (connected p9010${vari} std_${vari} year, 				 /// Plot
	lcolor(red blue green ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D )		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Measures of dispersion of `symbol'", axis(1) size(`ytitlesize')) `ylabel_2') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P10" `two_plus' "Std. dev.") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig2a_${vari}_`name_subsample'.pdf", replace 		
	
	tw  `rece_bars' (connected p9050${vari} p5010${vari} year, 				 /// Plot
	lcolor(red blue green ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D )		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Measures of dispersion of `symbol'", axis(1) size(`ytitlesize')) `ylabel_3') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P50" `two_plus' "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig2b_${vari}_`name_subsample'.pdf", replace	

end

	
********************************
	
	
cap program drop CS_graphs_sector
program CS_graphs_sector
	
	graph set window fontface "${fontface}"
	global marksize = "medium"
	local titlesize "vlarge"
	local ytitlesize = "medium" 
	local subtitlesize = "medium" 
		
	global vari = "`1'" 
	local gender `2'
	local subtitle "`3'"
	local name_subsample "`4'"
	local sector `5'
	
	if `6' == 1 {
	local ylabel_1 ylabel(`7'(`8')`9', axis(1) gstyle(dot) gmin gmax)
	local ylabel_2 ylabel(`10'(`11')`12', axis(1) gstyle(dot) gmin gmax)
	local ylabel_3 ylabel(`13'(`14')`15', axis(1) gstyle(dot) gmin gmax)
	}
	else if `6' == 0 { 
	local ylabel_1 ylabel(,axis(1) gstyle(dot) gmin gmax)
	local ylabel_2 ylabel(,axis(1) gstyle(dot) gmin gmax)
	local ylabel_3 ylabel(,axis(1) gstyle(dot) gmin gmax)
	}
	
	
	if substr("`1'", 1, 7) == "researn" {
		local symbol "{&epsilon}{sub:it}"
	}
	else if substr("`1'", 1, 7) == "logearn" {
		local symbol "log y{sub:it}"
	}
	else {
		disp as error "USER ERROR: Cannot automatically define earnings symbol!"
		error 1
	}
	if substr("`1'", -4, 4) == "c_m1" {
		local folder complete/CS/m1
		global variN "n${vari}"
	} 
	else if substr("`1'", -4, 4) == "c_m2" {
		local folder complete/CS/m2
		global variN "n${vari}"
	}
	else {
		disp as error "USER ERROR: Cannot automatically define folder name!"
		error 1
	}
	
	* load data
	use "${FINAL_DIR}/${vari}", clear
	
	* selection
	keep if gender == `gender' & sec == `5'
	
	* create scaled and normalized variables
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	foreach vv in p1${vari} p2_5${vari} p5${vari} p10${vari} p12_5${vari} p25${vari} ///
		p37_5${vari} p50${vari} p62_5${vari} p75${vari} p87_5${vari} p90${vari} p95${vari} ///
		p97_5${vari} p99${vari} p99_9${vari} p99_99${vari} ///
		mean_${vari} std_${vari} ///
		p9010${vari} p9050${vari} p5010${vari} {
		replace `vv' = 100*`vv'
		sum `vv' if year == ${year_norm}, meanonly
		gen n`vv' = `vv' - r(mean)
	}
	
	* Normalized plots
// 	local varilist np10${vari} np25${vari} np50${vari} np75${vari} np90${vari} np95${vari} np99${vari} // old by Roberta (before Oct 17, 2020)
// 	local varilist np5${vari} np10${vari} np25${vari} np50${vari} np75${vari} np90${vari} np95${vari} // new by Chris (after Oct 17, 2020)
	if $plot_rece_bars { // plot recession bars
		gen rece = inlist(year,${receyears})
		local rece_bars = "(bar rece year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5) yscale(off))"
		local rece_legend_entry = 1
	}
	else {
		local rece_bars = "" // do not plot recession bars
		local rece_legend_entry = 0
	}
	local varilist = ""
	local legend_str = `" "'
	local n_p = 1 + `rece_legend_entry'
	foreach p in $perc_list {
		local varilist = "`varilist' np`p'${vari}"
		local legend_str = `"`legend_str' `n_p' "P`p'" "'
		local ++n_p
	}
	local one_plus = 1 + `rece_legend_entry'
	local two_plus = 2 + `rece_legend_entry'

	local ylabel_1_save = "`ylabel_1'"
	if inlist("${vari}", "logearn_sec_m1", "logearn_sec_m2") & inlist("`name_subsample'", "all_s1", "all_s2") local ylabel_1 = "ylabel(-60(20)40, grid gstyle(dot) gmin gmax)"	
	
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Normalized percentiles of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_1') , /// yaxis optins
	xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(4) symxsize(7.0) ring(0) position(11) ///
	order(`legend_str') ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Normalized percentiles of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig1_${variN}_`name_subsample'.pdf", replace
	
	local ylabel_1 = "`ylabel_1_save'"
	
	local ylabel_2_save = "`ylabel_2'"
	if inlist("${vari}", "logearn_sec_m1", "logearn_sec_m2") & inlist("`name_subsample'", "all_s1", "all_s2") local ylabel_2 = "ylabel(-30(10)20, grid gstyle(dot) gmin gmax)"	
	
	tw `rece_bars' (connected np9010${vari} nstd_${vari} year, 				 /// Plot
	lcolor(red blue green ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D )		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_2') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P10" `two_plus' "Std. dev.") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig2a_${variN}_`name_subsample'.pdf", replace 		
	
	local ylabel_2 = "`ylabel_2_save'"

	tw `rece_bars' (connected np9050${vari} np5010${vari} year, 				 /// Plot
	lcolor(red blue green ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D )		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_3') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P50" `two_plus' "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig2b_${variN}_`name_subsample'.pdf", replace
	
	* Non-normalized plots
// 	local varilist p5${vari} p10${vari} p25${vari} p50${vari} p75${vari} p90${vari} p95${vari} // new by Chris (after Oct 17, 2020)
	local varilist = ""
	local legend_str = `" "'
	local n_p = 1 + `rece_legend_entry'
	foreach p in $perc_list {
		local varilist = "`varilist' p`p'${vari}"
		local legend_str = `"`legend_str' `n_p' "P`p'" "'
		local ++n_p
	}
	local one_plus = 1 + `rece_legend_entry'
	local two_plus = 2 + `rece_legend_entry'
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Percentiles of `symbol'", axis(1) size(`ytitlesize')) `ylabel_1') , /// yaxis optins
	xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(4) symxsize(7.0) ring(0) position(11) ///
	order(`legend_str') ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Percentiles of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig1_${vari}_`name_subsample'.pdf", replace 
	
	tw `rece_bars' (connected p9010${vari} std_${vari} year, 				 /// Plot
	lcolor(red blue green ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D )		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Measures of dispersion of `symbol'", axis(1) size(`ytitlesize')) `ylabel_2') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P10" `two_plus' "Std. dev.") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of dispersion of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig2a_${vari}_`name_subsample'.pdf", replace 		

	tw `rece_bars' (connected p9050${vari} p5010${vari} year, 				 /// Plot
	lcolor(red blue green ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D )		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Measures of dispersion of `symbol'", axis(1) size(`ytitlesize')) `ylabel_3') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P50" `two_plus' "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of dispersion of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig2b_${vari}_`name_subsample'.pdf", replace

end
	
	
********************************


cap program drop L_graphs
program L_graphs
	
	graph set window fontface "${fontface}"
	global marksize = "medium"
	local titlesize "vlarge"
	local ytitlesize = "medium" 
	local subtitlesize = "medium" 
		
	global vari = "`1'" 
	local subsample `2'
	local subtitle `3'
	local name_subsample "`4'"
	if `5' == 1 {
		local ylabel_1 ylabel(`6'(`7')`8', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_1N ylabel(`9'(`10')`11', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_2 ylabel(`12'(`13')`14', axis(2) grid gstyle(dot) gmin gmax)
		local ylabel_2N ylabel(`15'(`16')`17', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3 ylabel(`18'(`19')`20', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3N ylabel(`21'(`22')`23', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_4 ylabel(, axis(1) grid gstyle(dot) gmin gmax)			
		local ylabel_5 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
	}
	else if `5' == 0 { 
		local ylabel_1 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_1N ylabel(, axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_2 ylabel(,axis(2) grid gstyle(dot) gmin gmax)
		local ylabel_2N ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3N ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_4 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_5 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
	}
	
	if substr("`1'", 1, 9) == "L_researn" {
	local symbol "{&Delta}{sup:1}{&epsilon}{sub:it}"
	}
	
	* automatically define folder names
	if substr("`1'", -4, 4) == "v_m1" { // if variable name ends in "v_m1"
		local folder datav/L/m1
		global variN "L_nresearn_1y_datav_m1"
	}
	else if substr("`1'", -4, 4) == "v_m2" { // if variable name ends in "v_m2"
		local folder datav/L/m2
		global variN "L_nresearn_1y_datav_m2"
	}
	else if substr("`1'", -4, 4) == "y_m1" { // if variable name ends in "y_m1"
		local folder complete/L/m1
		global variN "L_nresearn_1y_m1"
	} 
	else if substr("`1'", -4, 4) == "y_m2" { // if variable name ends in "y_m2"
		local folder complete/L/m2
		global variN "L_nresearn_1y_m2"
	}
	else {
		disp as error "USER ERROR: Cannot automatically define folder name!"
		error 1
	}
	
	* load data
	use "${FINAL_DIR}/${vari}", clear
	
	* selection
	keep if gender == `subsample'
	
	* create scaled and normalized variables
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75${vari} - p25${vari})
	foreach vv in p1${vari} p2_5${vari} p5${vari} p10${vari} p12_5${vari} p25${vari} ///
		p37_5${vari} p50${vari} p62_5${vari} p75${vari} p87_5${vari} p90${vari} p95${vari} ///
		p97_5${vari} p99${vari} p99_9${vari} p99_99${vari} ///
		mean_${vari} std_${vari} ///
		p9010${vari} p9050${vari} p5010${vari} ///
		skew_${vari} ksk${vari} kurt_${vari} cku${vari} {
		replace `vv' = 100*`vv'
		sum `vv' if year == ${year_norm}, meanonly
		gen n`vv' = `vv' - r(mean)
	}
	
	* Normalized plots
// 	local varilist np10${vari} np25${vari} np50${vari} np75${vari} np90${vari} np95${vari} np99${vari} // old by Roberta (before Oct 17, 2020)
// 	local varilist np5${vari} np10${vari} np25${vari} np50${vari} np75${vari} np90${vari} np95${vari} // new by Chris (after Oct 17, 2020)
	if $plot_rece_bars { // plot recession bars
		gen rece = inlist(year,${receyears})
		local rece_bars = "(bar rece year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5) yscale(off))"
		local rece_legend_entry = 1
	}
	else {
		local rece_bars = "" // do not plot recession bars
		local rece_legend_entry = 0
	}
	local varilist = ""
	local legend_str = `" "'
	local n_p = 1 + `rece_legend_entry'
	foreach p in $perc_list {
		local varilist = "`varilist' np`p'${vari}"
		local legend_str = `"`legend_str' `n_p' "P`p'" "'
		local ++n_p
	}
	local one_plus = 1 + `rece_legend_entry'
	local two_plus = 2 + `rece_legend_entry'
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Normalized percentiles of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_1N') , /// yaxis optins
	xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(4) symxsize(7.0) ring(0) position(11) ///
	order(`legend_str') ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Normalized percentiles of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig4_${variN}_`name_subsample'.pdf", replace
	
	local varilist np9010${vari} nstd_${vari}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_2N') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P10" `two_plus' "Std. dev.") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
	graph export "${FIG_DIR}/`folder'/fig5a_${variN}_`name_subsample'.pdf", replace 

	local varilist np9050${vari} np5010${vari}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_3N') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(1 "P90-P50" 2 "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
	graph export "${FIG_DIR}/`folder'/fig5b_${variN}_`name_subsample'.pdf", replace
	
	tw `rece_bars' (connected nskew_${vari} year, yaxis(2) yscale(alt axis(2)) ytitle("Norm. coefficient of skewness of `symbol'", axis(2)) ///
	lcolor(blue) lpattern(solid) msymbol(O T D) msize("`marksize'") mfcolor(blue*0.25) mlcolor(blue)) ///
	(connected nksk${vari} year, /// Plot
	lcolor(red) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25) ///	Fill color
	mlcolor(red) ///			Marker line color
	yaxis(1) yscale(alt axis(1)) ytitle("Norm. Kelley skewness of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_4') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "Coeff. of skewness" `two_plus' "Kelley skewness") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of skewness of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig6_${variN}_`name_subsample'.pdf", replace 
	
	tw `rece_bars' (connected ncku${vari} year, yaxis(2) yscale(alt axis(2)) ytitle("Norm. coefficient of kurtosis of `symbol'", axis(2)) ///
	lcolor(blue) lpattern(solid) msymbol(O T D) msize("`marksize'") mfcolor(blue*0.25) mlcolor(blue)) ///
	(connected nkurt_${vari} year, /// Plot
	lcolor(red) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25) ///	Fill color
	mlcolor(red) ///			Marker line color
	yaxis(1) yscale(alt axis(1)) ytitle("Norm. Crow-Siddiqui kurtosis of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_5') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "Coeff. of kurtosis" `two_plus' "Crow-Siddiqui kurtosis") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white)) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of kurtosis of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig7_${variN}_`name_subsample'.pdf", replace
	
	* Non-normalized plots
// 	local varilist p10${vari} p25${vari} p50${vari} p75${vari} p90${vari} p95${vari} p99${vari} // old by Roberta (before Oct 17, 2020)
// 	local varilist p5${vari} p10${vari} p25${vari} p50${vari} p75${vari} p90${vari} p95${vari} // new by Chris (after Oct 17, 2020)
	local varilist = ""
	local legend_str = `" "'
	local n_p = 1 + `rece_legend_entry'
	foreach p in $perc_list {
		local varilist = "`varilist' p`p'${vari}"
		local legend_str = `"`legend_str' `n_p' "P`p'" "'
		local ++n_p
	}
	local one_plus = 1 + `rece_legend_entry'
	local two_plus = 2 + `rece_legend_entry'
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Percentiles of `symbol'", axis(1) size(`ytitlesize')) `ylabel_1') , /// yaxis optins
	xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(4) symxsize(7.0) ring(0) position(11) ///
	order(`legend_str') ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Percentiles of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig4_${vari}_`name_subsample'.pdf", replace 
	
	local varilist p9010${vari} std_${vari}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Measures of dispersion of `symbol'", axis(1) size(`ytitlesize')) `ylabel_3') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P50" `two_plus' "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
	graph export "${FIG_DIR}/`folder'/fig5a_${vari}_`name_subsample'.pdf", replace
	
	local varilist p9050${vari} p5010${vari}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Measures of dispersion of `symbol'", axis(1) size(`ytitlesize')) `ylabel_3') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P50" `two_plus' "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of dispersion of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
	graph export "${FIG_DIR}/`folder'/fig5b_${vari}_`name_subsample'.pdf", replace
	
	tw `rece_bars' (connected skew_${vari} year, yaxis(2) yscale(alt axis(2)) ytitle("Coeff. of skewness of `symbol'", axis(2)) ///
	lcolor(blue) lpattern(solid) msymbol(O T D) msize("`marksize'") mfcolor(blue*0.25) mlcolor(blue)) ///
	(connected ksk${vari} year, /// Plot
	lcolor(red) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25) ///	Fill color
	mlcolor(red) ///			Marker line color
	yaxis(1) yscale(alt axis(1)) ytitle("Kelley skewness of `symbol'", axis(1) size(`ytitlesize')) `ylabel_4') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "Coeff. of skewness" `two_plus' "Kelley skewness") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of skewness of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig6_${vari}_`name_subsample'.pdf", replace 
	
	tw `rece_bars' (connected cku${vari} year, yaxis(2) yscale(alt axis(2)) ytitle("Coeff. of kurtosis of `symbol'", axis(2)) ///
	lcolor(blue) lpattern(solid) msymbol(O T D) msize("`marksize'") mfcolor(blue*0.25) mlcolor(blue)) ///
	(connected kurt_${vari} year, /// Plot
	lcolor(red) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25) ///	Fill color
	mlcolor(red) ///			Marker line color
	yaxis(1) yscale(alt axis(1)) ytitle("Crow-Siddiqui kurtosis of `symbol'", axis(1) size(`ytitlesize')) `ylabel_5') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "Coeff. of kurtosis" `two_plus' "Crow-Siddiqui kurtosis") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white)) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of kurtosis of `symbol'", color(black) size(`titlesize')) //subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig7_${vari}_`name_subsample'.pdf", replace 
	
end
	
	
********************************


cap program drop L_graphs_sector
program L_graphs_sector

	graph set window fontface "${fontface}"
	global marksize = "medium"
	local titlesize "vlarge"
	local ytitlesize = "medium" 
	local subtitlesize = "medium" 
		
	global vari = "`1'" 
	local subsample `2'
	local subtitle `3'
	local name_subsample "`4'"
	local sector `5'

	if substr("`1'", 1, 9) == "L_researn" {
		local symbol "{&Delta}{sup:1}{&epsilon}{sub:it}"
	}
	else {
		disp as error "USER ERROR: Cannot automatically define earnings symbol!"
		error 1
	}
	if substr("`1'", -4, 4) == "c_m1" {
		local folder complete/L/m1
		global variN "L_nresearn_1y_m1"
	} 
	else if substr("`1'", -4, 4) == "c_m2" {
		local folder complete/L/m2
		global variN "L_nresearn_1y_m2"
	}
	else {
		disp as error "USER ERROR: Cannot automatically define folder name!"
		error 1
	}
	
	* define axis labels
	if `6' == 1 {
		local ylabel_1 ylabel(`6'(`7')`8', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_1N ylabel(`9'(`10')`11', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_2 ylabel(`12'(`13')`14', axis(2) grid gstyle(dot) gmin gmax)
		local ylabel_2N ylabel(`15'(`16')`17', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3 ylabel(`18'(`19')`20', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3N ylabel(`21'(`22')`23', axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_4 ylabel(, axis(1) grid gstyle(dot) gmin gmax)			
		local ylabel_5 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
	}
	else if `6' == 0 { 
		local ylabel_1 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_1N ylabel(, axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_2 ylabel(,axis(2) grid gstyle(dot) gmin gmax)
		local ylabel_2N ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_3N ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_4 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
		local ylabel_5 ylabel(,axis(1) grid gstyle(dot) gmin gmax)
	}
	
	* load data
	use "${FINAL_DIR}/${vari}", clear
	
	* selection
	keep if gender == `subsample' & sec == `5'
	
	* create scaled and normalized variables
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75${vari} - p25${vari})
	foreach vv in p1${vari} p2_5${vari} p5${vari} p10${vari} p12_5${vari} p25${vari} ///
		p37_5${vari} p50${vari} p62_5${vari} p75${vari} p87_5${vari} p90${vari} p95${vari} ///
		p97_5${vari} p99${vari} p99_9${vari} p99_99${vari} ///
		mean_${vari} std_${vari} ///
		p9010${vari} p9050${vari} p5010${vari} ///
		skew_${vari} ksk${vari} kurt_${vari} cku${vari} {
		replace `vv' = 100*`vv'
		sum `vv' if year == ${year_norm}, meanonly
		gen n`vv' = `vv' - r(mean)
	}
	
	* Normalized plots
// 	local varilist np10${vari} np25${vari} np50${vari} np75${vari} np90${vari} np95${vari} np99${vari} // old by Roberta (before Oct 17, 2020)
// 	local varilist np5${vari} np10${vari} np25${vari} np50${vari} np75${vari} np90${vari} np95${vari} // new by Chris (after Oct 17, 2020)
	if $plot_rece_bars { // plot recession bars
		gen rece = inlist(year,${receyears})
		local rece_bars = "(bar rece year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5) yscale(off))"
		local rece_legend_entry = 1
	}
	else {
		local rece_bars = "" // do not plot recession bars
		local rece_legend_entry = 0
	}
	local varilist = ""
	local legend_str = `" "'
	local n_p = 1 + `rece_legend_entry'
	foreach p in $perc_list {
		local varilist = "`varilist' np`p'${vari}"
		local legend_str = `"`legend_str' `n_p' "P`p'" "'
		local ++n_p
	}
	local one_plus = 1 + `rece_legend_entry'
	local two_plus = 2 + `rece_legend_entry'
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Normalized percentiles of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_1N') , /// yaxis optins
	xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(4) symxsize(7.0) ring(0) position(11) ///
	order(`legend_str') ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Normalized percentiles of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig4_${variN}_`name_subsample'.pdf", replace
	
	local varilist np9010${vari} nstd_${vari}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_2N') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P10" `two_plus' "Std. dev.") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
	graph export "${FIG_DIR}/`folder'/fig5a_${variN}_`name_subsample'.pdf", replace 
	
	local varilist np9050${vari} np5010${vari}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Norm. measures of dispersion of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_3N') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(1 "P90-P50" 2 "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of dispersion of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
	graph export "${FIG_DIR}/`folder'/fig5b_${variN}_`name_subsample'.pdf", replace 
	
	tw `rece_bars' (connected nskew_${vari} year, yaxis(2) yscale(alt axis(2)) ytitle("Norm. coeff. of skewness of `symbol'", axis(2)) ///
	lcolor(blue) lpattern(longdash) msymbol(O T D) msize("`marksize'") mfcolor(blue*0.25) mlcolor(blue)) ///
	(connected nksk${vari} year, /// Plot
	lcolor(red) ///			Line color
	lpattern(solid) ///			Line pattern
	msymbol(O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25) ///	Fill color
	mlcolor(red) ///			Marker line color
	yaxis(1) yscale(alt axis(1)) ytitle("Normalized Kelley skewness of `symbol'", axis(1) size(`ytitlesize')) `ylabel_5') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "Coeff. of skewness" `two_plus' "Kelley skewness") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Normalized measures of skewness of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig6_${variN}_`name_subsample'.pdf", replace 
	
	tw `rece_bars' (connected ncku${vari} year, yaxis(2) yscale(alt axis(2)) ytitle("Norm. coefficient of kurtosis of `symbol'", axis(2)) ///
	lcolor(blue) lpattern(longdash) msymbol(O T D) msize("`marksize'") mfcolor(blue*0.25) mlcolor(blue)) ///
	(connected nkurt_${vari} year, /// Plot
	lcolor(red ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25) ///	Fill color
	mlcolor(red) ///			Marker line color
	yaxis(1) yscale(alt axis(1)) ytitle("Norm. Crow-Siddiqui kurtosis of `symbol' (${year_norm}=0)", axis(1) size(`ytitlesize')) `ylabel_6') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "Coeff. of kurtosis" `two_plus' "Crow-Siddiqui kurtosis") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white)) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Norm. measures of kurtosis of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig7_${variN}_`name_subsample'.pdf", replace 
	
	* Non-normalized plots
// 	local varilist p10${vari} p25${vari} p50${vari} p75${vari} p90${vari} p95${vari} p99${vari}
	local varilist = ""
	local legend_str = `" "'
	local n_p = 1 + `rece_legend_entry'
	foreach p in $perc_list {
		local varilist = "`varilist' p`p'${vari}"
		local legend_str = `"`legend_str' `n_p' "P`p'" "'
		local ++n_p
	}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Percentiles of `symbol'", axis(1) size(`ytitlesize')) `ylabel_1') , /// yaxis optins
	xtitle("",) xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(4) symxsize(7.0) ring(0) position(11) ///
	order(`legend_str') ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Percentiles of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig4_${vari}_`name_subsample'.pdf", replace 
	
	local varilist p9010${vari} std_${vari}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Measures of dispersion of `symbol'", axis(1) size(`ytitlesize')) `ylabel_2N') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P10" `two_plus' "Std. dev.") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of dispersion of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
	graph export "${FIG_DIR}/`folder'/fig5a_${vari}_`name_subsample'.pdf", replace
	
	local varilist p9050${vari} p5010${vari}
	tw `rece_bars' (connected `varilist' year, 				 /// Plot
	lcolor(red blue green maroon navy forest_green navy magenta orange) ///			Line color
	lpattern(solid longdash dash solid longdash dash solid longdash dash) ///			Line pattern
	msymbol(O T D O T D O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25 navy*0.25 forest_green*0.25 navy*0.25 magenta*0.25 orange*0.25) ///	Fill color
	mlcolor(red blue green maroon navy forest_green navy magenta orange) ///			Marker line color
	yaxis(1) ytitle("Dispersion of `symbol'", axis(1) size(`ytitlesize')) `ylabel_3') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(1) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "P90-P50" `two_plus' "P50-P10") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Dispersion of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
	graph export "${FIG_DIR}/`folder'/fig5b_${vari}_`name_subsample'.pdf", replace
	
	tw `rece_bars' (connected skew_${vari} year, yaxis(2) yscale(alt axis(2)) ytitle("Coeff. of skewness of `symbol'", axis(2)) ///
	lcolor(blue) lpattern(longdash) msymbol(O T D) msize("`marksize'") mfcolor(blue*0.25) mlcolor(blue)) ///
	(connected ksk${vari} year, /// Plot
	lcolor(red) ///			Line color
	lpattern(solid) ///			Line pattern
	msymbol(O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25) ///	Fill color
	mlcolor(red) ///			Marker line color
	yaxis(1) yscale(alt axis(1)) ytitle("Kelley skewness of `symbol'", axis(1) size(`ytitlesize')) `ylabel_5') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "Coeff. of skewness" `two_plus' "Kelley skewness") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white) ) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of skewness of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig6_${vari}_`name_subsample'.pdf", replace 
	
	tw `rece_bars' (connected cku${vari} year, yaxis(2) yscale(alt axis(2)) ytitle("Coeff. of kurtosis of `symbol'", axis(2)) ///
	lcolor(blue) lpattern(longdash) msymbol(O T D) msize("`marksize'") mfcolor(blue*0.25) mlcolor(blue)) ///
	(connected kurt_${vari} year, /// Plot
	lcolor(red ) ///			Line color
	lpattern(solid longdash dash) ///			Line pattern
	msymbol(O T D)		/// Marker
	msize("`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" "`marksize'" )		/// Marker size
	mfcolor(red*0.25) ///	Fill color
	mlcolor(red) ///			Marker line color
	yaxis(1) yscale(alt axis(1)) ytitle("Crow-Siddiqui kurtosis of `symbol'", axis(1) size(`ytitlesize')) `ylabel_6') , /// yaxis optins
	xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
	legend(col(2) symxsize(7.0) ring(0) position(11) ///
	order(`one_plus' "Coeff. of kurtosis" `two_plus' "Crow-Siddiqui kurtosis") ///
	region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
	graphregion(color(white)) ///				Graph region define
	plotregion(lcolor(black)) ///				Plot regione define
	title("Measures of kurtosis of `symbol'", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize')) // Title and subtitle
	graph export "${FIG_DIR}/`folder'/fig7_${vari}_`name_subsample'.pdf", replace
	
end	
	
	
********************************
	
	
// 	cap program drop Sector_obs
// 	program Sector_obs
	
// 		graph set window fontface "${fontface}"
// 		global marksize = "medium"
// 		local titlesize "vlarge"
// 		local ytitlesize = "medium" 
// 		local subtitlesize = "medium" 
		
// 		local subtitle all
		
// 		local folder = "XXX TBC!"
		
// 		use "${FINAL_DIR}/stats/composition_CS.dta", clear
		
// 		if $plot_rece_bars { // plot recession bars
// 		gen rece = inlist(year,${receyears})
// 			local rece_bars = "(bar rece year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5) yscale(off))"
// 			local rece_legend_entry = 1
// 		}
// 		else {
// 			local rece_bars = "" // do not plot recession bars
// 			local rece_legend_entry = 0
// 		}
// 		local one_plus = 1 + `rece_legend_entry'
// 		local two_plus = 2 + `rece_legend_entry'
// 		local three_plus = 3 + `rece_legend_entry'
// 		local four_plus = 4 + `rece_legend_entry'
// 		tw `rece_bars' (connected share_1 share_2 year, 				 /// Plot
// 		lcolor(red blue) ///			Line color
// 		lpattern(solid solid solid solid) ///			Line pattern
// 		msymbol(O T D O T D O T D)		/// Marker
// 		msize("`marksize'" "`marksize'" "`marksize'" "`marksize'")		/// Marker size
// 		mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) ///	Fill color
// 		mlcolor(red blue green maroon) ///			Marker line color
// 		yaxis(1) ylabel(0(.2)1, grid gstyle(dot)gmin gmax)), /// yaxis optins
// 		xtitle("") xlabel(${year_min}(2)${year_max}, grid gstyle(dot) gmin gmax) ///		xaxis options
// 		legend(col(1) symxsize(7.0) ring(0) position(11) ///
// 		order(`one_plus' "Formal" `two_plus' "Informal") ///
// 		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
// 		graphregion(color(white)) ///				Graph region define
// 		plotregion(lcolor(black)) ///				Plot regione define
// 		title("Composition of employment, by sector", color(black) size(`titlesize')) subtitle("Sample: `subtitle'", color(black) size(`subtitlesize'))
// 		graph export "${FIG_DIR}/`folder'/fig0_composition_CS.pdf", replace
		
// 		use "${FINAL_DIR}/stats/composition_L.dta", clear
		
// 		local symbol "{&Delta}{sup:1}{&epsilon}{sub:it}"
		
// 		tw `rece_bars' (connected share_1 share_2 share_5 share_6 year, 				 /// Plot
// 		lcolor(red blue green maroon) ///			Line color
// 		lpattern(solid solid solid solid) ///			Line pattern
// 		msymbol(O T D O T D O T D)		/// Marker
// 		msize("`marksize'" "`marksize'" "`marksize'" "`marksize'")		/// Marker size
// 		mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) ///	Fill color
// 		mlcolor(red blue green maroon) ///			Marker line color
// 		yaxis(1) ylabel(0(.2)1, grid gstyle(dot) gmin gmax)) , /// yaxis optins
// 		xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
// 		legend(col(2) symxsize(7.0) ring(0) position(11) ///
// 		order(`one_plus' "Formal-Formal" `two_plus' "Informal-Informal" `three_plus' "Formal-Informal" `four_plus' "Informal-Formal") ///
// 		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
// 		graphregion(color(white) ) ///				Graph region define
// 		plotregion(lcolor(black)) ///				Plot regione define
// 		title("Composition of employment transitions, by sector", color(black) size(`titlesize')) subtitle("Sample: `subtitle', 1-year-forward change", color(black) size(`subtitlesize'))
// 		graph export "${FIG_DIR}/`folder'/fig0_composition_L.pdf", replace

// 		tw `rece_bars' (connected share_5 share_6 year, ///
// 		lcolor(green maroon) lpattern(solid solid) ///
// 		msymbol(D O) msize("`marksize'" "`marksize'") mfcolor(green*0.25 maroon*0.25) ///
// 		mlcolor(green maroon) yaxis(2) yscale(alt axis(2)) ylabel(0(0.02)0.06, axis(2) grid gstyle(dot) gmin gmax)) ///
// 		(connected share_1 share_2 year, 				 /// Plot
// 		lcolor(red blue) ///			Line color
// 		lpattern(solid solid) ///			Line pattern
// 		msymbol(O T)		/// Marker
// 		msize("`marksize'" "`marksize'")		/// Marker size
// 		mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) ///	Fill color
// 		mlcolor(red blue green maroon) ///			Marker line color
// 		yaxis(1) yscale(alt axis(1)) ylabel(0(0.2)1, axis(1) grid gstyle(dot) gmin gmax)), /// yaxis optins
// 		xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
// 		legend(col(2) symxsize(7.0) ring(0) position(11) ///
// 		order(3 "Formal-Formal (lhs)" 4 "Informal-Informal (lhs)" 1 "Formal-Informal (rhs)" 2 "Informal-Formal (rhs)") ///
// 		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
// 		graphregion(color(white) ) ///				Graph region define
// 		plotregion(lcolor(black)) ///				Plot regione define
// 		title("Composition of employment transitions, by sector", color(black) size(`titlesize')) subtitle("Sample: `subtitle', 1-year-forward change", color(black) size(`subtitlesize'))
// 		graph export "${FIG_DIR}/`folder'/fig0_composition_L_altaxis.pdf", replace
		
// 		tw `rece_bars' (connected share_1 share_2 year, 				 /// Plot
// 		lcolor(red blue green maroon) ///			Line color
// 		lpattern(solid solid solid solid) ///			Line pattern
// 		msymbol(O T D O T D O T D)		/// Marker
// 		msize("`marksize'" "`marksize'" "`marksize'" "`marksize'")		/// Marker size
// 		mfcolor(red*0.25 blue*0.25 green*0.25 maroon*0.25) ///	Fill color
// 		mlcolor(red blue green maroon) ///			Marker line color
// 		yaxis(1) ylabel(0(.2)1, grid gstyle(dot) gmin gmax)), /// yaxis optins
// 		xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
// 		legend(col(2) symxsize(7.0) ring(0) position(11) ///
// 		order(`one_plus' "Formal-Formal" `two_plus' "Informal-Informal") ///
// 		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
// 		graphregion(color(white) ) ///				Graph region define
// 		plotregion(lcolor(black)) ///				Plot regione define
// 		title("Composition of employment transitions, by sector", color(black) size(`titlesize')) subtitle("Sample: `subtitle', 1-year-forward change", color(black) size(`subtitlesize'))
// 		graph export "${FIG_DIR}/`folder'/fig0_composition_L_part1.pdf", replace
		
// 		tw `rece_bars' (connected share_5 share_6 year, 				 /// Plot
// 		lcolor(green maroon) ///			Line color
// 		lpattern(solid solid) ///			Line pattern
// 		msymbol(D O T D O T D)		/// Marker
// 		msize("`marksize'" "`marksize'" "`marksize'" "`marksize'")		/// Marker size
// 		mfcolor(green*0.25 maroon*0.25) ///	Fill color
// 		mlcolor(green maroon) ///			Marker line color
// 		yaxis(1) ylabel(0(0.02)0.06, grid gstyle(dot) gmin gmax)), /// yaxis optins
// 		xtitle("") xlabel(${year_min}(2)${year_max},grid gstyle(dot) gmin gmax) ///		xaxis options
// 		legend(col(2) symxsize(7.0) ring(0) position(11) ///
// 		order(`one_plus' "Formal-Informal" `two_plus' "Informal-Formal") ///
// 		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
// 		graphregion(color(white)) ///				Graph region define
// 		plotregion(lcolor(black)) ///				Plot regione define
// 		title("Composition of employment transitions, by sector", color(black) size(`titlesize')) subtitle("Sample: `subtitle', 1-year-forward change", color(black) size(`subtitlesize'))
// 		graph export "${FIG_DIR}/`folder'/fig0_composition_L_part2.pdf", replace
		
// 	end	
