********************************************************************************
* DESCRIPTION: Creates programs that compute statistics.
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

	
********************************************************************************
******* I. Program that create variable to identify individual-year obs type ***
********************************************************************************
	
	cap program drop create_season_group
	program create_season_group
	
		sort id_year quarter
		by id_year: gen first_quarter = quarter[1] 
		by id_year: gen second_quarter = quarter[2]
		gen season_group = 0
		replace season_group = 1 if first_quarter == 1 & second_quarter == 2
		replace season_group = 2 if first_quarter == 2 & second_quarter == 3
		replace season_group = 3 if first_quarter == 3 & second_quarter == 4
		replace season_group = 4 if first_quarter == 2 & second_quarter == 4
		replace season_group = 5 if first_quarter == 1 & second_quarter == 4
		replace season_group = 6 if first_quarter == 1 & second_quarter == .
		replace season_group = 7 if first_quarter == 2 & second_quarter == .
		replace season_group = 8 if first_quarter == 3 & second_quarter == .
		replace season_group = 9 if first_quarter == 4 & second_quarter == .
		label var season_group "1 q1,q2; 2 q2,q3; 3 q3,q4; 4 q2,q4; 5 q1,q4; 6 q1,.; 7 q2,.; 8 q3,.; 9 q4,."
	
	end
	
	
********************************************************************************
******* II. Program that creates main stats for each variable ******************
********************************************************************************
	
	cap program drop mystats
	program mystats
		cd "${FINAL_DIR}"
			preserve
			local varM "`1'"
			
			qui summarize data, meanonly
			scalar mean_data = r(mean)
				
				// Argentina, each year
				if mean_data == 1 {
				local by_1 `" "gender year" "'
				local by_2 year
				local save_file `varM'
				}
				
				// By Sectors, each year
				else if mean_data == 2 {
				local by_1 `" "gender year sec" "'
				local by_2 `" "year sec" "'
				local save_file `varM'
				}
			
			global statlist ="mean_`varM'=r(mean) std_`varM'=r(sd) skew_`varM'=r(skewness) kurt_`varM'=r(kurtosis)" 
			qui statsby $statlist, by(`by_1') saving(`varM'_meanstd,replace): ///
			summarize `varM' [aw=weight], detail 
			
			clear
			restore
			preserve
				
			global statlist ="mean_`varM'=r(mean) std_`varM'=r(sd) skew_`varM'=r(skewness) kurt_`varM'=r(kurtosis)" 
			qui statsby $statlist, by(`by_2') saving(`varM'_all_meanstd,replace): ///
			summarize `varM' [aw=weight], detail  
		
			use `varM'_all_meanstd.dta, clear
			gen gender = .
			append using `varM'_meanstd.dta
			
			save `varM'_meanstd.dta, replace
			
			clear
			restore
			preserve
			
			global statlist1 ="p1`varM'=r(r1) p2_5`varM'=r(r2) p5`varM'=r(r3) p10`varM'=r(r4) p12_5`varM'=r(r5)"
			global statlist2 ="p25`varM'=r(r6) p37_5`varM'=r(r7) p50`varM'=r(r8) p62_5`varM'=r(r9)"
			global statlist3 ="p75`varM'=r(r10) p87_5`varM'=r(r11) p90`varM'=r(r12) p95`varM'=r(r13)" 
			global statlist4 ="p97_5`varM'=r(r14) p99`varM'=r(r15) p99_9`varM'=r(r16) p99_99`varM'=r(r17)" 
			qui statsby $statlist1 $statlist2 $statlist3 $statlist4, by(`by_1') saving(`save_file',replace): ///
			_pctile `varM' [aw=weight],p(1,2.5,5,10,12.5,25,37.5,50,62.5,75,87.5,90,95,97.5,99,99.9,99.99) 
			
			clear
			restore
			preserve
			
			global statlist1 ="p1`varM'=r(r1) p2_5`varM'=r(r2) p5`varM'=r(r3) p10`varM'=r(r4) p12_5`varM'=r(r5)"
			global statlist2 ="p25`varM'=r(r6) p37_5`varM'=r(r7) p50`varM'=r(r8) p62_5`varM'=r(r9)"
			global statlist3 ="p75`varM'=r(r10) p87_5`varM'=r(r11) p90`varM'=r(r12) p95`varM'=r(r13)" 
			global statlist4 ="p97_5`varM'=r(r14) p99`varM'=r(r15) p99_9`varM'=r(r16) p99_99`varM'=r(r17)" 
			qui statsby $statlist1 $statlist2 $statlist3 $statlist4, by(`by_2') saving(`varM'_all,replace): ///
			_pctile `varM' [aw=weight],p(1,2.5,5,10,12.5,25,37.5,50,62.5,75,87.5,90,95,97.5,99,99.9,99.99) 
			
			use `varM'_all.dta, clear
			gen gender = .
			append using `save_file'.dta
			
			merge m:m gender year using `varM'_meanstd.dta
			drop _merge
			order gender year
			
			save `save_file'.dta, replace
			erase `varM'_all.dta
			erase `varM'_meanstd.dta
			erase `varM'_all_meanstd.dta
	
			restore 
	end
	
	
********************************************************************************
******* III. Programs for number of observations compilation *******************
********************************************************************************	
	
	cap program drop obs_analysis
	program obs_analysis
		
		preserve
		
		qui summarize analysis_type, meanonly
		scalar mean_analysis = r(mean)
		
		qui summarize method, meanonly
		scalar mean_method = r(mean)
		
		if mean_method == 1 {
			
			if mean_analysis == 1 {
				collapse (mean) obs_*, by (year quarter)	
				tsset quarter year
				tsfill, full
				sort year quarter
				reshape wide obs_*, i(year) j(quarter)
				order year obs_1* obs_2* obs_3*
				save "${FINAL_DIR}/obs/datav_CS_m1.dta", replace
			}
			
			if mean_analysis == 2 {
				collapse (mean) obs_*, by (year quarter sec)
				egen id_quarter_sec = group(quarter sec)
				tsset id_quarter_sec year
				tsfill, full
				replace quarter = 1 if id_quarter_sec == 1 |  id_quarter_sec == 2 
				replace quarter = 2 if id_quarter_sec == 3 |  id_quarter_sec == 4 
				replace quarter = 3 if id_quarter_sec == 5 |  id_quarter_sec == 6 
				replace quarter = 4 if id_quarter_sec == 7 |  id_quarter_sec == 8 
				replace sec = 1 if id_quarter_sec == 1 | id_quarter_sec == 3 | id_quarter_sec == 5 | id_quarter_sec == 7 
				replace sec = 2 if id_quarter_sec == 2 | id_quarter_sec == 4 | id_quarter_sec == 6 | id_quarter_sec == 8 
				sort year quarter sec
				tostring(year), replace
				tostring(sec), replace
				gen underline = "_"
				egen year_sec = concat(year underline sec)
				drop underline
				collapse (mean) obs_*, by (year_sec quarter)
				reshape wide obs_*, i(year_sec) j(quarter)
				order year_sec obs_1* obs_2* obs_3*
				save "${FINAL_DIR}/obs/complete_CS_m1.dta", replace
			}
		
		}
		
		if mean_method == 2 {
			
			if mean_analysis == 1 {
				collapse (mean) obs_*, by (year season_group)
				tsset season_group year
				tsfill, full
				sort year season_group
				reshape wide obs_*, i(year) j(season_group)
				order year obs_1* obs_2* obs_3*
				save "${FINAL_DIR}/obs/datav_CS_m2", replace
			}
		}	
			
			restore
		
	end
	
	
	cap program drop L_obs_analysis
	program L_obs_analysis
		
		preserve
		
		qui summarize method, meanonly
		scalar mean_method = r(mean)
		
		if mean_method == 1 {
			
			capture confirm variable L_researn_1y
			
			if _rc != 0 { 
				collapse (mean) obs_*, by (year quarter)	
				tsset quarter year
				tsfill, full
				sort year quarter
				reshape wide obs_*, i(year) j(quarter)
				order year obs_1* obs_2* obs_3*
				save "${FINAL_DIR}/obs/datav_L_m1.dta", replace
			}
			else {
				collapse (mean) obs_4, by (year)
				save "${FINAL_DIR}/obs/datav_L_m1_temp.dta", replace
				use "${FINAL_DIR}/obs/datav_L_m1.dta", clear
				merge m:m year using "${FINAL_DIR}/obs/datav_L_m1_temp.dta", keep(master match) nogen
				save "${FINAL_DIR}/obs/datav_L_m1.dta", replace
			}
			
		}
		
		if mean_method == 2 {
			
			capture confirm variable L_researn_1y
			
			if _rc != 0 { 
				rename season_group sg_obs
				keep year obs_* sg_*
				collapse (mean) obs_*, by (year sg_*)
				
				save "${FINAL_DIR}/obs/datav_L_m2_temp.dta", replace
				
				forval i = 1/2 {
					use "${FINAL_DIR}/obs/datav_L_m2_temp.dta", clear
					keep year obs_`i' sg_obs_`i'
					collapse (mean) obs, by (year sg)
					tsset sg year
					tsfill, full
					sort year sg
					reshape wide obs_*, i(year) j(sg)
					save "${FINAL_DIR}/obs/datav_L_m2_temp_`i'.dta", replace
				}
				
				use "${FINAL_DIR}/obs/datav_L_m2_temp.dta", clear
				keep year obs_3 obs_4 sg_obs
				collapse (mean) obs_*, by (year sg)
				tsset sg year
				tsfill, full
				sort year sg
				reshape wide obs_*, i(year) j(sg)
				order year obs_3* obs_4*
				merge m:m year using "${FINAL_DIR}/obs/datav_L_m2_temp_1.dta", keep(master match) nogen
				merge m:m year using "${FINAL_DIR}/obs/datav_L_m2_temp_2.dta", keep(master match) nogen
				order year obs_1* obs_2*
				save "${FINAL_DIR}/obs/datav_L_m2", replace
			}
			else {
				
				collapse (mean) obs_5, by (year)
				save "${FINAL_DIR}/obs/datav_L_m2_temp_5.dta", replace
				use "${FINAL_DIR}/obs/datav_L_m2.dta", clear
				merge m:m year using "${FINAL_DIR}/obs/datav_L_m2_temp_5.dta", keep(master match) nogen
				save "${FINAL_DIR}/obs/datav_L_m2.dta", replace
			
			}
		}	
			restore
		
	end
	
	
********************************************************************************
******* IV. Programs for density figures ***************************************
********************************************************************************	
	
	cap program drop kdensity_fig
	program kdensity_fig
		global fontface = "Times New Roman"
		graph set window fontface "${fontface}"
		local titlesize "vlarge"
		local subtitlesize "medium" 	
		
		local varM "`1'"
		local year `2'
		local symbol "`3'"
	
		kdensity `varM' if year == `year' & sec == 1 [aw=weight], ///
		lcolor(red) ///
		lpattern(solid) ///
		legend(col(2) symxsize(7.0) ring(0) position(11) ///
		order(1 "Formal" 2 "Informal") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(, grid gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of `symbol': `year'", color(black) size(`titlesize')) ///
		subtitle("Subsample: all", size (`subtitlesize')) ///
		addplot(kdensity `varM' if year == `year' & sec == 2 [aw=weight], ///
		lcolor(blue) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/complete/densities/fig0_density_`varM'_`year'.pdf", replace 		
	end
	
	cap program drop kdensity_fig_2
	program kdensity_fig_2
		global fontface = "Times New Roman"
		graph set window fontface "${fontface}"
		local titlesize "vlarge"
		local subtitlesize "medium" 	
		
		local varM "`1'"
		local year `2'
		local symbol "`3'"
		local year2 `4'
		
		qui summarize data, meanonly
		scalar mean_data = r(mean)
		
		if substr("`1'", -4, 4) == "v_m1" {
		local folder datav
		local subsample formal	
		}
		else if substr("`1'", -4, 4) == "v_m2" {
		local folder datav
		local subsample formal	
		}
		else if substr("`1'", -6, 3) == "sec" {
			preserve
			keep if sec == `5'
		local folder complete
			if `5' == 1 {
			local subsample formal	
			local namefolder formal
			}
			else if `5' == 2 {
			local subsample informal
			local namefolder informal
			}
		}
		else {
		local folder complete
		local subsample all
		}
		
		kdensity `varM' if year == `year' [aw=weight], ///
		lcolor(red) ///
		lpattern(solid) ///
		legend(col(2) symxsize(7.0) ring(0) position(11) ///
		order(1 "`year'" 2 "`year2'") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(, grid gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of `symbol'", color(black) size(`titlesize')) ///
		subtitle("Subsample: `subsample'", size (`subtitlesize')) ///
		addplot(kdensity `varM' if year == `year2' [aw=weight], ///
		lcolor(blue) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/`folder'/densities/fig0_density_`varM'_`year'`year2'`namefolder'.pdf", replace 		
	
		 if substr("`1'", -6, 3) == "sec" {
		 restore
		 }
		
	end
	
	
	cap program drop L_kdensity_sec_fig
	program L_kdensity_sec_fig
		global fontface = "Times New Roman"
		graph set window fontface "${fontface}"
		local titlesize "vlarge"
		local subtitlesize "medium" 	
		
		local varM "`1'"
		local year `2'
		local year2 `3'
		
		local folder complete
		
		kdensity `varM' if sec == 1 & year == `year' [aw=weight], ///
		lcolor(red) ///
		lpattern(solid) ///
		legend(col(1) symxsize(7.0) ring(0) position(11) ///
		order(1 "Formal-Formal" 2 "Informal-Informal" 3 "Formal-Informal" 4 "Informal-Formal") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(,axis(1) gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of {&Delta}{sup:1}{&epsilon}{sub:it}: `year'", color(black) size(`titlesize')) ///
		subtitle("Sample: all", size (`subtitlesize')) ///
		addplot(kdensity `varM' if sec == 2 & year == `year' [aw=weight], ///
		lcolor(blue) lpattern(solid) ///
		|| kdensity `varM' if sec == 5 & year == `year' [aw=weight], ///
		lcolor(green) lpattern(solid) ///
		|| kdensity `varM' if sec == 6 & year == `year' [aw=weight], ///
		lcolor(maroon) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/`folder'/densities/fig0_density_`varM'`year'.pdf", replace 
		
		kdensity `varM' if sec == 5 & year == `year' [aw=weight], ///
		lcolor(green) ///
		lpattern(solid) ///
		legend(col(1) symxsize(7.0) ring(0) position(11) ///
		order(1 "Formal-Informal" 2 "Informal-Formal") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(,axis(1) gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of {&Delta}{sup:1}{&epsilon}{sub:it}: `year'", color(black) size(`titlesize')) ///
		subtitle("Sample: all", size (`subtitlesize')) ///
		addplot(kdensity `varM' if sec == 6 & year == `year' [aw=weight], lcolor(maroon) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/`folder'/densities/fig0_density_`varM'`year'_switchers.pdf", replace 
		
		// years pooled
		local year_max_m1 = ${year_max} - 1
		kdensity `varM' if sec == 1 [aw=weight], ///
		lcolor(red) ///
		lpattern(solid) ///
		legend(col(1) symxsize(7.0) ring(0) position(11) ///
		order(1 "Formal-Formal" 2 "Informal-Informal" 3 "Formal-Informal" 4 "Informal-Formal") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(,axis(1) gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of {&Delta}{sup:1}{&epsilon}{sub:it}: all years (${year_min}-`year_max_m1')", color(black) size(`titlesize')) ///
		subtitle("Sample: all", size (`subtitlesize')) ///
		addplot(kdensity `varM' if sec == 2 [aw=weight], lcolor(blue) lpattern(solid) ///
		|| kdensity `varM' if sec == 5 [aw=weight], lcolor(green) lpattern(solid) ///
		|| kdensity `varM' if sec == 6 [aw=weight], lcolor(maroon) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/`folder'/densities/fig0_density_`varM'.pdf", replace
	
	end
	
	cap program drop L_kdensity_sec_fig_2
	program L_kdensity_sec_fig_2
		
		global fontface = "Times New Roman"
		graph set window fontface "${fontface}"
		local titlesize "vlarge"
		local subtitlesize "medium" 	
		
		local varM "`1'"
		local year `2'
		local year2 `3'
		
		local folder complete
		
		** Graph each sector separated 
		
		kdensity `varM' if sec == 1 & year == `year' [aw=weight], ///
		lcolor(red) ///
		lpattern(solid) ///
		legend(col(1) symxsize(7.0) ring(0) position(11) ///
		order(1 "`year'" 2 "`year2'") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(0(.6)1.8,axis(1) gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of {&Delta}{sup:1}{&epsilon}{sub:it}", color(black) size(`titlesize')) ///
		subtitle("Sample: formal-formal", size (`subtitlesize')) ///
		addplot(kdensity `varM' if sec == 1 & year == `year2' [aw=weight], ///
		lcolor(blue) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/`folder'/densities/fig0_density_`varM'`year'`year2'FF.pdf", replace 	
		
		kdensity `varM' if sec == 2 & year == `year' [aw=weight], ///
		lcolor(red) ///
		lpattern(solid) ///
		legend(col(1) symxsize(7.0) ring(0) position(11) ///
		order(1 "`year'" 2 "`year2'") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(0(.6)1.8,axis(1) gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of {&Delta}{sup:1}{&epsilon}{sub:it}", color(black) size(`titlesize')) ///
		subtitle("Sample: informal-informal", size (`subtitlesize')) ///
		addplot(kdensity `varM' if sec == 2 & year == `year2' [aw=weight], ///
		lcolor(blue) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/`folder'/densities/fig0_density_`varM'`year'`year2'II.pdf", replace 	
		
		kdensity `varM' if sec == 5 & year == `year' [aw=weight], ///
		lcolor(red) ///
		lpattern(solid) ///
		legend(col(1) symxsize(7.0) ring(0) position(11) ///
		order(1 "`year'" 2 "`year2'") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(0(.6)1.8,axis(1) gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of {&Delta}{sup:1}{&epsilon}{sub:it}", color(black) size(`titlesize')) ///
		subtitle("Sample: formal-informal", size (`subtitlesize')) ///
		addplot(kdensity `varM' if sec == 5 & year == `year2' [aw=weight], ///
		lcolor(blue) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/`folder'/densities/fig0_density_`varM'`year'`year2'FI.pdf", replace 	
		
		kdensity `varM' if sec == 6 & year == `year' [aw=weight], ///
		lcolor(red) ///
		lpattern(solid) ///
		legend(col(1) symxsize(7.0) ring(0) position(11) ///
		order(1 "`year'" 2 "`year2'") ///
		region(lcolor(none) fcolor(none))) graphregion(color(white)) /// Legend options 
		graphregion(color(white)) ///				Graph region define
		plotregion(lcolor(black))  ///				Plot regione define
		yaxis(1) ylabel(0(.6)1.8,axis(1) gstyle(dot) gmin gmax) /// yaxis optins
		xtitle("") xlabel(, grid gstyle(dot) gmin gmax) ///
		title("Density of {&Delta}{sup:1}{&epsilon}{sub:it}", color(black) size(`titlesize')) ///
		subtitle("Sample: informal-formal", size (`subtitlesize')) ///
		addplot(kdensity `varM' if sec == 6 & year == `year2' [aw=weight], ///
		lcolor(blue) lpattern(solid)) 
		cap noisily: graph export "${FIG_DIR}/`folder'/densities/fig0_density_`varM'`year'`year2'IF.pdf", replace 	
		
	end
	

	
