********************************************************************************
* DESCRIPTION: Computes summary statistics of wage changes
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

********************
*Housekeeping
********************
clear
set more off
set scheme s2color

*Dataset to use
global dataset = "RSample"

* Add here your path to the random sample folder
global pathinit ""

* Fixed the seed for random variables
set seed 92

********************************************************************************
*** Parameters
********************************************************************************

* Steven filter parameters
global st_L   = 6             // number of sample to apply algorithm

global st_Ka  = 0.4168          // K param for sector a or 1

********************
*Paths and Logs
********************

*Folder with filters
global pathfilter = "$pathinit/do/FiltersRegular"

*Figures folder
global intput = "$pathinit/output/002_output"

*Output folder
global output = "$pathinit/output/003_output"

*temporary folder folder
global temp      = "$pathinit/temp"

global sample = ""


if "$dataset" == "RSample"{

    global name          = "GID_RSample_"

}

********************************************************************************
***************  Save the log file       ***************************************
********************************************************************************

capture log close
log using "$temp/${name}_Freq_Agg_ST_b_ParaK${st_Ka}.txt", replace text

********************************************************************************
***************  Step 1 of cleaning                           **************
********************************************************************************

global st_Ka=$st_Ka*100

forvalues dec = 1(1)10 {

	import delimited "$temp/${name}Data_KS_test_K${st_Ka}_L${st_L}_w_r_`dec'.csv", encoding(Big5) clear
	rename v1  new_id
	rename v2  w_r
	rename v3  date
	drop v4
	format date %tm
	save "$temp/${name}Data_KS_test_K${st_Ka}_L${st_L}_w_r_`dec'.dta", replace

}

use "$temp/${name}Data_KS_test_K${st_Ka}_L${st_L}_w_r_1.dta", clear

forvalues dec = 2(1)10 {

	qui append using "$temp/${name}Data_KS_test_K${st_Ka}_L${st_L}_w_r_`dec'.dta"

}

label var w_r               "regular wage"

compress
save "$output/${name}KS_test_K${st_Ka}_L${st_L}_w_r.dta", replace
