********************************************************************************
* DESCRIPTION: This code produces all the figures in part B
*
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************

* add here your path to the project
global pathinit ""

global path_results "$pathinit/Part_B/RandomSample/results/paths"
global freq_results "$pathinit/Part_B/RandomSample/results/frequency_stat"
global wach_results "$pathinit/Part_B/RandomSample/results/wage_change_stat"
global path_figures "$pathinit/Part_B/RandomSample/figures"
global nim_wage     "$pathinit/Part_B/RandomSample/input"
global esti_wage    "$pathinit/Part_B/RandomSample/results/estimation"
global temp       = "$pathinit/Part_B/RandomSample/temp"
global input_data   "$pathinit/Part_B/RandomSample/input"

* add here the name with the options
global file_name "GID_RSample_KS_test_K41.68_L6_w_r"

* Option in the figure

global xlabsize =     "large"
global ylabsize =     "large"
global legesize =     "large"
global xtitlesize =   "large"
global ytitlesize =   "large"
global titlesize  =   "large"

*****************

import delimited "$path_results/${file_name}.csv", encoding(ISO-8859-1) clear

rename v1 worker_id
rename v2 firm_id
rename v3 new_id
rename v4 date
rename v5 lwr
rename v6 lw

gen date2 = monthly(date,"YM")
format date2 %tm
drop date
rename date2 date

merge m:1 date using "$nim_wage/MW.dta", keepusing(MW)
drop _merge

gen l_minw =ln(MW/2)

gsort worker_id date
order worker_id date

replace lw=6.5 if   lw<l_minw

local ylimlo = 6.5
local ylimup = 7
local ylimdf = 7.4

tw (connected lw    date if worker_id==10000841, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr  date if worker_id==10000841, msymbol(t)  color(  blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"   540 "2005" , labsize(${xlabsize}) grid) ///
ylabel( 6.6 "6.6" 6.8 "6.8" 7 "7"  7.2 "7.2"   7.4 "7.4" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Log of Regular Wage" ) size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW1.pdf", replace


tw (connected lw    date if worker_id==10029740, msymbol(o  )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr  date if worker_id==10029740, msymbol(t)  color(  blue) lpattern(  dash ) lwidth(  thick )), ///
 xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"    , labsize(${xlabsize}) grid) ///
ylabel( 5.5 "5.5" 6 "6" 6.5 "6.5" 7 "7" 7.5 "7.5"  8 "8" 8.5 "8.5" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(off) ///
xline(458.5, lcolor(black) lpattern(dash)) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW2.pdf", replace


gen diff=0 if lwr~=lw
replace diff=1 if abs(lwr-lw)<0.001
sum diff if new_id==380 & worker_id==10029740


********************************************************************************
***************  Model simulated regular and total wage                 ********
********************************************************************************

import delimited "$esti_wage/simulated_data.cvs", encoding(ISO-8859-1) clear

rename v1 worker_id
rename v2 new_id
rename v3 date
rename v4 lwr_t
rename v5 lwr_b
rename v6 lwt
rename v7 lw
rename v8 break_t
rename v9 break_s


gen date2 = date+431
format date2 %tm
drop date
rename date2 date

gsort worker_id date

tw (connected   lw   date if worker_id==10021000 & new_id==22, msymbol(o)  color(red) lpattern(  dash ) lwidth(  medium )) ///
   (connected   lw   date if worker_id==10021000 & new_id==23, msymbol(o)  color(red) lpattern(  dash ) lwidth(  medium )) ///
   (scatter   lwr_b  date if worker_id==10021000, msymbol(t)  color(  blue) lpattern(  dash ) lwidth(  thick ))   ///
   (connected lwr_t  date if worker_id==10021000 & new_id==22, msymbol(none  )  color(green  ) lpattern(solid   ) lwidth(medium   ))  ///
   (connected lwr_t  date if worker_id==10021000 & new_id==23, msymbol(none  )  color(green  ) lpattern(solid   ) lwidth(medium   ))   , ///
xlabel(  444 "1997"   504 "2002"   564 "2007"   624 "2014"    , labsize(${xlabsize}) grid) ///
ylabel( 0 "0" 2 "2" 4 "4"  , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(10) order(1 "Wage" 3 "Regular Wage (Break Test)" 4 "Regular Wage (True)" ) size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW_pathM1.pdf", replace

tw (connected   lw   date if worker_id==10023000 & new_id==27, msymbol(o)  color(red) lpattern(  dash ) lwidth(  medium )) ///
   (connected   lw   date if worker_id==10023000 & new_id==26, msymbol(o)  color(red) lpattern(  dash ) lwidth(  medium )) ///
   (scatter   lwr_b  date if worker_id==10023000, msymbol(t)  color(  blue) lpattern(  dash ) lwidth(  thick ))   ///
   (connected lwr_t  date if worker_id==10023000 & new_id==27, msymbol(none  )  color(green  ) lpattern(solid   ) lwidth(medium   ))  ///
   (connected lwr_t  date if worker_id==10023000 & new_id==26, msymbol(none  )  color(green  ) lpattern(solid   ) lwidth(medium   ))   , ///
xlabel(  444 "1997"   504 "2002"   564 "2007"   624 "2014"    , labsize(${xlabsize}) grid) ///
ylabel( -0.5 "-0.5" 0 "0" 0.5 "0.5" 1 "1" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(off)  ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW_pathM2.pdf", replace

********************************************************************************
*************** Path across Filter                  ********
********************************************************************************
import delimited "$path_results/GID_RSample_KS_test_K41.68_L6_w_r.csv", encoding(ISO-8859-1) clear

rename v1 worker_id
rename v2 firm_id
rename v3 new_id
rename v4 date
rename v5 lwr_ST
rename v6 lw_ST

gen date2 = monthly(date,"YM")
format date2 %tm
drop date
rename date2 date

save "$temp/ST_F.dta", replace

import delimited "$path_results/GID_RSample_BL_ParaT.01L4_w_r.csv", encoding(ISO-8859-1) clear

rename v1 worker_id
rename v2 firm_id
rename v3 new_id
rename v4 date
rename v5 lwr_BL
rename v6 lw_BL

gen date2 = monthly(date,"YM")
format date2 %tm
drop date
rename date2 date

save "$temp/BL_F.dta", replace

import delimited "$path_results/GID_RSample_NS_ParaT3J8_w_r.csv", encoding(ISO-8859-1) clear

rename v1 worker_id
rename v2 firm_id
rename v3 new_id
rename v4 date
rename v5 lwr_NS
rename v6 lw_NS

gen date2 = monthly(date,"YM")
format date2 %tm
drop date
rename date2 date

save "$temp/NS_F.dta", replace

import delimited "$path_results/GID_RSample_MK_ParaL3a.5c.3_w_r.csv", encoding(ISO-8859-1) clear

rename v1 worker_id
rename v2 firm_id
rename v3 new_id
rename v4 date
rename v5 lwr_KM
rename v6 lw_KM

gen date2 = monthly(date,"YM")
format date2 %tm
drop date
rename date2 date

save "$temp/KM_F.dta", replace

merge 1:1 worker_id date using "$temp/NS_F.dta"
drop _merge

merge 1:1 worker_id date using "$temp/BL_F.dta"
drop _merge

merge 1:1 worker_id date  using "$temp/ST_F.dta"
drop _merge

merge m:1 date using "$nim_wage/MW.dta", keepusing(MW)
drop _merge

gen l_minw =ln(MW/2)

gsort worker_id date
order worker_id date

replace lw_ST=6.5 if   lw_ST<l_minw

tw (connected lw_ST    date if worker_id==10000841, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr_ST  date if worker_id==10000841, msymbol(t)  color(  blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"   540 "2005" , labsize(${xlabsize}) grid) ///
ylabel( 6.6 "6.6" 6.8 "6.8" 7 "7"  7.2 "7.2"   7.4 "7.4" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Reg. Wage, Stevens (2020)" ) size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW1_Filters_ST.pdf", replace

tw (connected lw_ST    date if worker_id==10000841, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr_KM  date if worker_id==10000841, msymbol(t)  color(  blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"   540 "2005" , labsize(${xlabsize}) grid) ///
ylabel( 6.6 "6.6" 6.8 "6.8" 7 "7"  7.2 "7.2"   7.4 "7.4" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Reg. Wage, Kehoe-Midrigan (2015)") size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW1_Filters_KM.pdf", replace

tw (connected lw_ST    date if worker_id==10000841, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr_BL  date if worker_id==10000841, msymbol(t)  color(blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"   540 "2005" , labsize(${xlabsize}) grid) ///
ylabel( 6.6 "6.6" 6.8 "6.8" 7 "7"  7.2 "7.2"   7.4 "7.4" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Reg. Wage, Blanco (2020)" ) size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW1_Filters_BL.pdf", replace

tw (connected lw_ST    date if worker_id==10000841, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr_BL  date if worker_id==10000841, msymbol(t)  color(blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"   540 "2005" , labsize(${xlabsize}) grid) ///
ylabel( 6.6 "6.6" 6.8 "6.8" 7 "7"  7.2 "7.2"   7.4 "7.4" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Reg. Wage, Nakamura-Steinsson (2008)" ) size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW1_Filters_NS.pdf", replace

tw (connected lw_ST    date if worker_id==10029740, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr_ST  date if worker_id==10029740, msymbol(t)  color(  blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"    , labsize(${xlabsize}) grid) ///
ylabel( 5.5 "5.5" 6 "6" 6.5 "6.5" 7 "7" 7.5 "7.5"  8 "8" 8.5 "8.5" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Reg. Wage, Stevens (2020)" ) size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW2_Filters_ST.pdf", replace

tw (connected lw_ST    date if worker_id==10029740, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr_KM  date if worker_id==10029740, msymbol(t)  color(  blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"    , labsize(${xlabsize}) grid) ///
ylabel( 5.5 "5.5" 6 "6" 6.5 "6.5" 7 "7" 7.5 "7.5"  8 "8" 8.5 "8.5" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Reg. Wage, Kehoe-Midrigan (2015)") size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW2_Filters_KM.pdf", replace

tw (connected lw_ST    date if worker_id==10029740, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr_BL  date if worker_id==10029740, msymbol(t)  color(blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"    , labsize(${xlabsize}) grid) ///
ylabel( 5.5 "5.5" 6 "6" 6.5 "6.5" 7 "7" 7.5 "7.5"  8 "8" 8.5 "8.5" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Reg. Wage, Blanco (2020)" ) size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW2_Filters_BL.pdf", replace

tw (connected lw_ST    date if worker_id==10029740, msymbol(o )  color(red  ) lpattern(solid   ) lwidth(medium   ))  ///
 (scatter   lwr_BL  date if worker_id==10029740, msymbol(t)  color(blue) lpattern(  dash ) lwidth(  thick )), ///
xlabel(  444 "1997"   468 "1999"   492 "2001"   516 "2003"    , labsize(${xlabsize}) grid) ///
ylabel( 5.5 "5.5" 6 "6" 6.5 "6.5" 7 "7" 7.5 "7.5"  8 "8" 8.5 "8.5" , labsize(${ylabsize}) grid) ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(ring(0) position(7) order(1 "Log Wage" 2 "Reg. Wage, Nakamura-Steinsson (2008)" ) size(${legesize}) cols(2) symxsize(7) region(color(none))) ///
xtitle("Time", size(${xtitlesize}))
graph export "${path_figures}/figW2_Filters_NS.pdf", replace

********************************************************************************
***************  Compute distribution of # of changes                   ********
********************************************************************************

* Changes by year
import delimited "${freq_results}/Share_months_with_change_${file_name}.csv", clear

tw (connected share_months_changes year, msymbol(o) color(blue) lpattern(solid) lwidth(medium)),  ///
graphregion(color(white)) plotregion(lcolor(black)) ///
legend(off) ///
xtitle("Year", size(${xtitlesize})) ytitle("Share Months with Change", size(${ytitlesize})) xlabel(, grid labsize(${xlabsize})) ylabel(,labsize(${ylabsize}))
graph export "${path_figures}/Share_months_with_change.pdf", replace

* Changes by calendar month
import delimited "${freq_results}/Freq_Agg_${file_name}.csv", clear

rename date periodo
gen year = substr(periodo,1,4)
destring year, replace
gen month = substr(periodo,6,2)
destring month, replace
capture drop date
gen date = ym(year, month)
format date %tm
drop periodo

gen inflation_period     = 1 if inrange(year,1997,2001)
replace inflation_period = 2 if inrange(year,2007,2015)

collapse (mean) freq_dw, by(month inflation_period)

drop if inflation_period == .

reshape wide freq_dw, i(month) j(inflation_period)

replace freq_dw1 = -freq_dw1

twoway (bar freq_dw1 month, horizontal color(red)) /*
*/ (bar freq_dw2 month, horizontal color(blue)), xlabel(-0.40 "0.4" -0.2 "0.2" 0 "0" 0.2 "0.2" 0.4 "0.4") ylabel(3 6 9 12) /*
*/ legend(region(color(none) lcolor(white)) pos(8) ring(0) col(1) size(medium) label(1 "Low inflation") label(2 "High inflation")) /*
*/ graphregion(color(white)) plotregion(lcolor(black)) ytitle("Month", size(${ytitlesize})) xtitle("Frequency of wage changes", size(${xtitlesize})) xlabel(, grid labsize(${xlabsize})) ylabel(,labsize(${ylabsize}))
graph export "${path_figures}/Freq_agg_calendar_month.pdf", replace

********************************************************************************
***************  Plot variance decomposition                            ********
********************************************************************************

import delimited "$freq_results/Var_decomp_lw_$file_name.csv", clear

rename date periodo
gen year = substr(periodo,1,4)
destring year, replace
gen month = substr(periodo,6,2)
destring month, replace
capture drop date
gen date = ym(year, month)
format date %tm
drop periodo

tsset date

gen share_var_lw_r   = var_lw_r/var_lw_t
gen share_var_lresid = var_lresid/var_lw_t

gen share_var_dlw_r   = var_dlw_r/var_dlw_t
gen share_var_dlresid = var_dlresid/var_dlw_t

tssmooth ma share_var_lw_r_ma    = share_var_lw_r, window(2 1 2)
tssmooth ma share_var_lresid_ma  = share_var_lresid, window(2 1 2)
tssmooth ma share_var_dlw_r_ma   = share_var_dlw_r, window(5 1 5)
tssmooth ma share_var_dlresid_ma = share_var_dlresid, window(5 1 5)

twoway (connected share_var_lw_r_ma date, msymbol(o) lwidth(medium) color(red)) /*
*/ (connected share_var_lresid_ma date, msymbol(t) lwidth(medium) color(blue)), /*
*/ legend(region(color(none) lcolor(white)) pos(11) ring(0) col(1) size(${legesize}) label(1 "Regular Wage") label(2 "Transitory Wage")) /*
*/ graphregion(color(white)) plotregion(lcolor(black)) xtitle("Month", size(${xtitlesize})) ytitle("Share of Total Variance", size(${ytitlesize})) xlabel(, grid labsize(${xlabsize})) ylabel(,labsize(${ylabsize}))
graph export "${path_figures}/Var_decomp_level.pdf", replace

twoway (connected share_var_dlw_r_ma date, msymbol(o) lwidth(medium) color(red)) /*
*/ (connected share_var_dlresid_ma date, msymbol(t) lwidth(medium) color(blue)) if date >= tm(1997m2), /*
*/ legend(region(color(none) lcolor(white)) pos(11) ring(0) col(1) size(${legesize}) label(1 "Regular Wage") label(2 "Transitory Wage")) /*
*/ graphregion(color(white)) plotregion(lcolor(black)) xtitle("Month", size(${xtitlesize})) ytitle("Share of Total Variance", size(${ytitlesize})) xlabel(, grid labsize(${xlabsize})) ylabel(,labsize(${ylabsize}))
graph export "${path_figures}/Var_decomp_12mchange.pdf", replace

********************************************************************************
***************  Plot Frequencies and Histogram                         ********
********************************************************************************

* Aggregates

import delimited "${freq_results}/Freq_Agg_${file_name}.csv", clear

			rename date periodo
			gen year = substr(periodo,1,4)
			destring year, replace
			gen month = substr(periodo,6,2)
			destring month, replace
			capture drop date
			gen date = ym(year, month)
			format date %tm
			drop periodo

			merge m:1 date using "${input_data}/ArgentinaPriceLevel.dta", nogen keep (matched master)
			gen cpi=yoy

			tsset date
			egen ma           = filter( freq_dw ), lags(0/11) normalise
			egen ma_up        = filter( freq_dw_up ), lags(0/11) normalise
			egen ma_mean_up   = filter( mean_dw_up ), lags(0/11) normalise
			egen ma_down      = filter( freq_dw_down ), lags(0/11) normalise
			egen ma_mean_down = filter( mean_dw_down ), lags(0/11) normalise

			*agg freq_dw_12
			twoway (connected freq_dw_12 date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "Freq. of 12-month wage change") lab(2 "CPI inflation, yoy (right)")) ///
			ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_KS_FT0_freq_dw_12_new.pdf", as (pdf) replace

			*agg freq_dw_up_12
			twoway (connected freq_dw_up_12 date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "Freq. of 12-month wage increase") lab(2 "CPI inflation, yoy (right)"))  /*
			*/  ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_KS_FT0_freq_dw_up_12_new.pdf", as (pdf) replace

			*agg freq_dw_down_12
			twoway (connected freq_dw_down_12 date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1) lab(1 "Freq. of 12-month wage decrease") lab(2 "CPI inflation, yoy (right)"))  /*
			*/  ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_KS_FT0_freq_dw_down_12_new.pdf", as (pdf) replace

			*NEW! agg freq_dw_up_12 + agg freq_dw_down_12

			twoway (connected freq_dw_up_12 date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(blue)) ///
			(connected freq_dw_down_12 date, yaxis(1) msymbol(t) msize(small) lwidth(medium) color(red)) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  /*
			*/ lab(1 "Freq. of 12-month wage increase") lab(2 "Freq. of 12-month wage decrease") lab(3 "CPI inflation, yoy (right)"))  ///
			ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) /*
			*/ ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize})) yscale(range(0 1.1))

			graph export "${path_figures}/agg_freq_dw_up_dwn_12_rev.pdf", as (pdf) replace

			*agg mean_dw_up_12
			twoway (connected mean_dw_up_12 date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize})  pos (11) ring(0) col(1)  lab(1 "Mean 12-month wage increase") lab(2 "CPI inflation, yoy (right)"))  /*
			*/  ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_KS_FT0_mean_dw_up_12_new.pdf", as (pdf) replace

			*agg mean_dw_down_12
			twoway (connected mean_dw_down_12 date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "Mean 12-month wage decrease") lab(2 "CPI inflation, yoy (right)"))  /*
			*/  ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize})) yscale(range(-.40 0)) ylabel(-.40 -.30 -.20 -.10 0)

			graph export "${path_figures}/agg_KS_FT0_mean_dw_down_12_new.pdf", as (pdf) replace

			twoway (connected ma date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "MA monthly frequency of wage change") lab(2 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_new.pdf", as (pdf) replace

			twoway (connected ma_up date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "MA monthly frequency of wage increase") lab(2 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_up_new.pdf", as (pdf) replace

			twoway (connected ma_down date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "MA monthly frequency of wage decrease") lab(2 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_down_new.pdf", as (pdf) replace

			twoway (connected ma_mean_up date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "MA mean monthly wage increase") lab(2 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_meanup_new.pdf", as (pdf) replace

			twoway (connected ma_mean_down date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red) ) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "MA mean monthly wage decrease") lab(2 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_meandown_new.pdf", as (pdf) replace

			twoway (connected mean_dw_up date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red) ) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "Mean monthly wage increase") lab(2 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_meanup_new.pdf", as (pdf) replace

			twoway (connected ma_mean_down date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), /*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize})  pos (11) ring(0) col(1)  lab(1 "MA mean monthly wage decrease") lab(2 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_meandown_new.pdf", as (pdf) replace

******************************************************************************

* Gender

import delimited "${freq_results}/Freq_gender_${file_name}.csv", clear

			rename date periodo
			gen year = substr(periodo,1,4)
			destring year, replace
			gen month = substr(periodo,6,2)
			destring month, replace
			capture drop date
			gen date = ym(year, month)
			format date %tm
			drop periodo

			encode gender, generate(gender2)
			xtset gender2 date

			egen ma           = filter( freq_dw ), lags(0/11) normalise
			egen ma_up        = filter( freq_dw_up ), lags(0/11) normalise
			egen ma_mean_up   = filter( mean_dw_up ), lags(0/11) normalise
			egen ma_down      = filter( freq_dw_down ), lags(0/11) normalise
			egen ma_mean_down = filter( mean_dw_down ), lags(0/11) normalise


			merge m:1 date using "${input_data}/ArgentinaPriceLevel.dta", nogen keep (matched master)
			gen cpi=yoy

			gen inflation_period     = 1 if inrange(year,1997,2001)
			replace inflation_period = 2 if inrange(year,2007,2015)


	foreach v in freq_dw_12 freq_dw_up_12 freq_dw_down_12 ma ma_up ma_down {

			twoway (connected `v' date if gender == "Male", yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(red) )   ///
			(connected `v' date if gender == "Female", yaxis(1) msymbol(t) msize(small) lpattern(solid) lwidth(medium) color(blue) ) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "Male") lab(2 "Female") ///
			lab(3 "CPI Inflation, yoy (right)") ) ///
			ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/gender_KS_`v'_new.pdf", as (pdf) replace

			}

	foreach v in mean_dw_up_12 mean_dw_down_12 ma_mean_up ma_mean_down {

			twoway (connected `v' date if gender == "Male", yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(red) )   ///
			(connected `v' date if gender == "Female", yaxis(1) msymbol(t) msize(small) lpattern(solid) lwidth(medium) color(blue) ) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "Male") lab(2 "Female") ///
			lab(3 "CPI Inflation, yoy (right)") ) ///
			ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/gender_KS_`v'_new.pdf", as (pdf) replace

			}


*******************************************************************************

* Sector

import delimited "${freq_results}/Freq_Sector_${file_name}.csv", clear

			rename date periodo
			gen year = substr(periodo,1,4)
			destring year, replace
			gen month = substr(periodo,6,2)
			destring month, replace
			capture drop date
			gen date = ym(year, month)
			format date %tm
			drop periodo

			encode sector, generate(sector2)
			xtset sector2 date
			egen ma           = filter( freq_dw ), lags(0/11) normalise
			egen ma_up        = filter( freq_dw_up ), lags(0/11) normalise
			egen ma_mean_up   = filter( mean_dw_up ), lags(0/11) normalise
			egen ma_down      = filter( freq_dw_down ), lags(0/11) normalise
			egen ma_mean_down = filter( mean_dw_down ), lags(0/11) normalise

			merge m:1 date using "${input_data}/ArgentinaPriceLevel.dta", nogen keep (matched master)
			gen cpi=yoy


			gen inflation_period     = 1 if inrange(year,1997,2001)
			replace inflation_period = 2 if inrange(year,2007,2015)

			gen sectors=sector if sector=="A"|sector=="D"|sector=="F"|sector=="G"|sector=="M"

	foreach v in freq_dw_12 freq_dw_up_12 freq_dw_down_12 ma ma_up ma_down {

			twoway (connected `v' date if sector == "A", yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(red) )   ///
			(connected `v' date if sector == "D", yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(blue) ) ///
			(connected `v' date if sector == "F", yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(green) ) ///
			(connected `v' date if sector == "G", yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(khaki) ) ///
			(connected `v' date if sector == "M", yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(brown) ) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize})  pos (11) ring(0) col(1)  ///
			lab(1 "Agriculture") lab(2 "Manufacturing") lab(3 "Construction") lab(4 "Trade") lab(5 "Education") ///
			lab(6 "CPI Inflation, yoy (right)") ) ///
			ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/sector_KS_`v'_new.pdf", as (pdf) replace

			}

	foreach v in mean_dw_up_12 mean_dw_down_12 ma_mean_up ma_mean_down {

			twoway (connected `v' date if sector == "A", yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(red) )   ///
			(connected `v' date if sector == "D", yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(blue) ) ///
			(connected `v' date if sector == "F", yaxis(1) msymbol(d) msize(small) lwidth(medium) lpattern(solid) color(green) ) ///
			(connected `v' date if sector == "G", yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(khaki) ) ///
			(connected `v' date if sector == "M", yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(brown) ) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  ///
			lab(1 "Agriculture") lab(2 "Manufacturing") lab(3 "Construction") lab(4 "Trade") lab(5 "Education") ///
			lab(6 "CPI Inflation, yoy (right)") ) ///
			ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/sector_KS_`v'_new.pdf", as (pdf) replace

			}

*******************************************************************************

* Income

import delimited "${freq_results}/Freq_income_${file_name}.csv", clear

			rename date periodo
			gen year = substr(periodo,1,4)
			destring year, replace
			gen month = substr(periodo,6,2)
			destring month, replace
			capture drop date
			gen date = ym(year, month)
			format date %tm
			drop periodo

			xtset decile date
			egen ma           = filter( freq_dw ), lags(0/11) normalise
			egen ma_up        = filter( freq_dw_up ), lags(0/11) normalise
			egen ma_mean_up   = filter( mean_dw_up ), lags(0/11) normalise
			egen ma_down      = filter( freq_dw_down ), lags(0/11) normalise
			egen ma_mean_down = filter( mean_dw_down ), lags(0/11) normalise

			merge m:1 date using "${input_data}/ArgentinaPriceLevel.dta", nogen keep (matched master)
			gen cpi=yoy

	foreach v in freq_dw_12 freq_dw_up_12 freq_dw_down_12 ma ma_up ma_down {

			twoway (connected `v' date if decile == 1, yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(red)  ) ///
			(connected `v' date if decile == 5, yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(blue))  ///
			(connected `v' date if decile == 10, yaxis(1) msymbol(d) msize(small) lwidth(medium) lpattern(solid) color(green)) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none))  pos (11) ring(0) col(1) lab(1 "Decile 1") lab(2 "Decile 5") ///
			lab(3 "Decile 10") lab(4 "CPI Inflation, yoy (right)") ) ///
			ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/income_KS_`v'_new.pdf", as (pdf) replace

			}

	foreach v in mean_dw_up_12 mean_dw_down_12 ma_mean_up ma_mean_down {

			twoway (connected `v' date if decile == 1, yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(red)  ) ///
			(connected `v' date if decile == 5, yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(blue))  ///
			(connected `v' date if decile == 10, yaxis(1) msymbol(d) msize(small) lwidth(medium) lpattern(solid) color(green)) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1) lab(1 "Decile 1") lab(2 "Decile 5") ///
			lab(3 "Decile 10") lab(4 "CPI Inflation, yoy (right)") ) ///
			ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/income_KS_`v'_new.pdf", as (pdf) replace

			}


*******************************************************************************

* Age

import delimited "${freq_results}/Freq_age_${file_name}.csv", clear

			rename date periodo
			gen year = substr(periodo,1,4)
			destring year, replace
			gen month = substr(periodo,6,2)
			destring month, replace
			capture drop date
			gen date = ym(year, month)
			format date %tm
			drop periodo

			xtset year_age date
			egen ma           = filter( freq_dw ), lags(0/11) normalise
			egen ma_up        = filter( freq_dw_up ), lags(0/11) normalise
			egen ma_mean_up   = filter( mean_dw_up ), lags(0/11) normalise
			egen ma_down      = filter( freq_dw_down ), lags(0/11) normalise
			egen ma_mean_down = filter( mean_dw_down ), lags(0/11) normalise

			merge m:1 date using "${input_data}/ArgentinaPriceLevel.dta", nogen keep (matched master)
			gen cpi=yoy

	foreach v in freq_dw_12 freq_dw_up_12 freq_dw_down_12 ma ma_up ma_down {

			twoway (connected `v' date if year_age == 26, yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(red)  )   ///
			(connected `v' date if year_age == 35, yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(blue) )	///
			(connected `v' date if year_age == 45, yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(green) ) ///
			(connected `v' date if year_age == 55, yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(brown) ) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "Age 26") lab(2 "Age 35")  ///
			lab(3 "Age 45") lab(4 "Age 55") lab(5 "CPI Inflation, yoy (right)") ) ///
			ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/age_KS_`v'_new.pdf", as (pdf) replace

			}

	foreach v in mean_dw_up_12 mean_dw_down_12 ma_mean_up ma_mean_down {

			twoway (connected `v' date if year_age == 26, yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(red)  )   ///
			(connected `v' date if year_age == 35, yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(blue) )	///
			(connected `v' date if year_age == 45, yaxis(1) msymbol(o) msize(small) lwidth(medium) lpattern(solid) color(green) ) ///
			(connected `v' date if year_age == 55, yaxis(1) msymbol(t) msize(small) lwidth(medium) lpattern(solid) color(brown) ) ///
			(area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "Age 26") lab(2 "Age 35")  ///
			lab(3 "Age 45") lab(4 "Age 55") lab(5 "CPI Inflation, yoy (right)") ) ///
			ytitle("Mean wage change", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/age_KS_`v'_new.pdf", as (pdf) replace

			}


*******************************************************************************

* Histogram

use "${wach_results}/Raw_Histogram12_${file_name}.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

keep bin low_pi high_pi

gen  lt_lpi=sum(low_pi) if bin<=-.7549
egen ut_lpi=sum(low_pi) if bin>=.7549

gen  lt_hpi=sum(high_pi) if bin<=-.7549
egen ut_hpi=sum(high_pi) if bin>=.7549

replace lt_lpi=. if bin<=-.7551
replace lt_hpi=. if bin<=-.7551

replace ut_lpi=. if bin>=.7551
replace ut_hpi=. if bin>=.7551

replace low_pi=.  if bin<=-.7549
replace high_pi=. if bin<=-.7549

replace low_pi=. if bin>=.7549
replace high_pi=. if bin>=.7549

gen t_low_pi  =low_pi  if bin>=-.7551 &  bin<=.7549
gen t_high_pi =high_pi if bin>=-.751 &  bin<=.7549

replace t_low_pi  =lt_lpi  if t_low_pi==.
replace t_low_pi  =ut_lpi  if t_low_pi==.

replace t_high_pi  =lt_hpi  if t_high_pi==.
replace t_high_pi  =ut_hpi  if t_high_pi==.

twoway (line t_low_pi bin, color(red) lwidth(medium)  ) (line t_high_pi bin, color(blue) lwidth(medium) ),/*
	*/ ytitle("", size(${ytitlesize}))  xtitle("log wage change", size(${xtitlesize})) graphregion(color(white)) xlabel(-0.75(0.25)0.8, grid labsize(${xlabsize})) xscale(range(-0.75 0.75)) /*
	*/ yscale(range(0 .12)) ylabel(0 .04 .08 .12) /*
	*/ legend(region(color(none) lcolor(white)) symxsize(7.0) size(${legesize}) pos(1) ring(0) col(1) label(1 "Low inflation (1997-2001)") label(2 "High inflation (2007-2015)") )

graph export "${path_figures}/hist12_comp_KS_new.pdf", as (pdf) replace

********************************************************************************
***************  Compute decomposition in Alvarez et al (2019)          ********
********************************************************************************

import delimited "${freq_results}/Freq_Agg_${file_name}.csv", clear

gen year = substr(date,1,4)
destring year, replace

gen mean_dw_check    = (freq_dw_up - freq_dw_down)*mean_dw_up + (mean_dw_up - abs(mean_dw_down))*freq_dw_down
gen mean_dw_12_check = (freq_dw_up_12 - freq_dw_down_12)*mean_dw_up_12 + (mean_dw_up_12 - abs(mean_dw_down_12))*freq_dw_down_12

scatter mean_dw mean_dw_check
scatter mean_dw_12 mean_dw_12_check

* Monthly
gen extensive_low_pi  = (freq_dw_up - freq_dw_down)*mean_dw_up if inrange(year,1997,2001)
gen intensive_low_pi  = (mean_dw_up - abs(mean_dw_down))*freq_dw_down if inrange(year,1997,2001)
gen extensive_high_pi = (freq_dw_up - freq_dw_down)*mean_dw_up if inrange(year,2007,2015)
gen intensive_high_pi = (mean_dw_up - abs(mean_dw_down))*freq_dw_down if inrange(year,2007,2015)

* Low inflation
sum mean_dw if inrange(year,1997,2001)
local var_mean_dw_low_pi = `r(Var)'
corr mean_dw extensive_low_pi if inrange(year,1997,2001), covariance
local cov_ext_low_pi = `r(cov_12)'
corr mean_dw intensive_low_pi if inrange(year,1997,2001), covariance
local cov_int_low_pi = `r(cov_12)'

di "Alvarez decomposition - low inflation (1997-2001)"
di "Fraction explained by extensive margin (monthly wage change)"
di `cov_ext_low_pi'/`var_mean_dw_low_pi'

* High inflation
sum mean_dw if inrange(year,2007,2015)
local var_mean_dw_high_pi = `r(Var)'
corr mean_dw extensive_high_pi if inrange(year,2007,2015), covariance
local cov_ext_high_pi = `r(cov_12)'
corr mean_dw intensive_high_pi if inrange(year,2007,2015), covariance
local cov_int_high_pi = `r(cov_12)'

di "Alvarez decomposition - high inflation (2007-2015)"
di "Fraction explained by extensive margin (monthly wage change)"
di `cov_ext_high_pi'/`var_mean_dw_high_pi'

* Annual
gen extensive_12_low_pi  = (freq_dw_up_12 - freq_dw_down_12)*mean_dw_up_12 if inrange(year,1997,2001)
gen intensive_12_low_pi  = (mean_dw_up_12 - abs(mean_dw_down_12))*freq_dw_down_12 if inrange(year,1997,2001)
gen extensive_12_high_pi = (freq_dw_up_12 - freq_dw_down_12)*mean_dw_up_12 if inrange(year,2007,2015)
gen intensive_12_high_pi = (mean_dw_up_12 - abs(mean_dw_down_12))*freq_dw_down_12 if inrange(year,2007,2015)

* Low inflation
sum mean_dw_12 if inrange(year,1997,2001)
local var_mean_dw_12_low_pi = `r(Var)'
corr mean_dw_12 extensive_12_low_pi if inrange(year,1997,2001), covariance
local cov_ext_12_low_pi = `r(cov_12)'
corr mean_dw_12 intensive_12_low_pi if inrange(year,1997,2001), covariance
local cov_int_12_low_pi = `r(cov_12)'

di "Alvarez decomposition - low inflation (1997-2001)"
di "Fraction explained by extensive margin (12 month wage change)"
di `cov_ext_12_low_pi'/`var_mean_dw_12_low_pi'

* High inflation
sum mean_dw_12 if inrange(year,2007,2015)
local var_mean_dw_12_high_pi = `r(Var)'
corr mean_dw_12 extensive_12_high_pi if inrange(year,2007,2015), covariance
local cov_ext_12_high_pi = `r(cov_12)'
corr mean_dw_12 intensive_12_high_pi if inrange(year,2007,2015), covariance
local cov_int_12_high_pi = `r(cov_12)'

di "Alvarez decomposition - high inflation (2007-2015)"
di "Fraction explained by extensive margin (12 month wage change)"
di `cov_ext_12_high_pi'/`var_mean_dw_12_high_pi'

********************************************************************************
***************  Robustness: K for different inflation levels           ********
********************************************************************************

import delimited "${freq_results}/Freq_Agg_GID_RSample_KS_R1_test_K40.03_L6_w_r.csv", clear

rename date periodo
gen year = substr(periodo,1,4)
destring year, replace
gen month = substr(periodo,6,2)
destring month, replace
capture drop date
gen date = ym(year, month)
format date %tm
drop periodo

save "$temp/Robustness_data.dta", replace

import delimited "${freq_results}/Freq_Agg_${file_name}.csv", clear

rename date periodo
gen year = substr(periodo,1,4)
destring year, replace
gen month = substr(periodo,6,2)
destring month, replace
capture drop date
gen date = ym(year, month)
format date %tm
drop periodo

merge m:1 date using "${input_data}/ArgentinaPriceLevel.dta", nogen keep (matched master)
gen cpi=yoy

tsset date
egen ma           = filter( freq_dw ), lags(0/11) normalise

keep date freq_dw_12 ma cpi

rename  freq_dw_12 freq_dw_12_bench
rename  ma   ma_bench

merge m:1 date using "$temp/Robustness_data.dta", nogen keep (matched master)

tsset date
egen ma           = filter( freq_dw ), lags(0/11) normalise

keep date freq_dw_12 ma cpi freq_dw_12_bench  ma_bench

			*agg freq_dw_12
			twoway (connected freq_dw_12_bench date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (connected freq_dw_12 date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(blue)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)),yscale(r(0.6 1.1)) ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "12-month freq. (baseline)") lab(2 "12-month freq. (robustness)")  lab(3 "CPI inflation, yoy (right)")) ///
			ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_freq_dw_12_new_robustness.pdf", as (pdf) replace


			twoway (connected ma_bench date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (connected ma date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(blue)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), yscale(r(0.05 0.25))/*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "MA monthly frequency (baseline)") lab(2 "MA monthly frequency (robustness)") lab(3 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_new_robustness.pdf", as (pdf) replace

* Histogram

use "${wach_results}/Raw_Histogram12_GID_RSample_KS_R1_test_K40.03_L6_w_r.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

keep bin low_pi high_pi

gen  lt_lpi=sum(low_pi) if bin<=-.7549
egen ut_lpi=sum(low_pi) if bin>=.7549

gen  lt_hpi=sum(high_pi) if bin<=-.7549
egen ut_hpi=sum(high_pi) if bin>=.7549

replace lt_lpi=. if bin<=-.7551
replace lt_hpi=. if bin<=-.7551

replace ut_lpi=. if bin>=.7551
replace ut_hpi=. if bin>=.7551

replace low_pi=.  if bin<=-.7549
replace high_pi=. if bin<=-.7549

replace low_pi=. if bin>=.7549
replace high_pi=. if bin>=.7549

gen t_low_pi  =low_pi  if bin>=-.7551 &  bin<=.7549
gen t_high_pi =high_pi if bin>=-.751 &  bin<=.7549

replace t_low_pi  =lt_lpi  if t_low_pi==.
replace t_low_pi  =ut_lpi  if t_low_pi==.

replace t_high_pi  =lt_hpi  if t_high_pi==.
replace t_high_pi  =ut_hpi  if t_high_pi==.

keep t_low_pi bin t_high_pi bin

rename t_low_pi   t_low_pi_robus
rename t_high_pi  t_high_pi_robust

save "$temp/Robustness_hist_data.dta", replace

use "${wach_results}/Raw_Histogram12_${file_name}.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

keep bin low_pi high_pi

gen  lt_lpi=sum(low_pi) if bin<=-.7549
egen ut_lpi=sum(low_pi) if bin>=.7549

gen  lt_hpi=sum(high_pi) if bin<=-.7549
egen ut_hpi=sum(high_pi) if bin>=.7549

replace lt_lpi=. if bin<=-.7551
replace lt_hpi=. if bin<=-.7551

replace ut_lpi=. if bin>=.7551
replace ut_hpi=. if bin>=.7551

replace low_pi=.  if bin<=-.7549
replace high_pi=. if bin<=-.7549

replace low_pi=. if bin>=.7549
replace high_pi=. if bin>=.7549

gen t_low_pi  =low_pi  if bin>=-.7551 &  bin<=.7549
gen t_high_pi =high_pi if bin>=-.751 &  bin<=.7549

replace t_low_pi  =lt_lpi  if t_low_pi==.
replace t_low_pi  =ut_lpi  if t_low_pi==.

replace t_high_pi  =lt_hpi  if t_high_pi==.
replace t_high_pi  =ut_hpi  if t_high_pi==.

keep t_low_pi bin t_high_pi bin

merge m:1 bin using "$temp/Robustness_hist_data.dta", nogen keep (matched master)

twoway (line t_low_pi bin, color(red) lwidth(medium)  ) (line t_low_pi_robus bin, color(red)  lwidth(thin) lpattern(dash)  )  (line t_high_pi bin, color(blue) lwidth(medium) ) (line t_high_pi_robust bin, color(blue)  lwidth(thin) lpattern(dash)  ),/*
	*/ ytitle("", size(${ytitlesize}))  xtitle("log wage change", size(${xtitlesize})) graphregion(color(white)) xlabel(-0.75(0.25)0.8, grid labsize(${xlabsize})) xscale(range(-0.75 0.75)) /*
	*/ yscale(range(0 .12)) ylabel(0 .04 .08 .12) /*
	*/ legend(region(color(none) lcolor(white)) symxsize(7.0) size(${legesize}) pos(1) ring(0) col(2) label(1 "Low inflation (baseline)") label(2 "Low inflation (robustness)")  label(3 "High inflation (baseline)") label(4 "High inflation (robustness)"))

graph export "${path_figures}/hist12_comp_KS_new_robustnes.pdf", as (pdf) replace

********************************************************************************
***************  Robustness: 12-month wage changes                      ********
********************************************************************************

import delimited "${freq_results}/Freq_Agg_${file_name}.csv", clear

rename date periodo
gen year = substr(periodo,1,4)
destring year, replace
gen month = substr(periodo,6,2)
destring month, replace
capture drop date
gen date = ym(year, month)
format date %tm
drop periodo

merge m:1 date using "${input_data}/ArgentinaPriceLevel.dta", nogen keep (matched master)
gen cpi=yoy

tsset date
egen ma           = filter( freq_dw ), lags(0/11) normalise
egen ma_rob       = filter( freq_dw_rob ), lags(0/11) normalise

			*agg freq_dw_12
			twoway (connected freq_dw_12  date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (connected freq_dw_12_rob date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(blue)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)),yscale(r(0.6 1.1)) ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "12-month freq. regular wage") lab(2 "12-month freq. wage")  lab(3 "CPI inflation, yoy (right)")) ///
			ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_freq_dw_12_new_robustness_2.pdf", as (pdf) replace

			twoway (connected ma date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(red)) (connected freq_dw_rob date, yaxis(1) msymbol(o) msize(small) lwidth(medium) color(blue)) (area cpi date, yaxis(2) lcolor(gray%30) fcolor(gray%30)), yscale(r(0.05 0.25))/*
			*/  legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  lab(1 "MA monthly frequency main text") lab(2 "MA monthly frequency robustness") lab(3 "CPI Inflation, yoy (right)") ) /*
			*/  ytitle("Frequency of wage changes", axis(1) size(${ytitlesize})) ytitle("% change", axis(2) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) ///
			xtitle("Month", size(${xtitlesize})) graphregion(color(white)) xlabel(, grid labsize(${xlabsize}))

			graph export "${path_figures}/agg_ma_new_robustness_2.pdf", as (pdf) replace


********************************************************************************
***************  Scatter plots like in Alvarez et al (2019)             ********
********************************************************************************

import delimited "${freq_results}/Freq_Agg_${file_name}.csv", clear


			rename date periodo
			gen year = substr(periodo,1,4)
			destring year, replace
			gen month = substr(periodo,6,2)
			destring month, replace
			capture drop date
			gen date = ym(year, month)
			format date %tm
			drop periodo

			merge m:1 date using "${input_data}/ArgentinaPriceLevel.dta", nogen keep (matched master)
			gen cpi=yoy

			merge m:1 date using "${input_data}/ArgentinaWageChange.dta", nogen keep (matched master)

			tsset date
			egen ma           = filter( freq_dw ), lags(0/11) normalise
			egen ma_up        = filter( freq_dw_up ), lags(0/11) normalise
			egen ma_mean_up   = filter( mean_dw_up ), lags(0/11) normalise
			egen ma_down      = filter( freq_dw_down ), lags(0/11) normalise
			egen ma_mean_down = filter( mean_dw_down ), lags(0/11) normalise

			gen cpi_lag3      = cpi[_n-3]
			gen cpi_lag6      = cpi[_n-6]
			gen cpi_lag12     = cpi[_n-12]

			gen sqr_cpi = cpi^2

			gen sqr_cpi_lag3      = sqr_cpi[_n-3]
			gen sqr_cpi_lag6      = sqr_cpi[_n-6]
			gen sqr_cpi_lag12     = sqr_cpi[_n-12]


			gen mean_dw_up_12_100 = mean_dw_up_12*100
			gen mean_dw_down_12_100 = mean_dw_down_12*100
			gen mean_dw_12_100 = mean_dw_12*100

			* Segment by inflation periods
			gen inflation_regime     = 1 if inrange(year,1996,2001)
			replace inflation_regime = 2 if inrange(year,2002,2006)
			replace inflation_regime = 3 if inrange(year,2007,2015)

			* Semi-logarithmic transformation as in Khan and Senhadji (2001) [to avoid both negative and very high inflation rates]
			gen cpi_tr  = cpi-1 if cpi<=1
			replace cpi_tr = log(cpi) if cpi>1

			gen cpi_tr_lag3      = cpi_tr[_n-3]
			gen cpi_tr_lag6      = cpi_tr[_n-6]
			gen cpi_tr_lag12     = cpi_tr[_n-12]


			* Regressions for frequency of wage changes in cpi (2 alternatives: semi-log and quadratic)
			reg freq_dw_12 cpi_tr
			predict yhat_cpitr

			reg freq_dw_12 cpi sqr_cpi
			predict yhat_cpisqr

			*Scatters freq_dw_12 / cpi

			twoway (scatter freq_dw_12 cpi if inflation_regime == 1, msymbol(circle_hollow) color(midgreen)) ///
			(scatter freq_dw_12 cpi if inflation_regime == 2, msymbol(X) color(red)) ///
			(scatter freq_dw_12 cpi if inflation_regime == 3, msymbol(circle_hollow) color(blue)) ///
			(line yhat_cpitr cpi, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(1)  /*
			*/ order(1 "1997-2001" 2 "2002-2006" /*
			*/ 3 "2007-2015")) ///
			ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_cpi_fit_log_regimes.pdf", as (pdf) replace

			twoway (scatter freq_dw_12 cpi, msymbol(circle_hollow)  color(blue)) (line yhat_cpisqr cpi, sort lwidth(medium)  color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Freq. of 12-month wage change") lab(2 "Quadratic fit")) ///
			ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_cpi_fit_sqr.pdf", as (pdf) replace


			twoway (scatter freq_dw_12 cpi, msymbol(circle_hollow)  color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2))  /*
			*/ ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_cpi_nofit.pdf", as (pdf) replace

			*Scatters dw_12 using (mean) wages from sipa / cpi

			reg dw_12_sipa_mean cpi
			predict yhat_dwsipa

			twoway (scatter dw_12_sipa_mean cpi, msymbol(circle_hollow) color(blue)) (line yhat_dwsipa cpi, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Mean 12-month wage change (%)") lab(2 "Linear fit")) ///
			ytitle("Mean wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_sipa_mean_cpi.pdf", as (pdf) replace

			reg dw_12_sipa_mean cpi_lag3
			predict yhat_dwsipa3

			twoway (scatter dw_12_sipa_mean cpi_lag3, msymbol(circle_hollow) color(blue)) (line yhat_dwsipa3 cpi_lag3, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Mean 12-month wage change (%)") lab(2 "Linear fit (lag 3)")) ///
			ytitle("Mean wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_sipa_mean_cpilag3.pdf", as (pdf) replace

			reg dw_12_sipa_mean cpi_lag6
			predict yhat_dwsipa6

			twoway (scatter dw_12_sipa_mean cpi_lag6, msymbol(circle_hollow) color(blue)) (line yhat_dwsipa6 cpi_lag6, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Mean 12-month wage change (%)") lab(2 "Linear fit (lag 6)")) ///
			ytitle("Mean wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_sipa_mean_cpilag6.pdf", as (pdf) replace

			reg dw_12_sipa_mean cpi_lag12
			predict yhat_dwsipa12

			twoway (scatter dw_12_sipa_mean cpi_lag12, msymbol(circle_hollow) color(blue)) (line yhat_dwsipa12 cpi_lag12, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Mean 12-month wage change (%)") lab(2 "Linear fit (lag 12)")) ///
			ytitle("Mean wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_sipa_mean_cpilag12.pdf", as (pdf) replace

			*Scatters dw_12 using (median) wages from sipa / cpi

			reg dw_12_sipa_med cpi
			predict yhat_dwsipa_med

			twoway (scatter dw_12_sipa_med cpi, msymbol(circle_hollow) color(blue)) (line yhat_dwsipa_med cpi, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Median 12-month wage change (%)") lab(2 "Linear fit")) ///
			ytitle("Median wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_sipa_med_cpi.pdf", as (pdf) replace

			reg dw_12_sipa_med cpi_lag3
			predict yhat_dwsipa_med3

			twoway (scatter dw_12_sipa_med cpi_lag3, msymbol(circle_hollow) color(blue)) (line yhat_dwsipa_med3 cpi_lag3, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Median 12-month wage change (%)") lab(2 "Linear fit (lag 3)")) ///
			ytitle("Median wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_sipa_med_cpilag3.pdf", as (pdf) replace

			reg dw_12_sipa_med cpi_lag6
			predict yhat_dwsipa_med6

			twoway (scatter dw_12_sipa_med cpi_lag6, msymbol(circle_hollow) color(blue)) (line yhat_dwsipa_med6 cpi_lag6, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Median 12-month wage change (%)") lab(2 "Linear fit (lag 6)")) ///
			ytitle("Median wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_sipa_med_cpilag6.pdf", as (pdf) replace

			reg dw_12_sipa_med cpi_lag12
			predict yhat_dwsipa_med12

			twoway (scatter dw_12_sipa_med cpi_lag12, msymbol(circle_hollow) color(blue)) (line yhat_dwsipa_med12 cpi_lag12, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Median 12-month wage change (%)") lab(2 "Linear fit (lag 12)")) ///
			ytitle("Median wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_sipa_med_cpilag12.pdf", as (pdf) replace

			*Scatters dw_12 using regular wages from our estimations / cpi

			gen wage_infl = (freq_dw_up_12-freq_dw_down_12)*abs(mean_dw_up_12_100)+freq_dw_down_12*(abs(mean_dw_up_12_100)-abs(mean_dw_down_12_100))

			reg wage_infl cpi_tr
			predict yhat_dwtr

			reg mean_dw_12_100 cpi_tr
			predict yhat_dwtrm

			twoway (scatter mean_dw_12_100 cpi, msymbol(circle_hollow) color(blue) legend(off)) (line yhat_dwtrm cpi, sort lwidth(medium) color(blue)), ///
			ytitle("Mean wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_cpi.pdf", as (pdf) replace

			reg mean_dw_12_100 cpi_tr_lag3
			predict yhat_dwtr3

			twoway (scatter mean_dw_12_100 cpi_lag3, msymbol(circle_hollow) color(blue) legend(off)) (line yhat_dwtr3 cpi_lag3, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Mean 12-month wage change (%)") lab(2 "Log fit (lag 3)")) ///
			ytitle("Mean wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_cpil3.pdf", as (pdf) replace

			reg mean_dw_12_100 cpi_tr_lag6
			predict yhat_dwtr6

			twoway (scatter mean_dw_12_100 cpi_lag6, msymbol(circle_hollow) color(blue) legend(off)) (line yhat_dwtr6 cpi_lag6, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Mean 12-month wage change (%)") lab(2 "Log fit (lag 6)")) ///
			ytitle("Mean wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_cpil6.pdf", as (pdf) replace


			reg mean_dw_12_100 cpi_tr_lag12
			predict yhat_dwtr12

			twoway (scatter mean_dw_12_100 cpi_lag12, msymbol(circle_hollow) color(blue) legend(off)) (line yhat_dwtr12 cpi_lag12, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Mean 12-month wage change (%)") lab(2 "Log fit (lag 12)")) ///
			ytitle("Mean wage change (%)", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_dw_12_cpil12.pdf", as (pdf) replace


			*Scatters freq_dw_up_12 / cpi

			reg freq_dw_up_12 cpi_tr
			predict yhat_upcpitr

			reg freq_dw_up_12 cpi sqr_cpi
			predict yhat_upcpisqr


			twoway (scatter freq_dw_up_12 cpi, msymbol(circle_hollow) color(blue)) (line yhat_upcpitr cpi, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Freq. of 12-month wage increase") lab(2 "Fitted values")) ///
			ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_upcpi_fit_log.pdf", as (pdf) replace


			twoway (scatter freq_dw_up_12 cpi, msymbol(circle_hollow) color(blue)) (line yhat_upcpisqr cpi, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Freq. of 12-month wage increase") lab(2 "Fitted values")) ///
			ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_upcpi_fit_sqr.pdf", as (pdf) replace


			twoway (scatter freq_dw_up_12 cpi, msymbol(circle_hollow) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2))  /*
			*/ ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_upcpi_nofit.pdf", as (pdf) replace


			*Scatters freq_dw_down_12 / cpi

			reg freq_dw_down_12 cpi_tr
			predict yhat_downcpitr

			reg freq_dw_down_12 cpi sqr_cpi
			predict yhat_downcpisqr


			twoway (scatter freq_dw_down_12 cpi, msymbol(circle_hollow) color(blue)) (line yhat_downcpitr cpi, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Freq. of 12-month wage decrease") lab(2 "Fitted values")) ///
			ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_downcpi_fit_log.pdf", as (pdf) replace


			twoway (scatter freq_dw_down_12 cpi, msymbol(circle_hollow) color(blue)) (line yhat_downcpisqr cpi, sort lwidth(medium) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2)  /*
			*/ lab(1 "Freq. of 12-month wage decrease") lab(2 "Fitted values")) ///
			ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_downcpi_fit_sqr.pdf", as (pdf) replace


			twoway (scatter freq_dw_down_12 cpi, msymbol(circle_hollow) color(blue)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (4) ring(0) col(2))  /*
			*/ ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_downcpi_nofit.pdf", as (pdf) replace



			*Scatters freq_dw_up_down_12 / cpi

			twoway (scatter freq_dw_up_12 cpi, msymbol(circle_hollow) mcolor(blue)) (line yhat_upcpitr cpi, sort lwidth(medium) color(blue)) /*
			*/ (scatter freq_dw_down_12 cpi, msymbol(square_hollow) mcolor(red)) (line yhat_downcpitr cpi, sort lwidth(medium) color(red)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  /*
			*/ order(1 "Freq. of 12-month wage increase" 3 "Freq. of 12-month wage decrease")) ///
			ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium)) yscale(range(0 1.1))

			graph export "${path_figures}/scatter_freq_dw_12_updowncpi_fit_log.pdf", as (pdf) replace


			twoway (scatter freq_dw_up_12 cpi, msymbol(circle_hollow) mcolor(blue)) (line yhat_upcpisqr cpi, sort lwidth(medium) color(blue)) /*
			*/ (scatter freq_dw_down_12 cpi, msymbol(square_hollow) mcolor(red)) (line yhat_downcpisqr cpi, sort lwidth(medium) color(red)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1)  /*
			*/ order(1 "Freq. of 12-month wage increase" 3 "Freq. of 12-month wage decrease")) ///
			ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_updowncpi_fit_sqr.pdf", as (pdf) replace


			twoway (scatter freq_dw_up_12 cpi, msymbol(circle_hollow) mcolor(blue)) (scatter freq_dw_down_12 cpi, msymbol(square_hollow) mcolor(red)), ///
			legend(symxsize(7.0) region(lcolor(none) fcolor(none)) size(${legesize}) pos (11) ring(0) col(1) /*
			*/ order(1 "Freq. of 12-month wage increase" 2 "Freq. of 12-month wage decrease")) /*
			*/ ytitle("Frequency of wage changes", size(medium)) ///
			xtitle("Inflation (% per year)", size(medium)) graphregion(color(white)) xlabel(, grid labsize(medium))

			graph export "${path_figures}/scatter_freq_dw_12_updowncpi_nofit.pdf", as (pdf) replace
