%{
* DESCRIPTION: This code estimates the Calvo-Taylor model with SMM

* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
%}


%% Delete Previous information, close figures and delete text in command window

close all;
clear;
clc;
rng(100);

% add here folder in your computer

Inputfolder    = '/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Part_B/RandomSample/output/esti_output';
currentFolder  = pwd;

% Estimate or calibrate the model

p.calibratemodel = 1;                                                      % 1 to calibrate, 0 to load results

% print the result of SMM
p.print          =0;                                                       % =1 if print results


% Number of K in the grid
p.nvalsK         = 10;
p.K_grid         = linspace(0.3,0.6,p.nvalsK);                            % number of parameters in the grid for K



% Number of K in the grid
p.version        =1;                                                       % 1=bechmark, >1=set some shocks to zero

% upper and lower bound in the estimatino
p.paramlb       = [3 ;0.001;-1.50;0.10;0.001;0.2;0.001;0.2];
p.paramub       = [36;0.090;-0.10;1.50;0.500;0.7;0.300;0.7];

% sectoral initial conditions
par_int          =ones(8,15);

% sector 1
par_int(1,1)      =     35   ;
par_int(2,1)      =     0.03 ;
par_int(3,1)      =    -0.11 ;
par_int(4,1)      =     1.49 ;
par_int(5,1)      =     0.19 ;
par_int(6,1)      =     0.29 ;
par_int(7,1)      =     0.15 ;
par_int(8,1)      =     0.33 ;

% sector 2
par_int(1,2)      =     29   ;
par_int(2,2)      =     0.09 ;
par_int(3,2)      =    -0.12 ;
par_int(4,2)      =     1.13 ;
par_int(5,2)      =     0.44 ;
par_int(6,2)      =     0.35 ;
par_int(7,2)      =     0.30 ;
par_int(8,2)      =     0.70 ;


% sector 3
par_int(1,3)      =     3    ;
par_int(2,3)      =     0.07 ;
par_int(3,3)      =    -1.00 ;
par_int(4,3)      =     1.48 ;
par_int(5,3)      =     0.09 ;
par_int(6,3)      =     0.32 ;
par_int(7,3)      =     0.17 ;
par_int(8,3)      =     0.53 ;


% sector 4
par_int(1,4)      =     26   ;
par_int(2,4)      =     0.06 ;
par_int(3,4)      =    -0.21 ;
par_int(4,4)      =     1.48 ;
par_int(5,4)      =     0.04 ;
par_int(6,4)      =     0.38 ;
par_int(7,4)      =     0.14 ;
par_int(8,4)      =     0.58 ;

% sector 5
par_int(1,5)      =     24   ;
par_int(2,5)      =     0.02 ;
par_int(3,5)      =    -0.22 ;
par_int(4,5)      =     1.49 ;
par_int(5,5)      =     0.01 ;
par_int(6,5)      =     0.35 ;
par_int(7,5)      =     0.17 ;
par_int(8,5)      =     0.62 ;


% sector 6
par_int(1,6)      =     36   ;
par_int(2,6)      =     0.09 ;
par_int(3,6)      =    -0.18 ;
par_int(4,6)      =     1.48 ;
par_int(5,6)      =     0.09 ;
par_int(6,6)      =     0.34 ;
par_int(7,6)      =     0.17 ;
par_int(8,6)      =     0.53 ;


% sector 7
par_int(1,7)      =     29   ;
par_int(2,7)      =     0.06 ;
par_int(3,7)      =    -0.22 ;
par_int(4,7)      =     1.48 ;
par_int(5,7)      =     0.05 ;
par_int(6,7)      =     0.35 ;
par_int(7,7)      =     0.10 ;
par_int(8,7)      =     0.46 ;


% sector 8
par_int(1,8)      =     27   ;
par_int(2,8)      =     0.06 ;
par_int(3,8)      =    -0.22 ;
par_int(4,8)      =     1.49 ;
par_int(5,8)      =     0.09 ;
par_int(6,8)      =     0.35 ;
par_int(7,8)      =     0.10 ;
par_int(8,8)      =     0.51 ;


% sector 9
par_int(1,9)      =     20   ;
par_int(2,9)      =     0.06 ;
par_int(3,9)      =    -0.22 ;
par_int(4,9)      =     1.49 ;
par_int(5,9)      =     0.02 ;
par_int(6,9)      =     0.33 ;
par_int(7,9)      =     0.13 ;
par_int(8,9)      =     0.59 ;


% sector 10
par_int(1,10)      =     36   ;
par_int(2,10)      =     0.07 ;
par_int(3,10)      =    -0.27 ;
par_int(4,10)      =     1.49 ;
par_int(5,10)      =     0.02 ;
par_int(6,10)      =     0.38 ;
par_int(7,10)      =     0.17 ;
par_int(8,10)      =     0.51 ;


% sector 11
par_int(1,11)      =     28   ;
par_int(2,11)      =     0.06 ;
par_int(3,11)      =    -0.21 ;
par_int(4,11)      =     1.48 ;
par_int(5,11)      =     0.03 ;
par_int(6,11)      =     0.35 ;
par_int(7,11)      =     0.12 ;
par_int(8,11)      =     0.46 ;


% sector 12
par_int(1,12)      =     4    ;
par_int(2,12)      =     0.09 ;
par_int(3,12)      =    -0.10 ;
par_int(4,12)      =     1.48 ;
par_int(5,12)      =     0.01 ;
par_int(6,12)      =     0.33 ;
par_int(7,12)      =     0.17 ;
par_int(8,12)      =     0.69 ;


% sector 13
par_int(1,13)      =     36   ;
par_int(2,13)      =     0.08 ;
par_int(3,13)      =    -0.18 ;
par_int(4,13)      =     1.42 ;
par_int(5,13)      =     0.04 ;
par_int(6,13)      =     0.25 ;
par_int(7,13)      =     0.11 ;
par_int(8,13)      =     0.36 ;


% sector 14
par_int(1,14)      =     27   ;
par_int(2,14)      =     0.04 ;
par_int(3,14)      =    -0.14 ;
par_int(4,14)      =     1.49 ;
par_int(5,14)      =     0.09 ;
par_int(6,14)      =     0.37 ;
par_int(7,14)      =     0.13 ;
par_int(8,14)      =     0.44 ;


% sector 15
par_int(1,15)      =     31   ;
par_int(2,15)      =     0.04 ;
par_int(3,15)      =    -0.22 ;
par_int(4,15)      =     1.49 ;
par_int(5,15)      =     0.06 ;
par_int(6,15)      =     0.36 ;
par_int(7,15)      =     0.13 ;
par_int(8,15)      =     0.43 ;



parfor ss=1:15

    mom_m=estimate_income_process(ss,p,Inputfolder,currentFolder,par_int(:,ss));

end

%% Compute table for the paper


Moments_estimation=ones(26,15);
K_evaluation      =ones(7,15);
n_workers         =ones(1,15);
cd(Inputfolder)

for ii=1:15

    load(strcat('calibpar_',num2str(ii,'%.1i')))

    % Sectoral moments: data
    Moments_estimation(1:9,ii)=mom_d;

    % Sectoral moments: model
    Moments_estimation(10:18,ii)=mom_m;

    % Parameters for estimation
    Moments_estimation(19:26,ii)=calibpar;

    % Moments for K
    K_evaluation(1,ii)   =K_opt;

    % Moments for K
    K_evaluation(2:6,ii) =moments(1:end-1);

    % number of workers
    n_workers(1,ii) =moments(end);


end


cd(currentFolder)
