%{
* DESCRIPTION: This code simulates the Calvo-Taylor model for a given set of parameters

* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
%}

function simdata = simulate(d,par,shock)

% Transitory shock
w_trans = d.agui.*(par.sigma_phi*shock.phi + par.m_phi) + (shock.gamma_i <= par.beta).*shock.gamma*par.sigma_gamma;


% Permanent shock over the completed time series
aux                        = nan(size(d.lw_t_com));
aux(~isnan(d.lw_t_com))    = 0;
check1                     = nan(size(d.lw_t_com));
check2                     = nan(size(d.lw_t_com));
break_point                = nan(size(d.lw_t_com));
w_perm                     = nan(size(d.lw_t_com));
w_perm(~isnan(d.lw_t_com)) = 0;
age                        = nan(size(d.lw_t_com));
age(~isnan(d.lw_t_com))    = 0;
nonmissing                 = ~isnan(aux(:,1));
age(nonmissing,1)          = floor(par.T_taylor*shock.br(nonmissing));

% complete missing time series

for t = 2:size(d.agui,2)

    % start age for those jobs starting in period t
    nonmissing                = (~isnan(aux(:,t)) &  isnan(aux(:,t-1)));
    age(nonmissing,t)          = floor(par.T_taylor*shock.br(nonmissing));


    nonmissing                = (~isnan(aux(:,t)) & ~isnan(aux(:,t-1)));
    wptilde                   = aux(:,t-1) - d.dwage_r(:,t) + par.sigma_eta*shock.eta(:,t);
    atilde                    = age(:,t-1)+1;
    flag                      = (wptilde >= par.w_lb & wptilde <= par.w_ub) & (atilde < par.T_taylor) & nonmissing;

    aux(flag,t)               = wptilde(flag);
    age(flag,t)               = atilde(flag);

    check1(:,t)               = ((wptilde >= par.w_lb & wptilde <= par.w_ub) & nonmissing);
    check2(:,t)               = ( atilde  < par.T_taylor);
    break_point(nonmissing,t) = 1 - (check1(nonmissing,t) == 1 & check2(nonmissing,t) == 1);

    w_perm((break_point(:,t) == 1),t) = aux((break_point(:,t) == 1),t) - aux((break_point(:,t) == 1),t-1);


end


temp                        = w_perm;
temp(isnan(temp))           = 0;
w_perm                      = cumsum(temp,2);
w_perm(isnan(w_trans))      = nan;

break_point =[nan(size(w_perm,1),1),w_perm(:,2:end)-w_perm(:,1:end-1)];
break_point(~isnan(break_point) & break_point~=0)=1;


w_total                     = w_trans + w_perm;

for t=5:6:(size(d.agui,2)-1)

    nonmissing           = (~isnan(w_total(:,t-1)) & ~isnan(w_total(:,t)) & ~isnan(w_total(:,t+1)));
    non_agui             = (w_total(:,t+1)==w_total(:,t-1)) & nonmissing;
    w_total(non_agui,t)  =w_total(non_agui,t-1);

end

% Store results
simdata.w_trans     = w_trans;
simdata.w_perm      = w_perm;
simdata.w_total     = w_total;
simdata.break_point = break_point;

end