%{
* DESCRIPTION: This code runs the filter by Luminita Stevents

* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
%}


%% Delete Previous information, close figures and delete text in command window

close all;
clear;
clc;

%% paramaters

% add here folder in your computer

Tempfolder     = '/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Part_B/RandomSample/temp';
currentFolder  = pwd;

% Options

p.name    = 'GID_RSample';                                                 % GID_RSample=run in random sample;XX=run in subsample
p.test    = '0';                                                           % 0=run in all sample;1=run in subsample
%p.Ka      = 41.68;                                                            % K for the A sector
p.Ka      = 40.03;
p.L       = 6;                                                             % L parameter
p.robust  = 1;

%% upload the data and apply break test


if p.robust==0
	data_name = strcat(p.name,'_Data_KS_test_K',string(p.Ka),'_L',string(p.L));
else
    data_name = strcat(p.name,'_Data_KS_R1_test_K',string(p.Ka),'_L',string(p.L));
end


parfor jj=1:10

    % upload the data if there is no information over size
    cd(Tempfolder)
    data_name_in = strcat(data_name,'_',string(jj),'.csv');
    data         = csvread(data_name_in,0,0);
    cd(currentFolder)
    mystats      = @(x)[median(x) numel(x)];
    data(:,2)    = log(data(:,2));
    dates        = data(2:end,1)-data(1:(end-1),1);
    dates        = [0;find(dates);size(data,1)];
    aux_var      = 0;

    for tt=2:size(dates,1)

        wage         = data(dates(tt-1)+1:dates(tt),2);
        K_par         = data(dates(tt-1)+1,4);
        [brks,SnVals] = break_test_basic(wage,1,K_par);
        brks          = cumsum(brks);
        Group_sector  = findgroups(brks);
        Group_sector  = splitapply(mystats,wage,Group_sector);

        data((dates(tt-1)+1):dates(tt),2) = exp(repelem(Group_sector(:,1),Group_sector(:,2)));

        if floor(tt/size(dates,1)*100) > aux_var
            fprintf('number completed :        %6.2f percent \n', floor( tt/size(dates,1)*100) );
            aux_var = aux_var+5;
        end
    end
    data_name_out = strcat(data_name,'_w_r','_',string(jj),'.csv');
    cd(Tempfolder)
    dlmwrite(data_name_out,data,'precision', '%i');
    cd(currentFolder)
end
