%{
* DESCRIPTION: This code estimates the Calvo-Taylor model with SMM

* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
%}

%% Delete Previous information, close figures and delete text in command window

close all;
clear;
clc;
rng(100);


% add here folder in your computer

Inputfolder    = '/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Part_B/RandomSample/output/esti_output';
currentFolder  = pwd;

% Estimate or calibrate the model

p.calibratemodel = 1;                                                      % 1 to calibrate, 0 to load results

% print the result of SMM
p.print          =0;                                                       % =1 if print results


% Number of K in the grid
p.nvalsK         = 10;
p.K_grid         = linspace(0.3,0.6,p.nvalsK);                            % number of parameters in the grid for K



% Number of K in the grid
p.version        =1;                                                       % 1=bechmark, >1=set some shocks to zero

% upper and lower bound in the estimatino
p.paramlb       = [3 ;0.001;-1.50;0.10;0.001;0.2;0.001;0.2];
p.paramub       = [36;0.090;-0.10;1.50;0.500;0.7;0.300;0.7];


%% Compute table for the paper


Moments_data_h =ones(9,15);
Moments_model_h=ones(9,15);
Estimate_par_h =ones(8,15);
K_evaluation_h =ones(6,15);
n_workers_h    =ones(1,15);



Moments_data_l =ones(9,15);
Moments_model_l=ones(9,15);
Estimate_par_l =ones(8,15);
K_evaluation_l =ones(6,15);
n_workers_l    =ones(1,15);
cd(Inputfolder)

for ii=1:15

    load(strcat('calibpar_l_',num2str(ii,'%.1i')))

    % Sectoral moments: data
    Moments_data_l(:,ii)=mom_d;

    % Sectoral moments: model
    Moments_model_l(:,ii)=mom_m;

    % Parameters for estimation
    Estimate_par_l(:,ii)=calibpar;

    % Moments for K
    K_evaluation_l(1,ii)   =K_opt;

    % Moments for K
    K_evaluation_l(2:6,ii) =moments(1:end-1);

    % number of workers
    n_workers_l(1,ii) =moments(end);


end


for ii=1:15

    load(strcat('calibpar_h_',num2str(ii,'%.1i')))

    % Sectoral moments: data
    Moments_data_h(:,ii)=mom_d;

    % Sectoral moments: model
    Moments_model_h(:,ii)=mom_m;

    % Parameters for estimation
    Estimate_par_h(:,ii)=calibpar;

    % Moments for K
    K_evaluation_h(1,ii)   =K_opt;

    % Moments for K
    K_evaluation_h(2:6,ii) =moments(1:end-1);

    % number of workers
    n_workers_h(1,ii) =moments(end);


end


cd(currentFolder)

