%{
* DESCRIPTION: This code simulates the Calvo-Taylor model and apply the Break Test

* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
%}

% Sector
p.sect_num       =4;


Inputfolder    = '/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Part_B/RandomSample/output/esti_output';
Outputfolder   ='/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Part_B/RandomSample/results/estimation';
currentFolder  = pwd;

% Estimate or calibrate the model

p.calibratemodel = 1;                                                      % 1 to calibrate, 0 to load results

% print the result of SMM
p.print          =1;                                                       % =1 if print results


% Number of K in the grid

p.K_opt          =0.48;

%% Upload the data
cd(Inputfolder)

% order in the variables are cuil_trab, new_id, date, agui, lw_t, dwage

data = csvread(strcat('CrossValidation_',num2str(p.sect_num,'%.1i'),'.csv'),0,0);

% Change date to start from 1
data(:,3) = data(:,3) - min(data(:,3)) + 1;

cd(currentFolder)

%% Reshape data

data(:,end+1)    = 999;

d.spellid        = full(sparse(data(:,2),data(:,3),data(:,2)));
d.agui           = full(sparse(data(:,2),data(:,3),data(:,4)));
d.lw_t           = full(sparse(data(:,2),data(:,3),data(:,5)));
d.dwage_r        = full(sparse(data(:,2),data(:,3),data(:,6)));
d.month          = full(sparse(data(:,2),data(:,3),data(:,3)+1-(ceil((data(:,3)+1)/12)-1)*12));
aux              = full(sparse(data(:,2),data(:,3),data(:,3)));
aux(aux==0)      = size(aux,2)+1;
d.min_date       = min(aux,[],2);
d.max_date       = max(full(sparse(data(:,2),data(:,3),data(:,3))),[],2);
d.lw_t_com       = d.lw_t;

for t=2:size(d.lw_t_com,2)

    aux              =d.lw_t_com(:,t)==0 & t<=d.max_date & t>=d.min_date;

    d.lw_t_com(aux,t)=d.lw_t_com(aux,t-1);

end

isdata           = full(sparse(data(:,2),data(:,3),data(:,end)));
d.flag             =isdata ~=999;

d.spellid(d.flag) = nan;
d.agui(d.flag) = nan;
d.lw_t(d.flag) = nan;
d.dwage_r(d.flag) = nan;
d.lw_t_com(d.lw_t_com==0) = nan;

% generate auxiliary variables

ddate       = data(:,3);
mystats2    = @(x)[min(x) max(x) numel(x)];
Group_spell = findgroups(data(:,2));
Group_spell = splitapply(mystats2,ddate,Group_spell);
start_spell = repelem(Group_spell(:,1),Group_spell(:,3));
end_spell   = repelem(Group_spell(:,2),Group_spell(:,3));

tenaux      = data(2:end,1)-data(1:(end-1),1);
tenaux      = [0;find(tenaux);size(data,1)];
tenaux      = tenaux(2:end)-tenaux(1:end-1);
tenure      = repelem(tenaux,tenaux);

d.tenure      = full(sparse(data(:,2),data(:,3),tenure));
d.start_spell = full(sparse(data(:,2),data(:,3),start_spell));
d.end_spell   = full(sparse(data(:,2),data(:,3),end_spell));
d.ddate       = full(sparse(data(:,2),data(:,3),ddate));

d.tenure(d.flag)        = nan;
d.start_spell(d.flag)   = nan;
d.end_spell(d.flag)     = nan;
d.ddate(d.flag)         = nan;

clear tenure tenaux t start_spell mystats2 flag isdata dates  ddate  Group_spell  end_spell aux

%% Parameters

% initial parameters for the SMM

par.T_taylor    = 25.26 ;
par.sigma_eta   = 0.0623 ;
par.w_lb        = -0.2048 ;
par.w_ub        = 1.47970 ;
par.sigma_phi   = 0.02505 ;
par.m_phi       = 0.38164 ;
par.sigma_gamma = 0.15100 ;
par.beta        = 0.5812 ;


%% Random number generator for the distributions

shock.phi     = randn(size(d.lw_t));
shock.gamma   = randn(size(d.lw_t));
shock.eta     = randn(size(d.lw_t));
shock.gamma_i = rand(size(d.lw_t));
shock.br      = rand(size(d.lw_t));


%% Simulate data and store it for cross-validation exercise

mom               = simulate(d,par,shock);


clear  data_name_out

%% Apply Stevens filter to the simulated wage series

new_id                = reshape(d.spellid',numel(d.spellid),1);
new_id(isnan(new_id)) = [];
lw_t                  = reshape(mom.w_total',numel(mom.w_total),1);
filter                = (isnan(lw_t));
lw_t(filter)          = [];

sim_data = [new_id lw_t ];

mystats      = @(x)[median(x) numel(x)];
dates        = sim_data(2:end,1)-sim_data(1:(end-1),1);
dates        = [0;find(dates);size(sim_data,1)];


% Storage variables
breaks_cv_opt = nan(size(sim_data,1),1);
lregw_t_opt   = nan(size(sim_data,1),1);



for tt = 2:size(dates,1)

	wage         = sim_data((dates(tt-1)+1):dates(tt),2);
    [brks,SnVals] = break_test_basic(wage,1,p.K_opt);

    breaks_cv_opt((dates(tt-1)+1):dates(tt)) = brks;

    brks         = cumsum(brks);
    Group_sector = findgroups(brks);
    Group_sector = splitapply(mystats,wage,Group_sector);

    lregw_t_opt((dates(tt-1)+1):dates(tt))   = repelem(Group_sector(:,1),Group_sector(:,2));


end


% Reshape into array to make comparisons easier
testbreaks_opt = full(sparse(data(:,2),data(:,3),breaks_cv_opt));
testwage_opt   = full(sparse(data(:,2),data(:,3),lregw_t_opt));

testbreaks_opt(d.flag) = nan;
testwage_opt(d.flag)   = nan;

figure(1)
plot((1:1:size(testbreaks_opt,2))./12,mom.w_total(16,:),...
     (1:1:size(testbreaks_opt,2))./12,mom.w_perm(16,:),...
     (1:1:size(testbreaks_opt,2))./12,testwage_opt(16,:))
legend('total wage','regular wage','estimate reg wage')


figure(2)
plot((1:1:size(testbreaks_opt,2))./12,mom.w_total(18,:),...
     (1:1:size(testbreaks_opt,2))./12,mom.w_perm(18,:),...
     (1:1:size(testbreaks_opt,2))./12,testwage_opt(18,:))

%% save the data in stata format

% variables worker id, match id, date, w_t, w_r, w, w_ht,

w_T                  = reshape(mom.w_trans',numel(mom.w_trans),1);
filter                = (isnan(w_T));
w_T(filter)          = [];

w_R                  = reshape(mom.w_perm',numel(mom.w_perm),1);
w_R(filter)          = [];

w                  = reshape(mom.w_total',numel(mom.w_total),1);
w(filter)          = [];

BD                  = reshape(mom.break_point',numel(mom.break_point),1);
BD(filter)          = [];




output_file=[data(:,1:3),w_R,lregw_t_opt,w_T,w,BD,breaks_cv_opt];


cd(Outputfolder)

csvwrite('simulated_data.cvs',output_file);

cd(currentFolder)
