********************************************************************************
* DESCRIPTION: This code produces the excel tables for the main text
* for the code 002_Build_Dataset.do
* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
********************************************************************************
/*

 - input: data with the regular wage, e.g.,  "GID_RSample_Data_KS_test_K51_L6_w_r.dta"

 - output: Figures of the wages before and after the filters
		   Excel files in results

*/

*Dataset to use
global dataset = "RSample"

* add here your path to the random sample folder
global pathinit ""

* add here the name with the options
global file_name "GID_RSample_KS_test_K41.68_L6_w_r"   // with steavens (2020)
*global file_name "GID_RSample_KS_R1_test_K40.03_L6_w_r"   // with steavens (2020) and two K for diff. level of inflation
*global file_name "GID_RSample_BL_ParaT.01L4_w_r"      //with Blanco (2020)
*global file_name "GID_RSample_MK_ParaL3a.5c.3_w_r"    // with Kehoe and Midrigan method (2015)
*global file_name "GID_RSample_NS_ParaT3J8_w_r"        // with Nakamura and Steinsson method (2008)

*test code with 10% of original sample
global test_code = 0      /* 0=original sample, 1=subsample 10\% \%*/

********************************************************************************
*** graph options for individual labor income
********************************************************************************
global graph_nid   = 50
global graph_ntime = 5*12

********************
*Paths and Logs
********************

*input folder for data
global intput = "$pathinit/output/002_output"

*input folder for regular wagepaths
global intput_wr = "$pathinit/output/003_output"

*results folder
global results = "$pathinit/results/Robustness"

*
global path_figures ="/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Figures/KS_filter"

*temporary folder folder
global temp = "$pathinit/temp"

global sample = ""


if "$dataset" == "RSample"{

    global filename      = "${sample}CleanRandomSample_"
    global last_year     = 2015
    local convencionado  = "convencionado"
    local basic_wage     = "basic_wage"
    global name          = "GID_RSample_"

}

if $test_code == 0{

    use cuil_trab cuit_empl ciiu_4 gender date wage first_or_last_obs /*
    */ sector year_age min_wage_ind new_id /*
    */ using "$intput/${name}Prepped_Dataset.dta", replace


}

else if $test_code == 1{

    use cuil_trab cuit_empl ciiu_4 gender date wage first_or_last_obs /*
    */ sector year_age min_wage_ind new_id/*
    */ using "$temp/${name}Prepped_Dataset_small.dta", replace


}

********************************************************************************
***************  Save the log file       ***************************************
********************************************************************************

capture log close
log using "$temp/004_Compute_state.txt", replace text

merge 1:1 date new_id using "$intput_wr/$file_name.dta"
drop _merge

********************************************************************************
***************  Compute statistics wage changes      **************************
********************************************************************************

* Sort dataset by job id
qui xtset new_id date
qui gsort new_id date

* round wages to pesos (no cents)
qui gen w_t = round(wage ,1)

* drop first and last wage due to time aggregation
qui replace w_t =. if first_or_last_obs==1 | min_wage_ind==1

* replace June and December
qui by new_id: replace w_t =0.5*l.w_t+0.5*f.w_t if  (month(dofm(date))==6 | month(dofm(date))==12) & (w_t~=l.w_t & w_t~=f.w_t) & (l.w_t ==f.w_t) & l.w_t~=. & f.w_t~=.

********************************************************************************
***************  Compute 1- and 12- monthly wage change distribution    ********
********************************************************************************

bysort new_id (date): gen wage_change_r12 = (ln(w_r) - ln(l12.w_r)) /*current wage minus the previous ***observed*** one*/
replace wage_change_r12 = . if (wage_change_r12 == 0)
bysort new_id (date): gen wage_change_t12 = (ln(w_t) - ln(l12.w_t)) /*current wage minus the previous ***observed*** one*/
replace wage_change_t12 = . if (wage_change_t12 == 0)

* generate wage changes across jobs

qui xtset cuil_trab date
qui gsort cuil_trab date

bysort cuil_trab (date): gen wage_change_r12jj = (ln(w_r) - ln(l12.w_r)) /*current wage minus the previous ***observed*** one*/
replace wage_change_r12jj = . if (wage_change_r12jj == 0)
bysort cuil_trab (date): gen wage_change_t12jj = (ln(w_t) - ln(l12.w_t)) /*current wage minus the previous ***observed*** one*/
replace wage_change_t12jj = . if (wage_change_t12jj == 0)

* generate early income changes
gen year = year(dofm(date))
qui gsort cuil_trab year

bys cuil_trab year: egen yearly_wt=sum(w_t)
bys cuil_trab year: egen yearly_wr=sum(w_r)

qui xtset cuil_trab date
qui gsort cuil_trab date

bysort cuil_trab (date): gen wage_change_r12ye = (ln(yearly_wr) - ln(l12.yearly_wr)) /*current wage minus the previous ***observed*** one*/
replace wage_change_r12ye = . if (wage_change_r12ye == 0)
bysort cuil_trab (date): gen wage_change_t12ye = (ln(yearly_wt) - ln(l12.yearly_wt)) /*current wage minus the previous ***observed*** one*/
replace wage_change_t12ye = . if (wage_change_t12ye == 0)

gen  aux = 1 if (wage_change_r12 ~=. & wage_change_r12==l.wage_change_r12)
replace wage_change_r12 = . if (wage_change_r12 ~= . & aux==1)
drop aux
gen  aux = 1 if (wage_change_t12 ~=. & wage_change_t12==l.wage_change_t12)
replace wage_change_t12 = . if (wage_change_t12 ~= . & aux==1)
drop aux

gen  aux = 1 if (wage_change_r12jj ~=. & wage_change_r12jj==l.wage_change_r12jj)
replace wage_change_r12jj = . if (wage_change_r12jj ~= . & aux==1)
drop aux
gen  aux = 1 if (wage_change_t12jj ~=. & wage_change_t12jj==l.wage_change_t12jj)
replace wage_change_t12jj = . if (wage_change_t12jj ~= . & aux==1)
drop aux

gen  aux = 1 if (wage_change_r12ye ~=. & wage_change_r12ye==l.wage_change_r12ye)
replace wage_change_r12ye = . if (wage_change_r12ye ~= . & aux==1)
drop aux
gen  aux = 1 if (wage_change_t12ye ~=. & wage_change_t12ye==l.wage_change_t12ye)
replace wage_change_t12ye = . if (wage_change_t12ye ~= . & aux==1)
drop aux

drop yearly_wt yearly_wr

sum wage_change_r12, d

replace wage_change_r12  =-1 if wage_change_r12<=-1 & wage_change_r12~=.
replace wage_change_t12  =-1 if wage_change_t12<=-1 & wage_change_t12~=.
replace wage_change_r12jj  =-1 if wage_change_r12jj<=-1 & wage_change_r12jj~=.
replace wage_change_t12jj  =-1 if wage_change_t12jj<=-1 & wage_change_t12jj~=.
replace wage_change_r12ye  =-1 if wage_change_r12ye<=-1 & wage_change_r12ye~=.
replace wage_change_t12ye  =-1 if wage_change_t12ye<=-1 & wage_change_t12ye~=.

winsor2 wage_change_r12 wage_change_t12, cuts(0 99) by(year) replace
winsor2 wage_change_r12jj wage_change_t12jj, cuts(0 99) by(year) replace
winsor2 wage_change_r12ye wage_change_t12ye , cuts(0 99) by(year) replace

*Creates a histogram per year starting at -1 and the width is 0.01
summ year
forvalues i = `r(min)'(1)`r(max)' {

    preserve
    twoway__histogram_gen wage_change_r12 if (year == `i'), start(-1) width(0.01) fraction gen(freq_`i' bin, replace)
    keep if freq_`i' != .
    keep freq_`i' bin
    save "$results/${name}_w_r_`i'.dta", replace
    restore

    preserve
    twoway__histogram_gen wage_change_t12 if (year == `i'), start(-1) width(0.01) fraction gen(freq_`i' bin, replace)
    keep if freq_`i' != .
    keep freq_`i' bin
    save "$results/${name}_w_t_`i'.dta", replace
    restore

    preserve
    twoway__histogram_gen wage_change_r12jj if (year == `i'), start(-1) width(0.01) fraction gen(freq_`i' bin, replace)
    keep if freq_`i' != .
    keep freq_`i' bin
    save "$results/${name}_w_rjj_`i'.dta", replace
    restore

    preserve
    twoway__histogram_gen wage_change_t12jj if (year == `i'), start(-1) width(0.01) fraction gen(freq_`i' bin, replace)
    keep if freq_`i' != .
    keep freq_`i' bin
    save "$results/${name}_w_tjj_`i'.dta", replace
    restore

	preserve
    twoway__histogram_gen wage_change_r12ye if (year == `i'), start(-1) width(0.01) fraction gen(freq_`i' bin, replace)
    keep if freq_`i' != .
    keep freq_`i' bin
    save "$results/${name}_w_rye_`i'.dta", replace
    restore

    preserve
    twoway__histogram_gen wage_change_t12ye if (year == `i'), start(-1) width(0.01) fraction gen(freq_`i' bin, replace)
    keep if freq_`i' != .
    keep freq_`i' bin
    save "$results/${name}_w_tye_`i'.dta", replace
    restore

}

*  collapse yearly histograms

preserve
summ year
local startloop = `r(min)' + 1
local first = `r(min)'
forvalues i = `startloop'(1)`r(max)' {

    use "$results/${name}_w_r_`first'.dta", clear
    merge 1:1 bin using "$results/${name}_w_r_`i'.dta", nogen
    sleep 1000
    save "$results/${name}_w_r_`first'.dta", replace
    sleep 1000

}

*Final save
save "$results/${name}_w_r.dta", replace

restore

preserve
summ year
local startloop = `r(min)' + 1
local first = `r(min)'
forvalues i = `startloop'(1)`r(max)' {

    use "$results/${name}_w_t_`first'.dta", clear
    merge 1:1 bin using "$results/${name}_w_t_`i'.dta", nogen
    sleep 1000
    save "$results/${name}_w_t_`first'.dta", replace
    sleep 1000

}

*Final save
save "$results/${name}_w_t.dta", replace

restore

preserve
summ year
local startloop = `r(min)' + 1
local first = `r(min)'
forvalues i = `startloop'(1)`r(max)' {

    use "$results/${name}_w_rjj_`first'.dta", clear
    merge 1:1 bin using "$results/${name}_w_rjj_`i'.dta", nogen
    sleep 1000
    save "$results/${name}_w_rjj_`first'.dta", replace
    sleep 1000

}

*Final save
save "$results/${name}_w_rjj.dta", replace

restore

preserve
summ year
local startloop = `r(min)' + 1
local first = `r(min)'
forvalues i = `startloop'(1)`r(max)' {

    use "$results/${name}_w_tjj_`first'.dta", clear
    merge 1:1 bin using "$results/${name}_w_tjj_`i'.dta", nogen
    sleep 1000
    save "$results/${name}_w_tjj_`first'.dta", replace
    sleep 1000

}

*Final save
save "$results/${name}_w_tjj.dta", replace

restore

preserve
summ year
local startloop = `r(min)' + 1
local first = `r(min)'
forvalues i = `startloop'(1)`r(max)' {

    use "$results/${name}_w_rye_`first'.dta", clear
    merge 1:1 bin using "$results/${name}_w_rye_`i'.dta", nogen
    sleep 1000
    save "$results/${name}_w_rye_`first'.dta", replace
    sleep 1000

}

*Final save
save "$results/${name}_w_rye.dta", replace

restore

preserve
summ year
local startloop = `r(min)' + 1
local first = `r(min)'
forvalues i = `startloop'(1)`r(max)' {

    use "$results/${name}_w_tye_`first'.dta", clear
    merge 1:1 bin using "$results/${name}_w_tye_`i'.dta", nogen
    sleep 1000
    save "$results/${name}_w_tye_`first'.dta", replace
    sleep 1000

}

*Final save
save "$results/${name}_w_tye.dta", replace

restore

use "$results/${name}_w_r.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

* Option in the figure

global xlabsize =     "large"
global ylabsize =     "large"
global legesize =     "large"
global xtitlesize =   "large"
global ytitlesize =   "large"
global titlesize  =   "large"

drop if bin<-0.8 | bin>0.8

twoway (line low_pi bin, color(red) lwidth(medium)  ) (line high_pi bin, color(blue) lwidth(medium) ),/*
	*/ ytitle("", size(${ytitlesize}))  xtitle("log wage change", size(${xtitlesize})) graphregion(color(white)) xlabel(-0.75(0.25)0.75, grid labsize(${xlabsize})) xscale(range(-0.75 0.75)) /*
	*/ yscale(range(0 .12)) ylabel(0 .04 .08 .12) /*
	*/ legend(region(color(none) lcolor(white)) symxsize(7.0) size(${legesize}) pos(1) ring(0) col(1) label(1 "Low inflation (1997-2001)") label(2 "High inflation (2007-2015)") )


graph export "${path_figures}/hist12_w_r_appendix.pdf", as (pdf) replace

use "$results/${name}_w_t.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

drop if bin<-0.8 | bin>0.8

twoway (line low_pi bin, color(red) lwidth(medium)  ) (line high_pi bin, color(blue) lwidth(medium) ),/*
	*/ ytitle("", size(${ytitlesize}))  xtitle("log wage change", size(${xtitlesize})) graphregion(color(white)) xlabel(-0.75(0.25)0.75, grid labsize(${xlabsize})) xscale(range(-0.75 0.75)) /*
	*/ yscale(range(0 .12)) ylabel(0 .04 .08 .12) /*
	*/ legend(region(color(none) lcolor(white)) symxsize(7.0) size(${legesize}) pos(1) ring(0) col(1) label(1 "Low inflation (1997-2001)") label(2 "High inflation (2007-2015)") )


graph export "${path_figures}/hist12_w_t_appendix.pdf", as (pdf) replace

use "$results/${name}_w_rjj.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

drop if bin<-0.8 | bin>0.8

twoway (line low_pi bin, color(red) lwidth(medium)  ) (line high_pi bin, color(blue) lwidth(medium) ),/*
	*/ ytitle("", size(${ytitlesize}))  xtitle("log wage change", size(${xtitlesize})) graphregion(color(white)) xlabel(-0.75(0.25)0.75, grid labsize(${xlabsize})) xscale(range(-0.75 0.75)) /*
	*/ yscale(range(0 .12)) ylabel(0 .04 .08 .12) /*
	*/ legend(region(color(none) lcolor(white)) symxsize(7.0) size(${legesize}) pos(1) ring(0) col(1) label(1 "Low inflation (1997-2001)") label(2 "High inflation (2007-2015)") )


graph export "${path_figures}/hist12_w_rjj_appendix.pdf", as (pdf) replace

use "$results/${name}_w_tjj.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

drop if bin<-0.8 | bin>0.8

twoway (line low_pi bin, color(red) lwidth(medium)  ) (line high_pi bin, color(blue) lwidth(medium) ),/*
	*/ ytitle("", size(${ytitlesize}))  xtitle("log wage change", size(${xtitlesize})) graphregion(color(white)) xlabel(-0.75(0.25)0.75, grid labsize(${xlabsize})) xscale(range(-0.75 0.75)) /*
	*/ yscale(range(0 .12)) ylabel(0 .04 .08 .12) /*
	*/ legend(region(color(none) lcolor(white)) symxsize(7.0) size(${legesize}) pos(1) ring(0) col(1) label(1 "Low inflation (1997-2001)") label(2 "High inflation (2007-2015)") )


graph export "${path_figures}/hist12_w_tjj_appendix.pdf", as (pdf) replace


use "$results/${name}_w_rye.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

drop if bin<-0.8 | bin>0.8

twoway (line low_pi bin, color(red) lwidth(medium)  ) (line high_pi bin, color(blue) lwidth(medium) ),/*
	*/ ytitle("", size(${ytitlesize}))  xtitle("log wage change", size(${xtitlesize})) graphregion(color(white)) xlabel(-0.75(0.25)0.75, grid labsize(${xlabsize})) xscale(range(-0.75 0.75)) /*
	*/ yscale(range(0 .12)) ylabel(0 .04 .08 .12) /*
	*/ legend(region(color(none) lcolor(white)) symxsize(7.0) size(${legesize}) pos(1) ring(0) col(1) label(1 "Low inflation (1997-2001)") label(2 "High inflation (2007-2015)") )


graph export "${path_figures}/hist12_w_rye_appendix.pdf", as (pdf) replace


use "$results/${name}_w_tye.dta", replace

gen low_pi=1/5*(freq_1997+freq_1998+freq_1999+freq_2000+freq_2001)

gen high_pi=1/9*(freq_2007+freq_2008+freq_2009+freq_2010+freq_2011+freq_2012+freq_2013+freq_2014+freq_2015)

drop if bin<-0.8 | bin>0.8

twoway (line low_pi bin, color(red) lwidth(medium)  ) (line high_pi bin, color(blue) lwidth(medium) ),/*
	*/ ytitle("", size(${ytitlesize}))  xtitle("log wage change", size(${xtitlesize})) graphregion(color(white)) xlabel(-0.75(0.25)0.75, grid labsize(${xlabsize})) xscale(range(-0.75 0.75)) /*
	*/ yscale(range(0 .12)) ylabel(0 .04 .08 .12) /*
	*/ legend(region(color(none) lcolor(white)) symxsize(7.0) size(${legesize}) pos(1) ring(0) col(1) label(1 "Low inflation (1997-2001)") label(2 "High inflation (2007-2015)") )


graph export "${path_figures}/hist12_w_tye_appendix.pdf", as (pdf) replace
