%{
* DESCRIPTION: This code estimates the Calvo-Taylor model with SMM

* AUTHORS: Andres Blanco (University of Michigan),
*          Bernardo Diaz de Astarloa (Universidad de Buenos Aires and Universidad Nacional de La Plata-CEDLAS),
*          Andres Drenik (University of Texas at Austin),
*          Christian Moser (Columbia University and CEPR), and
*          Danilo R. Trupkin (Universidad de Buenos Aires and IIEP, CONICET-UBA).
*
* TIME STAMP: March 26, 2022.
%}

%% Delete Previous information, close figures and delete text in command window

close all;
clear;
clc;
rng(100);


% add here folder in your computer

Inputfolder    = '/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Part_B/RandomSample/results/estimation';
currentFolder  = pwd;

% Estimate or calibrate the model

p.calibratemodel = 1;                                                      % 1 to calibrate, 0 to load results

% print the result of SMM
p.print          =0;                                                       % =1 if print results


% Number of K in the grid
p.nvalsK         = 10;
p.K_grid         = linspace(0.3,0.6,p.nvalsK);                            % number of parameters in the grid for K

% Number of K in the grid
p.version        =1;                                                       % 1=bechmark, >1=set some shocks to zero

% upper and lower bound in the estimatino
p.paramlb       = [3 ;0.001;-1.50;0.10;0.001;0.2;0.001;0.2];
p.paramub       = [36;0.090;-0.10;1.50;0.500;0.7;0.300;0.7];

%% Compute table for the paper

Moments_data =ones(9,15);
Moments_model=ones(9,15);
Estimate_par =ones(8,15);
K_evaluation =ones(6,15);
n_workers    =ones(1,15);
cd(Inputfolder)

for ii=1:15

    load(strcat('calibpar_',num2str(ii,'%.1i')))

    % Sectoral moments: data
    Moments_data(:,ii)=mom_d;

    % Sectoral moments: model
    Moments_model(:,ii)=mom_m;

    % Parameters for estimation
    Estimate_par(:,ii)=calibpar;

    % Moments for K
    K_evaluation(1,ii)   =K_opt;

    % Moments for K
    K_evaluation(2:6,ii) =moments(1:end-1);

    % number of workers
    n_workers(1,ii) =moments(end);


end

cd(currentFolder)

shares         =n_workers./sum(n_workers);
ind_sec=[4,7];
data_main_table=[Moments_data(:,ind_sec),sum(bsxfun(@times,Moments_data,shares),2)];
mode_main_table=[Moments_model(:,ind_sec),sum(bsxfun(@times,Moments_model,shares),2)];
para_main_table=[Estimate_par(:,ind_sec),sum(bsxfun(@times,Estimate_par,shares),2)];
K_main_table   =[K_evaluation(1,ind_sec),sum(bsxfun(@times,K_evaluation(1,:),shares),2)];
share_main_table=[shares(1,ind_sec)*100,sum(shares(1,:)*100,2)];
Eva_main_table =[K_evaluation(2:end,ind_sec),sum(bsxfun(@times,K_evaluation(2:end,:),shares),2)];


data_main_table=[data_main_table(9,:);data_main_table(1,:);data_main_table(8,:);...
                 data_main_table(2,:);data_main_table(6,:);data_main_table(7,:);...
                 data_main_table(3,:);data_main_table(4,:);data_main_table(5,:)];


mode_main_table=[mode_main_table(9,:);mode_main_table(1,:);mode_main_table(8,:);...
                 mode_main_table(2,:);mode_main_table(6,:);mode_main_table(7,:);...
                 mode_main_table(3,:);mode_main_table(4,:);mode_main_table(5,:)];

para_main_table=[ceil(para_main_table(1,:));para_main_table(3,:);para_main_table(4,:);...
                 para_main_table(2,:);para_main_table(6,:);para_main_table(5,:);...
                 para_main_table(7,:);para_main_table(8,:)]  ;

data_main_table(1,:)=data_main_table(1,:).^0.5;
mode_main_table(1,:)=mode_main_table(1,:).^0.5;

fid=fopen('Table_main.tex','w+');
% Declare variables
fprintf(fid,'\\begin{table}[h!]\n');
fprintf(fid,'\\begin{center} \n');
fprintf(fid,'\\footnotesize \n');
fprintf(fid,'\\caption{{$\\mathcal{K}$ Estimation and Evaluation} \\label{secB:tab:DataModelK}} \n');
fprintf(fid,'\\begin{tabular}{l  c c         c} \n');
fprintf(fid,'& \\\\ \\hline \\hline \n');
%fprintf(fid,'       & \\multicolumn{2}{c|}{Sectors } & Average   \\\\   \n');
fprintf(fid,'  & Manufacturing   & Retail     &  Sector Average \\\\  \\hline   \n');
fprintf(fid,' Moments (data,model):  &&& \\\\ \n');
%fprintf(fid,'& &&\\\\  \n');

names_moments={'~~Mean of 1-yr $\\Delta w$';'~~Std. of 1-yr $\\Delta w$';'~~CV(3) of 1-yr $\\Delta w$';...
                '~~Std. of 1-mo $\\Delta w$';'~~Mean of 1-mo $\\Delta w$ in Jun/Dec';'~~Std. of 1-mo $\\Delta w$ in Jun/Dec';...
                '~~Share of 1-yr $\\Delta w=0$';'~~Share of 1-mo $\\Delta w=0$';'~~Share of 1-mo $\\Delta w>0$'};

for jj=1:size(names_moments,1)




    fprintf(fid,names_moments{jj,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(data_main_table(jj,i),'%2.2f'),',~',num2str(mode_main_table(jj,i),'%2.2f'),')'));

    end
    %if jj==2 || jj==8 || jj==8
    %    fprintf(fid,'\\\\  \\hline \\hline \n');
    %else
        fprintf(fid,'\\\\  \n');
    %end

end

fprintf(fid,'& && \\\\  \n');
fprintf(fid,'Parameters:   & & \\\\   \n');
%fprintf(fid,'& & &\\\\  \n');
names_moments={' $~~(T,\\tilde{w}^{-},\\tilde{w}^{+})$';...
                '$~~\\sigma_{\\eta}$';'$~~(m_{\\phi},\\sigma_{\\phi})$';...
                '$~~(\\sigma_{\\gamma},\\beta)$'};

    fprintf(fid,names_moments{1,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(1,i),'%2.0f'),',~',num2str(para_main_table(2,i),'%2.2f'),',~',num2str(para_main_table(3,i),'%2.1f'),'~)'));

    end
        fprintf(fid,'\\\\  \n');

    fprintf(fid,names_moments{2,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('&   ',num2str(para_main_table(4,i),'%2.2f') ));

    end
        fprintf(fid,'\\\\  \n');

  fprintf(fid,names_moments{3,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(5,i),'%2.2f'),',~',num2str(para_main_table(6,i),'%2.2f') ,')'));

    end
        fprintf(fid,'\\\\  \n');

          fprintf(fid,names_moments{4,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(para_main_table(7,i),'%2.2f'),',~',num2str(para_main_table(8,i),'%2.2f') ,')'));

    end
        fprintf(fid,'\\\\  \n');
fprintf(fid,'& & &\\\\    \n');

fprintf(fid,'Threshold and Break Test Evaluation: &&&\\\\  \n');
%fprintf(fid,'& && \\\\    \n');
fprintf(fid,'$~~\\mathcal{K}$     ');
    for i=1:size(K_main_table,2)

        fprintf(fid,strcat('&  ',num2str(K_main_table(1,i),'%2.2f')));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr($w_t^R \\neq  w_{t-1}^R$) (model,Break Test)     ');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& (',num2str(Eva_main_table(3,i),'%2.2f'),',~',num2str(Eva_main_table(5,i),'%2.2f'),')'));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(no break in $t$|no break $t$)    ');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& ',num2str(1-Eva_main_table(1,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(break between $t-2,t+2$ |break $t$)');
    for i=1:size(Eva_main_table,2)

        fprintf(fid,strcat('& ',num2str(1-Eva_main_table(2,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'&& & \\\\ \\hline \\hline  \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\vspace{0.1in} \\\\  \n');
fprintf(fid,'\\end{center} \n');

fprintf(fid,'{\\footnotesize Notes: The table presents moments used in the SMM estimation. $\\Delta w$ denotes wage changes.');
fprintf(fid,' The first block of rows (i.e., rows 1 to 9) describes the wage change moments in the data and in the model.');
fprintf(fid,' The second block of rows (i.e., rows 10 to 13) describes the estimated parameters.');
fprintf(fid,' The last block of rows (i.e., rows 14 to 17) describes the value of $\\mathcal{K}$ across sectors and some statistics to evaluate the validity of the methodology.');
fprintf(fid,' We truncate the wage change distribution at the 2nd and 98th percentiles in the data and in the model.');
fprintf(fid,' CV(3) denotes the third order generalized coefficient of variation, i.e., $CV(3)=E[\\Delta w^3]/E[\\Delta w]^3$. ');
fprintf(fid,' The last column shows the average results across sectors weighted by the number of workers in each sector. \\\\ \n    ');
fprintf(fid,' Source: SIPA, 1996--2015, and simulations. } \n');

fprintf(fid,'\\end{table} \n');
fclose(fid);

movefile('Table_main.tex','/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Tables');

%% Table in the appendix

shares         =n_workers./sum(n_workers);
ind_sec=[1,2,3,4];
data_main_table=Moments_data(:,ind_sec);
mode_main_table=Moments_model(:,ind_sec) ;
para_main_table=Estimate_par(:,ind_sec) ;
K_main_table   =K_evaluation(1,ind_sec) ;
share_main_table=shares(1,ind_sec)*100 ;
Eva_main_table = K_evaluation(2:end,ind_sec) ;


data_main_table=[data_main_table(9,:);data_main_table(1,:);data_main_table(8,:);...
                 data_main_table(2,:);data_main_table(6,:);data_main_table(7,:);...
                 data_main_table(3,:);data_main_table(4,:);data_main_table(5,:)];


mode_main_table=[mode_main_table(9,:);mode_main_table(1,:);mode_main_table(8,:);...
                 mode_main_table(2,:);mode_main_table(6,:);mode_main_table(7,:);...
                 mode_main_table(3,:);mode_main_table(4,:);mode_main_table(5,:)];

para_main_table=[ceil(para_main_table(1,:));para_main_table(3,:);para_main_table(4,:);...
                 para_main_table(2,:);para_main_table(6,:);para_main_table(5,:);...
                 para_main_table(7,:);para_main_table(8,:)]  ;

data_main_table(1,:)=data_main_table(1,:).^0.5;
mode_main_table(1,:)=mode_main_table(1,:).^0.5;

fid=fopen('Table_main_A1.tex','w+');
% Declare variables
fprintf(fid,'\\begin{table}[t]\n');
fprintf(fid,'\\begin{center} \n');
fprintf(fid,'\\footnotesize \n');
fprintf(fid,'\\caption{{$\\mathcal{K}$ Estimation and Evaluation for Sectors 1 to 4} \\label{secB:tab:DataModelK_A1}} \n');
fprintf(fid,'\\begin{tabular}{l | c c c c        } \n');
fprintf(fid,'& \\\\ \\hline \\hline \n');
fprintf(fid,'       & \\multicolumn{4}{c }{Sectors }     \\\\   \n');
fprintf(fid,'  & 1   & 2     &  3  &4   \\\\  \\hline \n');
fprintf(fid,' Moments (data,model):   &&& \\\\  \n');
%fprintf(fid,'& &&\\\\  \n');
names_moments={'~~Mean of 1-yr $\\Delta w$';'~~Std. of 1-yr $\\Delta w$';'~~CV(3) of 1-yr $\\Delta w$';...
                '~~Std. of 1-mo $\\Delta w$';'~~Mean of 1-mo $\\Delta w$ in Jun/Dec';'~~Std. of 1-mo $\\Delta w$ in Jun/Dec';...
                '~~Share of 1-yr $\\Delta w=0$';'~~Share of 1-mo $\\Delta w=0$';'~~Share of 1-mo $\\Delta w>0$'};

for jj=1:size(names_moments,1)




    fprintf(fid,names_moments{jj,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(data_main_table(jj,i),'%2.2f'),',~',num2str(mode_main_table(jj,i),'%2.2f'),')'));

    end
    %if jj==2 || jj==8 || jj==8
    %    fprintf(fid,'\\\\  \\hline \\hline \n');
    %else
        fprintf(fid,'\\\\  \n');
    %end

end

fprintf(fid,'& && \\\\  \n');
fprintf(fid,'Parameters:   & & \\\\   \n');
%fprintf(fid,'& & &\\\\  \n');
names_moments={' $~~(T,\\tilde{w}^{-},\\tilde{w}^{+})$';...
                '$~~\\sigma_{\\eta}$';'$~~(m_{\\phi},\\sigma_{\\phi})$';...
                '$~~(\\sigma_{\\gamma},\\beta)$'};

    fprintf(fid,names_moments{1,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(para_main_table(1,i),'%2.0f'),',',num2str(para_main_table(2,i),'%2.2f'),',',num2str(para_main_table(3,i),'%2.1f'),')'));

    end
        fprintf(fid,'\\\\  \n');

    fprintf(fid,names_moments{2,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('&   ',num2str(para_main_table(4,i),'%2.2f') ));

    end
        fprintf(fid,'\\\\  \n');

  fprintf(fid,names_moments{3,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(para_main_table(5,i),'%2.2f'),'~,~',num2str(para_main_table(6,i),'%2.2f') ,'~)'));

    end
        fprintf(fid,'\\\\  \n');

          fprintf(fid,names_moments{4,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(para_main_table(7,i),'%2.2f'),'~,~',num2str(para_main_table(8,i),'%2.2f') ,'~)'));

    end
        fprintf(fid,'\\\\  \n');
fprintf(fid,'& & &\\\\    \n');

fprintf(fid,'Threshold and Break Test Evaluation: &&&\\\\   \n');
%fprintf(fid,'& && \\\\    \n');
fprintf(fid,'$~~\\mathcal{K}$     ');
    for i=1:size(K_main_table,2)

        fprintf(fid,strcat('&  ',num2str(K_main_table(1,i),'%2.2f')));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr($w_t^R  \\neq w_{t-1}^R  $)');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& (',num2str(Eva_main_table(3,i),'%2.2f'),',~',num2str(Eva_main_table(5,i),'%2.2f'),')'));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(no break in $t$|no break $t$)    ');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& ',num2str(1-Eva_main_table(1,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(break between $t\\pm 2$ |break $t$)');
    for i=1:size(Eva_main_table,2)

        fprintf(fid,strcat('& ',num2str(1-Eva_main_table(2,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'&& & \\\\ \\hline \\hline  \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\vspace{0.1in} \\\\  \n');
fprintf(fid,'\\end{center} \n');

fprintf(fid,'{\\footnotesize Notes: The table presents selected moments of the wage data in the SMM estimation for sectors 1 (i.e., agriculture), 2 (i.e., fishing), 3 (i.e., minining), and 4 (i.e., manufacturing). $\\Delta w$ denotes wage changes.');
fprintf(fid,' The first block of rows (i.e., rows 1 to 9) describes the wage change moments in the data and in the model.');
fprintf(fid,' The second block of rows (i.e., rows 10 to 13) describes the estimated parameters.');
fprintf(fid,' The last block of rows (i.e., rows 14 to 17) describes the value of $\\mathcal{K}$ across sectors and some statistics to evaluate the validity of the methodology.');
fprintf(fid,' We truncate the wage change distribution at the 2nd and 98th percentiles in the data and in the model.');
fprintf(fid,' CV(3) denotes the third order generalized coefficient of variation, i.e., $CV(3)=E[\\Delta w^3]/E[\\Delta w]^3$. ');
fprintf(fid,' The last column shows the average results across sectors weighted by the number of workers in each sector. \\\\ \n    ');
fprintf(fid,' Source: SIPA, 1996--2015, and simulations. } \n');

fprintf(fid,'\\end{table} \n');
fclose(fid);

movefile('Table_main_A1.tex','/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Tables');


shares         =n_workers./sum(n_workers);
ind_sec=[5,6,7,8];
data_main_table=Moments_data(:,ind_sec);
mode_main_table=Moments_model(:,ind_sec) ;
para_main_table=Estimate_par(:,ind_sec) ;
K_main_table   =K_evaluation(1,ind_sec) ;
share_main_table=shares(1,ind_sec)*100 ;
Eva_main_table = K_evaluation(2:end,ind_sec) ;


data_main_table=[data_main_table(9,:);data_main_table(1,:);data_main_table(8,:);...
                 data_main_table(2,:);data_main_table(6,:);data_main_table(7,:);...
                 data_main_table(3,:);data_main_table(4,:);data_main_table(5,:)];


mode_main_table=[mode_main_table(9,:);mode_main_table(1,:);mode_main_table(8,:);...
                 mode_main_table(2,:);mode_main_table(6,:);mode_main_table(7,:);...
                 mode_main_table(3,:);mode_main_table(4,:);mode_main_table(5,:)];

para_main_table=[ceil(para_main_table(1,:));para_main_table(3,:);para_main_table(4,:);...
                 para_main_table(2,:);para_main_table(6,:);para_main_table(5,:);...
                 para_main_table(7,:);para_main_table(8,:)]  ;

data_main_table(1,:)=data_main_table(1,:).^0.5;
mode_main_table(1,:)=mode_main_table(1,:).^0.5;

fid=fopen('Table_main_A2.tex','w+');
% Declare variables
fprintf(fid,'\\begin{table}[t]\n');
fprintf(fid,'\\begin{center} \n');
fprintf(fid,'\\footnotesize \n');
fprintf(fid,'\\caption{{$\\mathcal{K}$ Estimation and Evaluation for Sectors 5 to 7} \\label{secB:tab:DataModelK_A2}} \n');
fprintf(fid,'\\begin{tabular}{l  c c c c c      } \n');
fprintf(fid,'& \\\\ \\hline  \\hline \n');
fprintf(fid,'       & \\multicolumn{4}{c }{Sectors }     \\\\   \n');
fprintf(fid,'  & 5   & 6     &  7  &8   \\\\  \\hline \n');
fprintf(fid,' Moments (data,model):   &&& \\\\  \n');
%fprintf(fid,'& &&\\\\  \n');

names_moments={'~~Mean of 1-yr $\\Delta w$';'~~Std. of 1-yr $\\Delta w$';'~~CV(3) of 1-yr $\\Delta w$';...
                '~~Std. of 1-mo $\\Delta w$';'~~Mean of 1-mo $\\Delta w$ in Jun/Dec';'~~Std. of 1-mo $\\Delta w$ in Jun/Dec';...
                '~~Share of 1-yr $\\Delta w=0$';'~~Share of 1-mo $\\Delta w=0$';'~~Share of 1-mo $\\Delta w>0$'};

for jj=1:size(names_moments,1)




    fprintf(fid,names_moments{jj,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(data_main_table(jj,i),'%2.2f'),',~',num2str(mode_main_table(jj,i),'%2.2f'),')'));

    end
    %if jj==2 || jj==8 || jj==8
    %    fprintf(fid,'\\\\  \\hline \\hline \n');
    %else
        fprintf(fid,'\\\\  \n');
    %end

end

fprintf(fid,'& && \\\\  \n');
fprintf(fid,'Parameters:   & & \\\\ \n');
%fprintf(fid,'& & &\\\\  \n');
names_moments={' $~~(T,\\tilde{w}^{-},\\tilde{w}^{+})$';...
                '$~~\\sigma_{\\eta}$';'$~~(m_{\\phi},\\sigma_{\\phi})$';...
                '$~~(\\sigma_{\\gamma},\\beta)$'};

    fprintf(fid,names_moments{1,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(1,i),'%2.0f'),',~',num2str(para_main_table(2,i),'%2.2f'),',~',num2str(para_main_table(3,i),'%2.1f'),')'));

    end
        fprintf(fid,'\\\\  \n');

    fprintf(fid,names_moments{2,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('&   ',num2str(para_main_table(4,i),'%2.2f') ));

    end
        fprintf(fid,'\\\\  \n');

  fprintf(fid,names_moments{3,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(5,i),'%2.2f'),',~',num2str(para_main_table(6,i),'%2.2f') ,')'));

    end
        fprintf(fid,'\\\\  \n');

          fprintf(fid,names_moments{4,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(7,i),'%2.2f'),',~',num2str(para_main_table(8,i),'%2.2f') ,')'));

    end
        fprintf(fid,'\\\\  \n');
fprintf(fid,'& & &\\\\    \n');

fprintf(fid,'Threshold and Break Test Evaluation: &&&\\\\  \n');
%fprintf(fid,'& && \\\\    \n');
fprintf(fid,'$~~\\mathcal{K}$     ');
    for i=1:size(K_main_table,2)

        fprintf(fid,strcat('&  ',num2str(K_main_table(1,i),'%2.2f')));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr($w_t^R  \\neq w_{t-1}^R $)');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& (',num2str(Eva_main_table(3,i),'%2.2f'),',~',num2str(Eva_main_table(5,i),'%2.2f'),')'));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(no break in $t$|no break $t$)    ');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& ',num2str(1-Eva_main_table(1,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(break between $t\\pm 2$ |break $t$)');
    for i=1:size(Eva_main_table,2)

        fprintf(fid,strcat('& ',num2str(1-Eva_main_table(2,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'&& & \\\\ \\hline \\hline  \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\vspace{0.1in} \\\\  \n');
fprintf(fid,'\\end{center} \n');

fprintf(fid,'{\\footnotesize Notes: The table presents selected moments of the wage data in the SMM estimation for sectors 5 (i.e., construction), 6 (i.e., retail), 7 (i.e., hotel and restaurant), and 8 (i.e., transport). $\\Delta w$ denotes wage changes.');
fprintf(fid,' The first block of rows (i.e., rows 1 to 9) describes the wage change moments in the data and in the model.');
fprintf(fid,' The second block of rows (i.e., rows 10 to 13) describes the estimated parameters.');
fprintf(fid,' The last block of rows (i.e., rows 14 to 17) describes the value of $\\mathcal{K}$ across sectors and some statistics to evaluate the validity of the methodology.');
fprintf(fid,' We truncate the wage change distribution at the 2nd and 98th percentiles in the data and in the model.');
fprintf(fid,' CV(3) denotes the third order generalized coefficient of variation, i.e., $CV(3)=E[\\Delta w^3]/E[\\Delta w]^3$. ');
fprintf(fid,' The last column shows the average results across sectors weighted by the number of workers in each sector. \\\\ \n    ');
fprintf(fid,' Source: SIPA, 1996--2015, and simulations. } \n');

fprintf(fid,'\\end{table} \n');
fclose(fid);

movefile('Table_main_A2.tex','/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Tables');


shares         =n_workers./sum(n_workers);
ind_sec=[9,10,11,13];
data_main_table=Moments_data(:,ind_sec);
mode_main_table=Moments_model(:,ind_sec) ;
para_main_table=Estimate_par(:,ind_sec) ;
K_main_table   =K_evaluation(1,ind_sec) ;
share_main_table=shares(1,ind_sec)*100 ;
Eva_main_table = K_evaluation(2:end,ind_sec) ;


data_main_table=[data_main_table(9,:);data_main_table(1,:);data_main_table(8,:);...
                 data_main_table(2,:);data_main_table(6,:);data_main_table(7,:);...
                 data_main_table(3,:);data_main_table(4,:);data_main_table(5,:)];


mode_main_table=[mode_main_table(9,:);mode_main_table(1,:);mode_main_table(8,:);...
                 mode_main_table(2,:);mode_main_table(6,:);mode_main_table(7,:);...
                 mode_main_table(3,:);mode_main_table(4,:);mode_main_table(5,:)];

para_main_table=[ceil(para_main_table(1,:));para_main_table(3,:);para_main_table(4,:);...
                 para_main_table(2,:);para_main_table(6,:);para_main_table(5,:);...
                 para_main_table(7,:);para_main_table(8,:)]  ;

data_main_table(1,:)=data_main_table(1,:).^0.5;
mode_main_table(1,:)=mode_main_table(1,:).^0.5;

fid=fopen('Table_main_A3.tex','w+');
% Declare variables
fprintf(fid,'\\begin{table}[t]\n');
fprintf(fid,'\\begin{center} \n');
fprintf(fid,'\\footnotesize \n');
fprintf(fid,'\\caption{{$\\mathcal{K}$ Estimation and Evaluation for Sectors 9 to 12} \\label{secB:tab:DataModelK_A3}} \n');
fprintf(fid,'\\begin{tabular}{l  c c c c c      } \n');
fprintf(fid,'& \\\\ \\hline   \\hline   \n');
fprintf(fid,'       & \\multicolumn{4}{c }{Sectors }     \\\\   \n');
fprintf(fid,'  & 9   & 10     &  11  &12   \\\\   \\hline \n');
fprintf(fid,' Moments (data,model):   &&& \\\\   \n');
%fprintf(fid,'& &&\\\\  \n');

names_moments={'~~Mean of 1-yr $\\Delta w$';'~~Std. of 1-yr $\\Delta w$';'~~CV(3) of 1-yr $\\Delta w$';...
                '~~Std. of 1-mo $\\Delta w$';'~~Mean of 1-mo $\\Delta w$ in Jun/Dec';'~~Std. of 1-mo $\\Delta w$ in Jun/Dec';...
                '~~Share of 1-yr $\\Delta w=0$';'~~Share of 1-mo $\\Delta w=0$';'~~Share of 1-mo $\\Delta w>0$'};

for jj=1:size(names_moments,1)




    fprintf(fid,names_moments{jj,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(data_main_table(jj,i),'%2.2f'),',~',num2str(mode_main_table(jj,i),'%2.2f'),')'));

    end
    %if jj==2 || jj==8 || jj==8
    %    fprintf(fid,'\\\\  \\hline \\hline \n');
    %else
        fprintf(fid,'\\\\  \n');
    %end

end

fprintf(fid,'& && \\\\  \n');
fprintf(fid,'Parameters:   & & \\\\  \n');
%fprintf(fid,'& & &\\\\  \n');
names_moments={' $~~(T,\\tilde{w}^{-},\\tilde{w}^{+})$';...
                '$~~\\sigma_{\\eta}$';'$~~(m_{\\phi},\\sigma_{\\phi})$';...
                '$~~(\\sigma_{\\gamma},\\beta)$'};


    fprintf(fid,names_moments{1,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(1,i),'%2.0f'),',~',num2str(para_main_table(2,i),'%2.2f'),',~',num2str(para_main_table(3,i),'%2.1f'),')'));

    end
        fprintf(fid,'\\\\  \n');

    fprintf(fid,names_moments{2,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('&   ',num2str(para_main_table(4,i),'%2.2f') ));

    end
        fprintf(fid,'\\\\  \n');

  fprintf(fid,names_moments{3,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(5,i),'%2.2f'),',~',num2str(para_main_table(6,i),'%2.2f') ,')'));

    end
        fprintf(fid,'\\\\  \n');

          fprintf(fid,names_moments{4,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(7,i),'%2.2f'),',~',num2str(para_main_table(8,i),'%2.2f') ,')'));

    end
        fprintf(fid,'\\\\  \n');
fprintf(fid,'& & &\\\\    \n');

fprintf(fid,'Threshold and Break Test Evaluation: &&&\\\\   \n');
%fprintf(fid,'& && \\\\    \n');
fprintf(fid,'$~~\\mathcal{K}$     ');
    for i=1:size(K_main_table,2)

        fprintf(fid,strcat('&  ',num2str(K_main_table(1,i),'%2.2f')));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr($w_t^R  \\neq w_{t-1}^R $)');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& (',num2str(Eva_main_table(3,i),'%2.2f'),',~',num2str(Eva_main_table(5,i),'%2.2f'),')'));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(no break in $t$|no break $t$)    ');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& ',num2str(1-Eva_main_table(1,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(break between $t\\pm 2$ |break $t$)');
    for i=1:size(Eva_main_table,2)

        fprintf(fid,strcat('& ',num2str(1-Eva_main_table(2,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'&& & \\\\ \\hline \\hline  \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\vspace{0.1in} \\\\  \n');
fprintf(fid,'\\end{center} \n');

fprintf(fid,'{\\footnotesize Notes: The table presents selected moments of the wage data in the SMM estimation for sectors 9 (i.e., financial activities), 10 (i.e., real state activities), 11 (i.e., education), and 12 (i.e., social services). $\\Delta w$ denotes wage changes.');
fprintf(fid,' The first block of rows (i.e., rows 1 to 9) describes the wage change moments in the data and in the model.');
fprintf(fid,' The second block of rows (i.e., rows 10 to 13) describes the estimated parameters.');
fprintf(fid,' The last block of rows (i.e., rows 14 to 17) describes the value of $\\mathcal{K}$ across sectors and some statistics to evaluate the validity of the methodology.');
fprintf(fid,' We truncate the wage change distribution at the 2nd and 98th percentiles in the data and in the model.');
fprintf(fid,' CV(3) denotes the third order generalized coefficient of variation, i.e., $CV(3)=E[\\Delta w^3]/E[\\Delta w]^3$. ');
fprintf(fid,' The last column shows the average results across sectors weighted by the number of workers in each sector. \\\\ \n    ');
fprintf(fid,' Source: SIPA, 1996--2015, and simulations. } \n');



fprintf(fid,'\\end{table} \n');
fclose(fid);

movefile('Table_main_A3.tex','/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Tables');


shares         =n_workers./sum(n_workers);
ind_sec=[14,15];
data_main_table=Moments_data(:,ind_sec);
mode_main_table=Moments_model(:,ind_sec) ;
para_main_table=Estimate_par(:,ind_sec) ;
K_main_table   =K_evaluation(1,ind_sec) ;
share_main_table=shares(1,ind_sec)*100 ;
Eva_main_table = K_evaluation(2:end,ind_sec) ;


data_main_table=[data_main_table(9,:);data_main_table(1,:);data_main_table(8,:);...
                 data_main_table(2,:);data_main_table(6,:);data_main_table(7,:);...
                 data_main_table(3,:);data_main_table(4,:);data_main_table(5,:)];


mode_main_table=[mode_main_table(9,:);mode_main_table(1,:);mode_main_table(8,:);...
                 mode_main_table(2,:);mode_main_table(6,:);mode_main_table(7,:);...
                 mode_main_table(3,:);mode_main_table(4,:);mode_main_table(5,:)];

para_main_table=[ceil(para_main_table(1,:));para_main_table(3,:);para_main_table(4,:);...
                 para_main_table(2,:);para_main_table(6,:);para_main_table(5,:);...
                 para_main_table(7,:);para_main_table(8,:)]  ;

data_main_table(1,:)=data_main_table(1,:).^0.5;
mode_main_table(1,:)=mode_main_table(1,:).^0.5;

fid=fopen('Table_main_A4.tex','w+');
% Declare variables
fprintf(fid,'\\begin{table}[t]\n');
fprintf(fid,'\\begin{center} \n');
fprintf(fid,'\\footnotesize \n');
fprintf(fid,'\\caption{{$\\mathcal{K}$ Estimation and Evaluation for Sectors 9 to 12} \\label{secB:tab:DataModelK_A4}} \n');
fprintf(fid,'\\begin{tabular}{l   c c         } \n');
fprintf(fid,'& \\\\ \\hline  \\hline   \n');
fprintf(fid,'       & \\multicolumn{2}{c }{Sectors }     \\\\   \n');
fprintf(fid,'  & 13   & 14     \\\\ \\hline   \n');
fprintf(fid,' Moments (data,model):   &&  \\\\   \n');
%fprintf(fid,'&  &\\\\  \n');

names_moments={'~~Mean of 1-yr $\\Delta w$';'~~Std. of 1-yr $\\Delta w$';'~~CV(3) of 1-yr $\\Delta w$';...
                '~~Std. of 1-mo $\\Delta w$';'~~Mean of 1-mo $\\Delta w$ in Jun/Dec';'~~Std. of 1-mo $\\Delta w$ in Jun/Dec';...
                '~~Share of 1-yr $\\Delta w=0$';'~~Share of 1-mo $\\Delta w=0$';'~~Share of 1-mo $\\Delta w>0$'};

for jj=1:size(names_moments,1)




    fprintf(fid,names_moments{jj,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& ( ',num2str(data_main_table(jj,i),'%2.2f'),',~',num2str(mode_main_table(jj,i),'%2.2f'),')'));

    end
    %if jj==2 || jj==8 || jj==8
    %    fprintf(fid,'\\\\  \\hline \\hline \n');
    %else
        fprintf(fid,'\\\\  \n');
    %end

end

fprintf(fid,'& &  \\\\  \n');
fprintf(fid,'Parameters:   & & \\\\   \n');
%fprintf(fid,'& & \\\\  \n');
names_moments={' $~~(T,\\tilde{w}^{-},\\tilde{w}^{+})$';...
                '$~~\\sigma_{\\eta}$';'$~~(m_{\\phi},\\sigma_{\\phi})$';...
                '$~~(\\sigma_{\\gamma},\\beta)$'};

    fprintf(fid,names_moments{1,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(1,i),'%2.0f'),',~',num2str(para_main_table(2,i),'%2.2f'),',~',num2str(para_main_table(3,i),'%2.1f'),')'));

    end
        fprintf(fid,'\\\\  \n');

    fprintf(fid,names_moments{2,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('&   ',num2str(para_main_table(4,i),'%2.0f') ));

    end
        fprintf(fid,'\\\\  \n');

  fprintf(fid,names_moments{3,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(5,i),'%2.2f'),',~',num2str(para_main_table(6,i),'%2.2f') ,')'));

    end
        fprintf(fid,'\\\\  \n');

          fprintf(fid,names_moments{4,1});

    for i=1:size(data_main_table,2)

        fprintf(fid,strcat('& (',num2str(para_main_table(7,i),'%2.2f'),',~',num2str(para_main_table(8,i),'%2.2f') ,')'));

    end
        fprintf(fid,'\\\\  \n');
fprintf(fid,'& & \\\\    \n');

fprintf(fid,'Threshold and Break Test Evaluation: &\\\\  \n');
%fprintf(fid,'& && \\\\    \n');
fprintf(fid,'$~~\\mathcal{K}$     ');
    for i=1:size(K_main_table,2)

        fprintf(fid,strcat('&  ',num2str(K_main_table(1,i),'%2.2f')));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr($w_t^R  \\neq w_{t-1}^R $)');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& (',num2str(Eva_main_table(3,i),'%2.2f'),',~',num2str(Eva_main_table(5,i),'%2.2f'),')'));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(no break in $t$|no break $t$)    ');
    for i=1:size(Eva_main_table,2)

      fprintf(fid,strcat('& ',num2str(1-Eva_main_table(1,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'~~Pr(break between $t\\pm 2$ |break $t$)');
    for i=1:size(Eva_main_table,2)

        fprintf(fid,strcat('& ',num2str(1-Eva_main_table(2,i),'%2.2f') ));

    end
fprintf(fid,'\\\\  \n');

fprintf(fid,'&&   \\\\ \\hline \\hline  \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\vspace{0.1in} \\\\  \n');
fprintf(fid,'\\end{center} \n');

fprintf(fid,'{\\footnotesize Notes: The table presents selected moments of the wage data in the SMM estimation for sectors 13 (i.e., health) and 14 (i.e., personales and comunity services).  $\\Delta w$ denotes wage changes.');
fprintf(fid,' The first block of rows (i.e., rows 1 to 9) describes the wage change moments in the data and in the model.');
fprintf(fid,' The second block of rows (i.e., rows 10 to 13) describes the estimated parameters.');
fprintf(fid,' The last block of rows (i.e., rows 14 to 17) describes the value of $\\mathcal{K}$ across sectors and some statistics to evaluate the validity of the methodology.');
fprintf(fid,' We truncate the wage change distribution at the 2nd and 98th percentiles in the data and in the model.');
fprintf(fid,' CV(3) denotes the third order generalized coefficient of variation, i.e., $CV(3)=E[\\Delta w^3]/E[\\Delta w]^3$. ');
fprintf(fid,' The last column shows the average results across sectors weighted by the number of workers in each sector. \\\\ \n    ');
fprintf(fid,' Source: SIPA, 1996--2015, and simulations. } \n');


fprintf(fid,'\\end{table} \n');
fclose(fid);

movefile('Table_main_A4.tex','/Users/jablanco/Dropbox (University of Michigan)/papers_new/GID_Argentina/Tables');
